Package: statease
Title: Simplified Statistical Analysis with Plain-English
        Interpretation
Version: 1.3.0
Authors@R: 
    person("Uwakmfon", "Paul", , "uwakmfon31@gmail.com", role = c("aut", "cre", "cph"))
Description: A toolkit for common statistical analyses including descriptive statistics, Student's t-tests (one-sample, independent, and paired), one-way and two-way Analysis of Variance (ANOVA), Multivariate Analysis of Variance (MANOVA), chi-square tests, Fisher's Exact Test, McNemar's Test, correlation analysis, simple and multiple linear regression, logistic regression, Friedman Test, and non-parametric tests (Mann-Whitney U, Wilcoxon Signed Rank, and Kruskal-Wallis). Additional tools include statistical power analysis and automated assumption checking. Each function automatically interprets results in plain English, reporting effect sizes, confidence intervals, and p-value interpretations. Post-hoc tests are automatically applied following significant results. A master function automatically detects the appropriate test based on the structure of the input data. Methods are based on Cohen, J. (1988) <doi:10.4324/9780203771587>, Tukey, J. W. (1949) <doi:10.2307/3001913>, and Shapiro and Wilk (1965) <doi:10.2307/2333709>.
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://github.com/DevWebWacky/statease,
        https://devwebwacky.github.io/statease/
BugReports: https://github.com/DevWebWacky/statease/issues
Config/roxygen2/version: 8.0.0
Suggests: DT, shinydashboard, shinyjs, knitr, rmarkdown, testthat (>=
        3.0.0)
VignetteBuilder: knitr
Imports: car, pwr, shiny,
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-07-01 11:08:09 UTC; Wacky
Author: Uwakmfon Paul [aut, cre, cph]
Maintainer: Uwakmfon Paul <uwakmfon31@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-02 07:00:10 UTC
Built: R 4.4.3; ; 2026-07-02 09:28:08 UTC; unix

Package: statease
Title: Simplified Statistical Analysis with Plain-English
        Interpretation
Version: 1.2.1
Authors@R: 
    person("Uwakmfon", "Paul", , "uwakmfon31@gmail.com", role = c("aut", "cre", "cph"))
Description: A toolkit for common statistical analyses including descriptive statistics, Student's t-tests (one-sample, independent, and paired), one-way and two-way Analysis of Variance (ANOVA), Multivariate Analysis of Variance (MANOVA), chi-square tests, correlation analysis, simple and multiple linear regression, logistic regression, and non-parametric tests (Mann-Whitney U, Wilcoxon Signed Rank, and Kruskal-Wallis). Each function automatically interprets results in plain English, reporting effect sizes, confidence intervals, and p-value interpretations. Post-hoc tests are automatically applied following significant results. A master function automatically detects the appropriate test based on the structure of the input data. Methods are based on Cohen, J. (1988) <doi:10.4324/9780203771587>, Tukey, J. W. (1949) <doi:10.2307/3001913>, and Shapiro and Wilk (1965) <doi:10.2307/2333709>.
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://github.com/DevWebWacky/statease,
        https://devwebwacky.github.io/statease/
BugReports: https://github.com/DevWebWacky/statease/issues
Config/roxygen2/version: 8.0.0
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
Imports: car
NeedsCompilation: no
Packaged: 2026-06-06 15:39:02 UTC; Wacky
Author: Uwakmfon Paul [aut, cre, cph]
Maintainer: Uwakmfon Paul <uwakmfon31@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-07 14:10:10 UTC
Built: R 4.6.0; ; 2026-06-07 17:21:23 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method(print,statease_anova)
S3method(print,statease_anova2)
S3method(print,statease_assumptions)
S3method(print,statease_chisq)
S3method(print,statease_cor)
S3method(print,statease_describe)
S3method(print,statease_fisher)
S3method(print,statease_friedman)
S3method(print,statease_kruskal)
S3method(print,statease_logistic)
S3method(print,statease_mannwhitney)
S3method(print,statease_manova)
S3method(print,statease_mcnemar)
S3method(print,statease_mlr)
S3method(print,statease_power)
S3method(print,statease_pvalue)
S3method(print,statease_reg)
S3method(print,statease_ttest)
S3method(print,statease_wilcoxon)
export(analyze)
export(anova2_interpret)
export(anova_interpret)
export(check_assumptions)
export(chisq_interpret)
export(cor_interpret)
export(describe)
export(fisher_interpret)
export(friedman_interpret)
export(interpret_p)
export(kruskal_interpret)
export(logistic_interpret)
export(mannwhitney_interpret)
export(manova_interpret)
export(mcnemar_interpret)
export(mlr_interpret)
export(power_interpret)
export(reg_interpret)
export(run_app)
export(ttest_interpret)
export(wilcoxon_interpret)
importFrom(stats,IQR)
importFrom(stats,TukeyHSD)
importFrom(stats,aov)
importFrom(stats,as.formula)
importFrom(stats,bartlett.test)
importFrom(stats,binomial)
importFrom(stats,chisq.test)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,confint.default)
importFrom(stats,contr.sum)
importFrom(stats,cor.test)
importFrom(stats,fisher.test)
importFrom(stats,fitted)
importFrom(stats,friedman.test)
importFrom(stats,glm)
importFrom(stats,kruskal.test)
importFrom(stats,ks.test)
importFrom(stats,lm)
importFrom(stats,manova)
importFrom(stats,mcnemar.test)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,summary.aov)
importFrom(stats,t.test)
importFrom(stats,var.test)
importFrom(stats,wilcox.test)
importFrom(utils,combn)

# statease <img src="man/figures/logo.png" align="right" height="139" />

![CRAN Total](https://cranlogs.r-pkg.org/badges/grand-total/statease)
![CRAN Version](https://www.r-pkg.org/badges/version/statease)

> Simplified statistical analysis with plain-English interpretation for R

## Overview

**statease** is an R package that runs a wide range of statistical
analyses and tells you in plain English what the results mean.
No more copy-pasting output into interpretation guides.
One function call gives you the full picture.

## Installation

```r
install.packages("statease")
```

For the development version from GitHub:
```r
# install.packages("devtools")
devtools::install_github("DevWebWacky/statease")
```

## Live App
Try statease directly in your browser without installing R:

🌐 [Launch statease Shiny App](https://devwebwacky.shinyapps.io/statease/)

## Functions

| Function | What it does |
|---|---|
| `analyze()` | Master function - auto-detects and runs the right test |
| `describe()` | Descriptive statistics with interpretation |
| `ttest_interpret()` | T-tests with Cohen's d and CI interpretation |
| `anova_interpret()` | One-way ANOVA with Tukey post-hoc and eta squared |
| `anova2_interpret()` | Two-way ANOVA with Type II/III SS |
| `manova_interpret()` | MANOVA with Pillai's trace and follow-up ANOVAs |
| `chisq_interpret()` | Chi-square test with Cramer's V effect size |
| `fisher_interpret()` | Fisher's Exact Test with Odds Ratio |
| `mcnemar_interpret()` | McNemar's Test for paired categorical data |
| `cor_interpret()` | Correlation analysis (Pearson, Spearman, Kendall) |
| `reg_interpret()` | Simple linear regression with diagnostics |
| `mlr_interpret()` | Multiple linear regression with diagnostics |
| `logistic_interpret()` | Logistic regression with odds ratios |
| `mannwhitney_interpret()` | Mann-Whitney U test (non-parametric) |
| `wilcoxon_interpret()` | Wilcoxon Signed Rank test (non-parametric) |
| `kruskal_interpret()` | Kruskal-Wallis test with post-hoc comparisons |
| `friedman_interpret()` | Friedman Test with Kendall's W |
| `check_assumptions()` | Automated assumption checking before analysis |
| `power_interpret()` | Statistical power analysis and sample size calculation |
| `interpret_p()` | Standalone p-value interpreter |

## Usage

### One command does it all

```r
library(statease)

# Descriptive statistics
analyze(x = c(23, 45, 12, 67, 34), var_name = "Exam Scores")

# Independent samples t-test (auto-detected)
analyze(x = c(23,45,12,67,34), y = c(19,38,22,51,29),
        var_name = "Scores")

# Check assumptions first
analyze(x = c(23,45,12,67,34), y = c(19,38,22,51,29),
        check = TRUE)

# Non-parametric alternative (auto-detected)
analyze(x = c(23,45,12,67,34), y = c(19,38,22,51,29),
        nonparam = TRUE, var_name = "Scores")

# Correlation (auto-detected)
analyze(x = c(23,45,12,67,34), y = c(19,38,22,51,29),
        var1_name = "Exam Score", var2_name = "Study Hours")

# Chi-square (auto-detected)
analyze(
  x = c("Yes","No","Yes","Yes","No"),
  y = c("Male","Female","Male","Female","Male")
)

# One-way ANOVA (auto-detected)
df <- data.frame(
  score = c(23,45,12,67,34,89,56,43,78,90,11,34),
  group = rep(c("A","B","C"), each = 4)
)
analyze(formula = score ~ group, data = df)

# Two-way ANOVA (auto-detected)
df2 <- data.frame(
  score  = c(23,45,12,67,34,89,56,43,78,90,11,34),
  method = rep(c("Online","Traditional"), each = 6),
  gender = rep(c("Male","Female"), times = 6)
)
analyze(formula = score ~ method * gender, data = df2)

# Simple linear regression (auto-detected)
df3 <- data.frame(
  exam_score  = c(23,45,12,67,34,89,56,43,78,90),
  study_hours = c(2,5,1,7,3,9,6,4,8,10)
)
analyze(formula = exam_score ~ study_hours, data = df3)

# Power analysis
analyze(test_type = "ttest.two", effect_size = 0.5)

# Interpret any p-value
interpret_p(0.03, context = "treatment vs control group")
```

## Why statease?

Most R output gives you numbers. statease gives you **numbers + meaning**.
Perfect for:
- Students learning statistics
- Researchers who want fast readable output
- Educators teaching statistical concepts

## Changelog

### v1.3.0
- Added `fisher_interpret()` for Fisher's Exact Test
- Added `mcnemar_interpret()` for McNemar's Test
- Added `friedman_interpret()` for Friedman Test
- Added `check_assumptions()` for automated assumption checking
- Added `power_interpret()` for power analysis and sample size
- Added Shiny app via `run_app()` for point-and-click analysis
- Updated `analyze()` with `check` and `test_type` arguments

### v1.2.1
- Fixed non-parametric interpretation — stochastic superiority
  correctly reported instead of median differences

### v1.2.0
- Added `mlr_interpret()` for multiple linear regression
- Added `logistic_interpret()` for logistic regression
- Added `manova_interpret()` for MANOVA
- Added `mannwhitney_interpret()` for Mann-Whitney U test
- Added `wilcoxon_interpret()` for Wilcoxon Signed Rank test
- Added `kruskal_interpret()` for Kruskal-Wallis test
- Updated `analyze()` with `nonparam` argument

### v1.1.0
- Added `chisq_interpret()` for chi-square tests
- Added `cor_interpret()` for correlation analysis
- Added `reg_interpret()` for simple linear regression
- Added `anova2_interpret()` for two-way ANOVA
- Updated `analyze()` to auto-detect all new tests

### v1.0.0
- Initial CRAN release
- `describe()`, `ttest_interpret()`, `anova_interpret()`,
  `interpret_p()`, `analyze()`

## License
MIT

library(shiny)
library(shinydashboard)
library(shinyjs)
library(DT)
library(statease)

#UI
ui <- dashboardPage(
  skin = "blue",

  # Header
  dashboardHeader(
    title = tags$span(
      tags$img(src = "logo.png", height = "40px"),
      "statease"
    ),
    titleWidth = 250
  ),

  # Sidebar
  dashboardSidebar(
    width = 250,
    sidebarMenu(
      id = "sidebar",
      menuItem("Home",
               tabName = "home",
               icon = icon("house")),
      menuItem("Descriptive Statistics",
               tabName = "describe",
               icon = icon("table")),
      menuItem("T-Tests",
               tabName = "ttest",
               icon = icon("not-equal")),
      menuItem("ANOVA",
               tabName = "anova",
               icon = icon("chart-bar")),
      menuItem("Two-Way ANOVA",
               tabName = "anova2",
               icon = icon("chart-bar")),
      menuItem("MANOVA",
               tabName = "manova",
               icon = icon("layer-group")),
      menuItem("Chi-Square",
               tabName = "chisq",
               icon = icon("table-cells")),
      menuItem("Correlation",
               tabName = "correlation",
               icon = icon("circle-nodes")),
      menuItem("Regression",
               tabName = "regression",
               icon = icon("chart-line")),
      menuItem("Non-Parametric",
               tabName = "nonparam",
               icon = icon("arrows-up-down")),
      menuItem("P-Value Interpreter",
               tabName = "pvalue",
               icon = icon("magnifying-glass")),
      menuItem("Auto Analyze",
               tabName = "analyze",
               icon = icon("wand-magic-sparkles")),
      hr(),
      menuItem("About",
               tabName = "about",
               icon = icon("circle-info"))
    )
  ),

  # Body
  dashboardBody(
    useShinyjs(),
    tags$head(
      tags$style(HTML("
        .skin-blue .main-header .logo {
          background-color: #2C3E7A;
        }
        .skin-blue .main-header .navbar {
          background-color: #2C3E7A;
        }
        .skin-blue .main-sidebar {
          background-color: #1a2550;
        }
        .result-box {
          background-color: #f8f9fa;
          border-left: 4px solid #2C3E7A;
          padding: 15px;
          border-radius: 5px;
          font-family: monospace;
          white-space: pre-wrap;
          font-size: 13px;
        }
        .btn-primary {
          background-color: #2C3E7A;
          border-color: #2C3E7A;
          color: #FFFFFF !important;
        }
        .btn-primary:hover {
          background-color: #4A90D9;
          border-color: #4A90D9;
          color: #FFFFFF !important;
        }
        .btn-primary:focus,
        .btn-primary:active {
          background-color: #2C3E7A;
          border-color: #2C3E7A;
          color: #FFFFFF !important;
        }
      "))
    ),

    tabItems(

      #HOME
      tabItem(
        tabName = "home",
        fluidRow(
          box(
            width = 12,
            status = "primary",
            solidHeader = TRUE,
            title = "Welcome to statease",
            h3("Statistical Analysis Made Simple"),
            p("statease is a free, open-source R package that runs
              statistical tests and automatically interprets results
              in plain English, no coding required"),
            hr(),
            h4("What can statease do?"),
            fluidRow(
              valueBox(
                value = "10+",
                subtitle = "Statistical Tests",
                icon = icon("chart-bar"),
                color = "blue",
                width = 3
              ),
              valueBox(
                value = "100%",
                subtitle = "Free & Open Source",
                icon = icon("unlock"),
                color = "green",
                width = 3
              ),
              valueBox(
                value = "Plain",
                subtitle = "English Interpretation",
                icon = icon("comment"),
                color = "purple",
                width = 3
              ),
              valueBox(
                value = "Auto",
                subtitle = "Test Detection",
                icon = icon("wand-magic-sparkles"),
                color = "yellow",
                width = 3
              )
            ),
            hr(),
            h4("How to use this app:"),
            tags$ol(
              tags$li("Upload your dataset (CSV file) in any analysis tab"),
              tags$li("Select your variables from the dropdown menus"),
              tags$li("Click 'Run Analysis' to get your results"),
              tags$li("Read the English interpretation"),
              tags$li("Download your results report")
            ),
            hr(),
            h4("Quick Links:"),
            tags$a(href = "https://cran.r-project.org/package=statease",
                   target = "_blank",
                   class = "btn btn-primary",
                   "CRAN Package"),
            tags$a(href = "https://devwebwacky.github.io/statease/",
                   target = "_blank",
                   class = "btn btn-primary",
                   style = "margin-left: 10px;",
                   "Documentation"),
            tags$a(href = "https://github.com/DevWebWacky/statease",
                   target = "_blank",
                   class = "btn btn-primary",
                   style = "margin-left: 10px;",
                   "GitHub")
          )
        )
      ),

      # Descriptive Statistics
      tabItem(
        tabName = "describe",
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            fileInput("desc_file", "Upload CSV File",
                      accept = ".csv"),
            uiOutput("desc_var_ui"),
            textInput("desc_varname", "Variable Label",
                      value = "Variable"),
            actionButton("desc_run", "Run Analysis",
                         class = "btn btn-primary btn-block",
                         icon = icon("play"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("desc_result"),
            hr(),
            downloadButton("desc_download", "Download Report")
          )
        ),
        fluidRow(
          box(
            width = 12,
            status = "info",
            solidHeader = TRUE,
            title = "Data Preview",
            DTOutput("desc_preview")
          )
        )
      ),

      #Ttest
      tabItem(
        tabName = "ttest",
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            fileInput("ttest_file", "Upload CSV File",
                      accept = ".csv"),
            selectInput("ttest_type", "Test Type",
                        choices = c(
                          "Independent Samples" = "independent",
                          "One Sample" = "onesample",
                          "Paired Samples" = "paired"
                        )),
            uiOutput("ttest_x_ui"),
            uiOutput("ttest_y_ui"),
            uiOutput("ttest_mu_ui"),
            sliderInput("ttest_conf", "Confidence Level",
                        min = 0.90, max = 0.99,
                        value = 0.95, step = 0.01),
            textInput("ttest_varname", "Variable Label",
                      value = "Variable"),
            actionButton("ttest_run", "Run Analysis",
                         class = "btn btn-primary btn-block",
                         icon = icon("play"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("ttest_result"),
            hr(),
            downloadButton("ttest_download", "Download Report")
          )
        ),
        fluidRow(
          box(
            width = 12,
            status = "info",
            solidHeader = TRUE,
            title = "Data Preview",
            DTOutput("ttest_preview")
          )
        )
      ),

      #One Way ANOVA
      tabItem(
        tabName = "anova",
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            fileInput("anova_file", "Upload CSV File",
                      accept = ".csv"),
            uiOutput("anova_outcome_ui"),
            uiOutput("anova_group_ui"),
            sliderInput("anova_conf", "Confidence Level",
                        min = 0.90, max = 0.99,
                        value = 0.95, step = 0.01),
            actionButton("anova_run", "Run Analysis",
                         class = "btn btn-primary btn-block",
                         icon = icon("play"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("anova_result"),
            hr(),
            downloadButton("anova_download", "Download Report")
          )
        ),
        fluidRow(
          box(
            width = 12,
            status = "info",
            solidHeader = TRUE,
            title = "Data Preview",
            DTOutput("anova_preview")
          )
        )
      ),

      #TWO WAY ANOVA
      tabItem(
        tabName = "anova2",
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            fileInput("anova2_file", "Upload CSV File",
                      accept = ".csv"),
            uiOutput("anova2_outcome_ui"),
            uiOutput("anova2_group1_ui"),
            uiOutput("anova2_group2_ui"),
            selectInput("anova2_type", "SS Type",
                        choices = c("Type II" = "II",
                                    "Type III" = "III")),
            sliderInput("anova2_conf", "Confidence Level",
                        min = 0.90, max = 0.99,
                        value = 0.95, step = 0.01),
            actionButton("anova2_run", "Run Analysis",
                         class = "btn btn-primary btn-block",
                         icon = icon("play"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("anova2_result"),
            hr(),
            downloadButton("anova2_download", "Download Report")
          )
        ),
        fluidRow(
          box(
            width = 12,
            status = "info",
            solidHeader = TRUE,
            title = "Data Preview",
            DTOutput("anova2_preview")
          )
        )
      ),

      #MANOVA
      tabItem(
        tabName = "manova",
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            fileInput("manova_file", "Upload CSV File",
                      accept = ".csv"),
            uiOutput("manova_outcomes_ui"),
            uiOutput("manova_group_ui"),
            sliderInput("manova_conf", "Confidence Level",
                        min = 0.90, max = 0.99,
                        value = 0.95, step = 0.01),
            actionButton("manova_run", "Run Analysis",
                         class = "btn btn-primary btn-block",
                         icon = icon("play"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("manova_result"),
            hr(),
            downloadButton("manova_download", "Download Report")
          )
        ),
        fluidRow(
          box(
            width = 12,
            status = "info",
            solidHeader = TRUE,
            title = "Data Preview",
            DTOutput("manova_preview")
          )
        )
      ),

      #Chi-square
      tabItem(
        tabName = "chisq",
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            fileInput("chisq_file", "Upload CSV File",
                      accept = ".csv"),
            uiOutput("chisq_x_ui"),
            uiOutput("chisq_y_ui"),
            sliderInput("chisq_conf", "Confidence Level",
                        min = 0.90, max = 0.99,
                        value = 0.95, step = 0.01),
            actionButton("chisq_run", "Run Analysis",
                         class = "btn btn-primary btn-block",
                         icon = icon("play"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("chisq_result"),
            hr(),
            downloadButton("chisq_download", "Download Report")
          )
        ),
        fluidRow(
          box(
            width = 12,
            status = "info",
            solidHeader = TRUE,
            title = "Data Preview",
            DTOutput("chisq_preview")
          )
        )
      ),

      #Correlation
      tabItem(
        tabName = "correlation",
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            fileInput("cor_file", "Upload CSV File",
                      accept = ".csv"),
            uiOutput("cor_x_ui"),
            uiOutput("cor_y_ui"),
            selectInput("cor_method", "Correlation Method",
                        choices = c("Pearson"  = "pearson",
                                    "Spearman" = "spearman",
                                    "Kendall"  = "kendall")),
            sliderInput("cor_conf", "Confidence Level",
                        min = 0.90, max = 0.99,
                        value = 0.95, step = 0.01),
            textInput("cor_var1", "Variable 1 Label",
                      value = "Variable 1"),
            textInput("cor_var2", "Variable 2 Label",
                      value = "Variable 2"),
            actionButton("cor_run", "Run Analysis",
                         class = "btn btn-primary btn-block",
                         icon = icon("play"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("cor_result"),
            hr(),
            downloadButton("cor_download", "Download Report")
          )
        ),
        fluidRow(
          box(
            width = 12,
            status = "info",
            solidHeader = TRUE,
            title = "Data Preview",
            DTOutput("cor_preview")
          )
        )
      ),

      #Regression
      tabItem(
        tabName = "regression",
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            fileInput("reg_file", "Upload CSV File",
                      accept = ".csv"),
            selectInput("reg_type", "Regression Type",
                        choices = c(
                          "Simple Linear"   = "simple",
                          "Multiple Linear" = "multiple",
                          "Logistic"        = "logistic"
                        )),
            uiOutput("reg_outcome_ui"),
            uiOutput("reg_predictors_ui"),
            sliderInput("reg_conf", "Confidence Level",
                        min = 0.90, max = 0.99,
                        value = 0.95, step = 0.01),
            actionButton("reg_run", "Run Analysis",
                         class = "btn btn-primary btn-block",
                         icon = icon("play"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("reg_result"),
            hr(),
            downloadButton("reg_download", "Download Report")
          )
        ),
        fluidRow(
          box(
            width = 12,
            status = "info",
            solidHeader = TRUE,
            title = "Data Preview",
            DTOutput("reg_preview")
          )
        )
      ),

      #Non-parametric tests
      tabItem(
        tabName = "nonparam",
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            fileInput("np_file", "Upload CSV File",
                      accept = ".csv"),
            selectInput("np_type", "Test Type",
                        choices = c(
                          "Mann-Whitney U"      = "mannwhitney",
                          "Wilcoxon Signed Rank"= "wilcoxon",
                          "Kruskal-Wallis"      = "kruskal"
                        )),
            uiOutput("np_x_ui"),
            uiOutput("np_y_ui"),
            sliderInput("np_conf", "Confidence Level",
                        min = 0.90, max = 0.99,
                        value = 0.95, step = 0.01),
            textInput("np_varname", "Variable Label",
                      value = "Variable"),
            actionButton("np_run", "Run Analysis",
                         class = "btn btn-primary btn-block",
                         icon = icon("play"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("np_result"),
            hr(),
            downloadButton("np_download", "Download Report")
          )
        ),
        fluidRow(
          box(
            width = 12,
            status = "info",
            solidHeader = TRUE,
            title = "Data Preview",
            DTOutput("np_preview")
          )
        )
      ),

      #Pvalue Interpreter
      tabItem(
        tabName = "pvalue",
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            numericInput("pval_p", "P-Value",
                         value = 0.05,
                         min = 0, max = 1,
                         step = 0.001),
            numericInput("pval_alpha", "Alpha Level",
                         value = 0.05,
                         min = 0.01, max = 0.10,
                         step = 0.01),
            textInput("pval_context", "Context (optional)",
                      placeholder = "e.g. treatment vs control"),
            actionButton("pval_run", "Interpret P-Value",
                         class = "btn btn-primary btn-block",
                         icon = icon("play"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("pval_result"),
            hr(),
            downloadButton("pval_download", "Download Report")
          )
        )
      ),

      #Auto analyze
      tabItem(
        tabName = "analyze",
        fluidRow(
          box(
            width = 12,
            status = "warning",
            solidHeader = TRUE,
            title = "Auto Analyze — Let statease decide the right test!!",
            p("Upload your data and select your variables.
              statease will automatically detect the right
              statistical test based on your data structure!!")
          )
        ),
        fluidRow(
          box(
            width = 4,
            status = "primary",
            solidHeader = TRUE,
            title = "Input",
            fileInput("auto_file", "Upload CSV File",
                      accept = ".csv"),
            uiOutput("auto_x_ui"),
            uiOutput("auto_y_ui"),
            checkboxInput("auto_nonparam",
                          "Use non-parametric test",
                          value = FALSE),
            sliderInput("auto_conf", "Confidence Level",
                        min = 0.90, max = 0.99,
                        value = 0.95, step = 0.01),
            textInput("auto_varname", "Variable Label",
                      value = "Variable"),
            actionButton("auto_run", "Auto Analyze",
                         class = "btn btn-primary btn-block",
                         icon = icon("wand-magic-sparkles"))
          ),
          box(
            width = 8,
            status = "primary",
            solidHeader = TRUE,
            title = "Results",
            verbatimTextOutput("auto_result"),
            hr(),
            downloadButton("auto_download", "Download Report")
          )
        ),
        fluidRow(
          box(
            width = 12,
            status = "info",
            solidHeader = TRUE,
            title = "Data Preview",
            DTOutput("auto_preview")
          )
        )
      ),

      #About
      tabItem(
        tabName = "about",
        fluidRow(
          box(
            width = 12,
            status = "primary",
            solidHeader = TRUE,
            title = "About statease",
            h3("statease — Statistical Analysis Made Simple"),
            p("statease is a free, open-source R package published
              on CRAN that makes statistical analysis accessible to
              everyone by running statistical tests and
              automatically interpreting results in English."),
            hr(),
            h4("Author"),
            p("Uwakmfon Usen Paul"),
            hr(),
            h4("Version"),
            p("1.2.1"),
            hr(),
            h4("Links"),
            tags$a(href = "https://cran.r-project.org/package=statease",
                   target = "_blank", "CRAN"),
            tags$span(" | "),
            tags$a(href = "https://devwebwacky.github.io/statease/",
                   target = "_blank", "Website"),
            tags$span(" | "),
            tags$a(href = "https://github.com/DevWebWacky/statease",
                   target = "_blank", "GitHub"),
            hr(),
            h4("Citation"),
            p("If you use statease in your research please cite:"),
            verbatimTextOutput("citation_text")
          )
        )
      )
    )
  )
)

#Server
server <- function(input, output, session) {

  # Helper: capture print output as text
  capture_output <- function(expr) {
    paste(capture.output(expr), collapse = "\n")
  }

  # Helper: read uploaded CSV
  read_csv_file <- function(file_input) {
    req(file_input)
    read.csv(file_input$datapath, stringsAsFactors = FALSE)
  }

  #Citation
  output$citation_text <- renderText({
    'Usen Paul, U. (2025). statease: Simplified Statistical
Analysis with Plain-English Interpretation.
R package version 1.2.1.
https://cran.r-project.org/package=statease'
  })

  #Descriptive Statistics
  desc_data <- reactive({ read_csv_file(input$desc_file) })

  output$desc_var_ui <- renderUI({
    req(desc_data())
    nums <- names(desc_data())[sapply(desc_data(), is.numeric)]
    selectInput("desc_var", "Select Variable", choices = nums)
  })

  output$desc_preview <- renderDT({
    req(desc_data())
    datatable(desc_data(), options = list(pageLength = 5))
  })

  desc_result_text <- eventReactive(input$desc_run, {
    req(desc_data(), input$desc_var)
    result <- describe(desc_data()[[input$desc_var]],
                       var_name = input$desc_varname)
    capture_output(print(result))
  })

  output$desc_result <- renderText({ desc_result_text() })

  output$desc_download <- downloadHandler(
    filename = "statease_descriptive_report.txt",
    content  = function(file) {
      writeLines(desc_result_text(), file)
    }
  )

  #TTest
  ttest_data <- reactive({ read_csv_file(input$ttest_file) })

  output$ttest_x_ui <- renderUI({
    req(ttest_data())
    nums <- names(ttest_data())[sapply(ttest_data(), is.numeric)]
    selectInput("ttest_x", "Select Variable (x)", choices = nums)
  })

  output$ttest_y_ui <- renderUI({
    req(ttest_data(), input$ttest_type)
    if (input$ttest_type == "onesample") return(NULL)
    nums <- names(ttest_data())[sapply(ttest_data(), is.numeric)]
    selectInput("ttest_y", "Select Variable (y)", choices = nums)
  })

  output$ttest_mu_ui <- renderUI({
    req(input$ttest_type)
    if (input$ttest_type != "onesample") return(NULL)
    numericInput("ttest_mu", "Hypothesised Mean (mu)",
                 value = 0)
  })

  output$ttest_preview <- renderDT({
    req(ttest_data())
    datatable(ttest_data(), options = list(pageLength = 5))
  })

  ttest_result_text <- eventReactive(input$ttest_run, {
    req(ttest_data(), input$ttest_x)
    x <- ttest_data()[[input$ttest_x]]

    result <- if (input$ttest_type == "onesample") {
      ttest_interpret(x, mu = input$ttest_mu,
                      conf.level = input$ttest_conf,
                      var_name = input$ttest_varname)
    } else if (input$ttest_type == "paired") {
      req(input$ttest_y)
      y <- ttest_data()[[input$ttest_y]]
      ttest_interpret(x, y, paired = TRUE,
                      conf.level = input$ttest_conf,
                      var_name = input$ttest_varname)
    } else {
      req(input$ttest_y)
      y <- ttest_data()[[input$ttest_y]]
      ttest_interpret(x, y, paired = FALSE,
                      conf.level = input$ttest_conf,
                      var_name = input$ttest_varname)
    }
    capture_output(print(result))
  })

  output$ttest_result <- renderText({ ttest_result_text() })

  output$ttest_download <- downloadHandler(
    filename = "statease_ttest_report.txt",
    content  = function(file) {
      writeLines(ttest_result_text(), file)
    }
  )

  #OneWayAnova
  anova_data <- reactive({ read_csv_file(input$anova_file) })

  output$anova_outcome_ui <- renderUI({
    req(anova_data())
    nums <- names(anova_data())[sapply(anova_data(), is.numeric)]
    selectInput("anova_outcome", "Select Outcome Variable",
                choices = nums)
  })

  output$anova_group_ui <- renderUI({
    req(anova_data())
    selectInput("anova_group", "Select Group Variable",
                choices = names(anova_data()))
  })

  output$anova_preview <- renderDT({
    req(anova_data())
    datatable(anova_data(), options = list(pageLength = 5))
  })

  anova_result_text <- eventReactive(input$anova_run, {
    req(anova_data(), input$anova_outcome, input$anova_group)
    formula <- as.formula(
      paste(input$anova_outcome, "~", input$anova_group)
    )
    result <- anova_interpret(formula,
                              data = anova_data(),
                              conf.level = input$anova_conf)
    capture_output(print(result))
  })

  output$anova_result <- renderText({ anova_result_text() })

  output$anova_download <- downloadHandler(
    filename = "statease_anova_report.txt",
    content  = function(file) {
      writeLines(anova_result_text(), file)
    }
  )

  #2WayAnova
  anova2_data <- reactive({ read_csv_file(input$anova2_file) })

  output$anova2_outcome_ui <- renderUI({
    req(anova2_data())
    nums <- names(anova2_data())[sapply(anova2_data(), is.numeric)]
    selectInput("anova2_outcome", "Select Outcome Variable",
                choices = nums)
  })

  output$anova2_group1_ui <- renderUI({
    req(anova2_data())
    selectInput("anova2_group1", "Select Factor 1",
                choices = names(anova2_data()))
  })

  output$anova2_group2_ui <- renderUI({
    req(anova2_data())
    selectInput("anova2_group2", "Select Factor 2",
                choices = names(anova2_data()))
  })

  output$anova2_preview <- renderDT({
    req(anova2_data())
    datatable(anova2_data(), options = list(pageLength = 5))
  })

  anova2_result_text <- eventReactive(input$anova2_run, {
    req(anova2_data(), input$anova2_outcome,
        input$anova2_group1, input$anova2_group2)
    formula <- as.formula(paste(
      input$anova2_outcome, "~",
      input$anova2_group1, "*",
      input$anova2_group2
    ))
    result <- anova2_interpret(formula,
                               data = anova2_data(),
                               conf.level = input$anova2_conf,
                               type = input$anova2_type)
    capture_output(print(result))
  })

  output$anova2_result <- renderText({ anova2_result_text() })

  output$anova2_download <- downloadHandler(
    filename = "statease_anova2_report.txt",
    content  = function(file) {
      writeLines(anova2_result_text(), file)
    }
  )

  #Manova
  manova_data <- reactive({ read_csv_file(input$manova_file) })

  output$manova_outcomes_ui <- renderUI({
    req(manova_data())
    nums <- names(manova_data())[sapply(manova_data(), is.numeric)]
    selectInput("manova_outcomes", "Select Outcome Variables
                (select 2 or more)",
                choices = nums, multiple = TRUE)
  })

  output$manova_group_ui <- renderUI({
    req(manova_data())
    selectInput("manova_group", "Select Group Variable",
                choices = names(manova_data()))
  })

  output$manova_preview <- renderDT({
    req(manova_data())
    datatable(manova_data(), options = list(pageLength = 5))
  })

  manova_result_text <- eventReactive(input$manova_run, {
    req(manova_data(), input$manova_outcomes,
        input$manova_group)
    outcomes <- paste(input$manova_outcomes, collapse = ", ")
    formula  <- as.formula(paste(
      "cbind(", outcomes, ") ~", input$manova_group
    ))
    result <- manova_interpret(formula,
                               data = manova_data(),
                               conf.level = input$manova_conf)
    capture_output(print(result))
  })

  output$manova_result <- renderText({ manova_result_text() })

  output$manova_download <- downloadHandler(
    filename = "statease_manova_report.txt",
    content  = function(file) {
      writeLines(manova_result_text(), file)
    }
  )

  #Chi-square
  chisq_data <- reactive({ read_csv_file(input$chisq_file) })

  output$chisq_x_ui <- renderUI({
    req(chisq_data())
    selectInput("chisq_x", "Select Variable 1 (x)",
                choices = names(chisq_data()))
  })

  output$chisq_y_ui <- renderUI({
    req(chisq_data())
    selectInput("chisq_y", "Select Variable 2 (y)",
                choices = names(chisq_data()))
  })

  output$chisq_preview <- renderDT({
    req(chisq_data())
    datatable(chisq_data(), options = list(pageLength = 5))
  })

  chisq_result_text <- eventReactive(input$chisq_run, {
    req(chisq_data(), input$chisq_x, input$chisq_y)
    result <- chisq_interpret(
      chisq_data()[[input$chisq_x]],
      chisq_data()[[input$chisq_y]],
      conf.level = input$chisq_conf
    )
    capture_output(print(result))
  })

  output$chisq_result <- renderText({ chisq_result_text() })

  output$chisq_download <- downloadHandler(
    filename = "statease_chisq_report.txt",
    content  = function(file) {
      writeLines(chisq_result_text(), file)
    }
  )

  #Correlation
  cor_data <- reactive({ read_csv_file(input$cor_file) })

  output$cor_x_ui <- renderUI({
    req(cor_data())
    nums <- names(cor_data())[sapply(cor_data(), is.numeric)]
    selectInput("cor_x", "Select Variable 1 (x)",
                choices = nums)
  })

  output$cor_y_ui <- renderUI({
    req(cor_data())
    nums <- names(cor_data())[sapply(cor_data(), is.numeric)]
    selectInput("cor_y", "Select Variable 2 (y)",
                choices = nums)
  })

  output$cor_preview <- renderDT({
    req(cor_data())
    datatable(cor_data(), options = list(pageLength = 5))
  })

  cor_result_text <- eventReactive(input$cor_run, {
    req(cor_data(), input$cor_x, input$cor_y)
    result <- cor_interpret(
      cor_data()[[input$cor_x]],
      cor_data()[[input$cor_y]],
      method    = input$cor_method,
      conf.level = input$cor_conf,
      var1_name = input$cor_var1,
      var2_name = input$cor_var2
    )
    capture_output(print(result))
  })

  output$cor_result <- renderText({ cor_result_text() })

  output$cor_download <- downloadHandler(
    filename = "statease_correlation_report.txt",
    content  = function(file) {
      writeLines(cor_result_text(), file)
    }
  )

  #Regression
  reg_data <- reactive({ read_csv_file(input$reg_file) })

  output$reg_outcome_ui <- renderUI({
    req(reg_data())
    nums <- names(reg_data())[sapply(reg_data(), is.numeric)]
    selectInput("reg_outcome", "Select Outcome Variable",
                choices = nums)
  })

  output$reg_predictors_ui <- renderUI({
    req(reg_data())
    nums <- names(reg_data())[sapply(reg_data(), is.numeric)]
    if (input$reg_type == "simple") {
      selectInput("reg_predictors", "Select Predictor",
                  choices = nums)
    } else {
      selectInput("reg_predictors", "Select Predictors
                  (select 2 or more)",
                  choices = nums, multiple = TRUE)
    }
  })

  output$reg_preview <- renderDT({
    req(reg_data())
    datatable(reg_data(), options = list(pageLength = 5))
  })

  reg_result_text <- eventReactive(input$reg_run, {
    req(reg_data(), input$reg_outcome, input$reg_predictors)
    predictors <- paste(input$reg_predictors, collapse = " + ")
    formula    <- as.formula(
      paste(input$reg_outcome, "~", predictors)
    )
    result <- if (input$reg_type == "logistic") {
      logistic_interpret(formula,
                         data = reg_data(),
                         conf.level = input$reg_conf)
    } else if (input$reg_type == "multiple") {
      mlr_interpret(formula,
                    data = reg_data(),
                    conf.level = input$reg_conf)
    } else {
      reg_interpret(formula,
                    data = reg_data(),
                    conf.level = input$reg_conf)
    }
    capture_output(print(result))
  })

  output$reg_result <- renderText({ reg_result_text() })

  output$reg_download <- downloadHandler(
    filename = "statease_regression_report.txt",
    content  = function(file) {
      writeLines(reg_result_text(), file)
    }
  )

  #Non-parametric
  np_data <- reactive({ read_csv_file(input$np_file) })

  output$np_x_ui <- renderUI({
    req(np_data())
    nums <- names(np_data())[sapply(np_data(), is.numeric)]
    selectInput("np_x", "Select Variable 1 (x)",
                choices = nums)
  })

  output$np_y_ui <- renderUI({
    req(np_data(), input$np_type)
    if (input$np_type == "kruskal") {
      selectInput("np_y", "Select Group Variable",
                  choices = names(np_data()))
    } else {
      nums <- names(np_data())[sapply(np_data(), is.numeric)]
      selectInput("np_y", "Select Variable 2 (y)",
                  choices = nums)
    }
  })

  output$np_preview <- renderDT({
    req(np_data())
    datatable(np_data(), options = list(pageLength = 5))
  })

  np_result_text <- eventReactive(input$np_run, {
    req(np_data(), input$np_x, input$np_y)

    result <- if (input$np_type == "mannwhitney") {
      mannwhitney_interpret(
        np_data()[[input$np_x]],
        np_data()[[input$np_y]],
        conf.level = input$np_conf,
        var_name   = input$np_varname
      )
    } else if (input$np_type == "wilcoxon") {
      wilcoxon_interpret(
        np_data()[[input$np_x]],
        np_data()[[input$np_y]],
        conf.level = input$np_conf,
        var_name   = input$np_varname
      )
    } else {
      formula <- as.formula(
        paste(input$np_x, "~", input$np_y)
      )
      kruskal_interpret(formula,
                        data = np_data(),
                        conf.level = input$np_conf)
    }
    capture_output(print(result))
  })

  output$np_result <- renderText({ np_result_text() })

  output$np_download <- downloadHandler(
    filename = "statease_nonparam_report.txt",
    content  = function(file) {
      writeLines(np_result_text(), file)
    }
  )

  #PvalueInterpreter
  pval_result_text <- eventReactive(input$pval_run, {
    context <- if (nchar(input$pval_context) > 0) {
      input$pval_context
    } else {
      NULL
    }
    result <- interpret_p(
      p       = input$pval_p,
      alpha   = input$pval_alpha,
      context = context
    )
    capture_output(print(result))
  })

  output$pval_result <- renderText({ pval_result_text() })

  output$pval_download <- downloadHandler(
    filename = "statease_pvalue_report.txt",
    content  = function(file) {
      writeLines(pval_result_text(), file)
    }
  )

  #auto-analyze
  auto_data <- reactive({ read_csv_file(input$auto_file) })

  output$auto_x_ui <- renderUI({
    req(auto_data())
    selectInput("auto_x", "Select Variable (x)",
                choices = names(auto_data()))
  })

  output$auto_y_ui <- renderUI({
    req(auto_data())
    selectInput("auto_y", "Select Variable (y) — optional",
                choices = c("None", names(auto_data())))
  })

  output$auto_preview <- renderDT({
    req(auto_data())
    datatable(auto_data(), options = list(pageLength = 5))
  })

  auto_result_text <- eventReactive(input$auto_run, {
    req(auto_data(), input$auto_x)
    x <- auto_data()[[input$auto_x]]
    y <- if (input$auto_y != "None") {
      auto_data()[[input$auto_y]]
    } else {
      NULL
    }

    result_text <- capture.output({
      if (is.null(y)) {
        analyze(x        = x,
                nonparam = input$auto_nonparam,
                conf.level = input$auto_conf,
                var_name = input$auto_varname)
      } else {
        analyze(x        = x,
                y        = y,
                nonparam = input$auto_nonparam,
                conf.level = input$auto_conf,
                var_name = input$auto_varname)
      }
    })
    paste(result_text, collapse = "\n")
  })

  output$auto_result <- renderText({ auto_result_text() })

  output$auto_download <- downloadHandler(
    filename = "statease_auto_report.txt",
    content  = function(file) {
      writeLines(auto_result_text(), file)
    }
  )
}

#runApp
shinyApp(ui = ui, server = server)

#' Correlation Analysis with Plain-English Interpretation
#'
#' @param x A numeric vector
#' @param y A numeric vector
#' @param method Correlation method: "pearson", "spearman", or "kendall".
#'   Default "pearson".
#' @param conf.level Confidence level. Default 0.95.
#' @param var1_name Optional name for first variable. Default "Variable 1"
#' @param var2_name Optional name for second variable. Default "Variable 2"
#'
#' @return An object of class \code{statease_cor} containing correlation
#'   results and interpretation. Use \code{print()} to display the
#'   formatted report.
#' @export
#'
#' @examples
#' x <- c(23, 45, 12, 67, 34, 89, 56, 43, 78, 90)
#' y <- c(19, 42, 15, 70, 30, 85, 52, 48, 80, 88)
#' result <- cor_interpret(x, y)
#' print(result)
cor_interpret <- function(x, y, method = "pearson", conf.level = 0.95,
                          var1_name = "Variable 1",
                          var2_name = "Variable 2") {

  # --- Guard clauses ---
  if (!is.numeric(x)) stop("x must be a numeric vector.")
  if (!is.numeric(y)) stop("y must be a numeric vector.")
  if (length(x) != length(y)) stop("x and y must have the same length.")
  if (!method %in% c("pearson", "spearman", "kendall")) {
    stop("method must be one of 'pearson', 'spearman', or 'kendall'.")
  }
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }
  if (length(na.omit(x)) < 3) stop("At least 3 non-missing observations are required.")

  alpha   <- 1 - conf.level
  n       <- length(na.omit(x))
  missing <- sum(is.na(x) | is.na(y))

  # --- Small sample warning ---
  if (n < 10) {
    warning("Sample size is small (n < 10). Interpret correlation with caution.")
  }

  # --- Normality check for Pearson ---
  normality_note <- NULL
  if (method == "pearson") {
    sw_x <- shapiro.test(na.omit(x))
    sw_y <- shapiro.test(na.omit(y))
    if (sw_x$p.value < 0.05 || sw_y$p.value < 0.05) {
      normality_note <- paste("WARNING: One or both variables may not be",
                              "normally distributed.",
                              "Consider using method = 'spearman' instead.")
    }
  }

  # --- Run correlation test ---
  result <- cor.test(x, y, method = method, conf.level = conf.level)
  r      <- result$estimate
  p_val  <- result$p.value
  ci     <- result$conf.int

  # --- Effect size label ---
  r_abs   <- abs(r)
  r_label <- if (r_abs < 0.1) {
    "negligible"
  } else if (r_abs < 0.3) {
    "small"
  } else if (r_abs < 0.5) {
    "moderate"
  } else if (r_abs < 0.7) {
    "large"
  } else {
    "very large"
  }

  # --- Direction ---
  direction <- if (r > 0) {
    "positive (as one variable increases, the other tends to increase)"
  } else {
    "negative (as one variable increases, the other tends to decrease)"
  }

  # --- Significance ---
  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)", p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)", p_val, alpha)
  }

  # --- Method label ---
  method_label <- switch(method,
                         "pearson"  = "Pearson Product-Moment Correlation",
                         "spearman" = "Spearman Rank Correlation",
                         "kendall"  = "Kendall Rank Correlation"
  )

  output <- list(
    var1_name      = var1_name,
    var2_name      = var2_name,
    method_label   = method_label,
    method         = method,
    n              = n,
    missing        = missing,
    r              = r,
    r_label        = r_label,
    direction      = direction,
    p_val          = p_val,
    ci             = ci,
    sig_label      = sig_label,
    conf.level     = conf.level,
    normality_note = normality_note,
    alpha          = alpha
  )

  class(output) <- "statease_cor"
  output
}

#' @export
print.statease_cor <- function(x, ...) {
  cat("\n")
  cat("-- statease Correlation Report -----------------------------------\n")
  cat(sprintf("  Method       : %s\n", x$method_label))
  cat(sprintf("  Variables    : %s & %s\n", x$var1_name, x$var2_name))
  cat(sprintf("  N            : %d  |  Missing: %d\n", x$n, x$missing))
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  r            : %.4f\n", x$r))
  cat(sprintf("  p-value      : %.4f\n", x$p_val))
  if (!is.null(x$ci)) {
    cat(sprintf("  %d%% CI      : [%.4f, %.4f]\n",
                as.integer(x$conf.level * 100), x$ci[1], x$ci[2]))
  }
  cat(sprintf("  Strength     : %s\n", x$r_label))
  cat(sprintf("  Direction    : %s\n", x$direction))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The correlation is %s.\n", x$sig_label))
  cat(sprintf("  The relationship between %s and %s is\n",
              x$var1_name, x$var2_name))
  cat(sprintf("  %s and %s in direction.\n", x$r_label, x$direction))
  if (!is.null(x$normality_note)) {
    cat(sprintf("\n  %s\n", x$normality_note))
  }
  if (x$missing > 0) {
    cat(sprintf("  WARNING: %d missing value(s) were excluded.\n", x$missing))
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

test_that("cor_interpret returns correct class", {
  result <- cor_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    c(2,3,4,5,6,7,8,9,10,11)
  )
  expect_s3_class(result, "statease_cor")
})

test_that("cor_interpret returns correct values", {
  result <- cor_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    c(2,3,4,5,6,7,8,9,10,11)
  )
  expect_true(is.numeric(result$r))
  expect_true(result$r >= -1 && result$r <= 1)
  expect_true(is.numeric(result$p_val))
})

test_that("cor_interpret perfect correlation", {
  result <- cor_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    c(1,2,3,4,5,6,7,8,9,10)
  )
  expect_equal(as.numeric(round(result$r, 4)), 1)
})

test_that("cor_interpret errors on unequal lengths", {
  expect_error(cor_interpret(
    c(1,2,3),
    c(1,2)
  ))
})

test_that("cor_interpret errors on invalid method", {
  expect_error(cor_interpret(
    c(1,2,3,4,5),
    c(1,2,3,4,5),
    method = "invalid"
  ))
})

test_that("cor_interpret spearman method works", {
  result <- cor_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    c(2,3,4,5,6,7,8,9,10,11),
    method = "spearman"
  )
  expect_equal(result$method, "spearman")
})

#' T-Test with Plain-English Interpretation
#'
#' @param x A numeric vector (group 1, or the only group for one-sample)
#' @param y A numeric vector (group 2, for independent samples). Default NULL.
#' @param mu Hypothesised mean for one-sample t-test. Default 0.
#' @param paired Logical. TRUE for paired t-test. Default FALSE.
#' @param conf.level Confidence level. Default 0.95.
#' @param var_name Optional label for the report. Default "Variable"
#'
#' @return An object of class \code{statease_ttest} containing test
#'   results and interpretation. Use \code{print()} to display the
#'   formatted report.
#' @export
#'
#' @examples
#' result <- ttest_interpret(c(23,45,12,67,34), c(19,38,22,51,29))
#' print(result)
ttest_interpret <- function(x, y = NULL, mu = 0, paired = FALSE,
                            conf.level = 0.95, var_name = "Variable") {

  if (!is.numeric(x)) stop("x must be a numeric vector.")
  if (!is.null(y) && !is.numeric(y)) stop("y must be a numeric vector.")
  if (conf.level <= 0 || conf.level >= 1) stop("conf.level must be between 0 and 1.")
  if (length(na.omit(x)) < 2) stop("x must have at least 2 non-missing values.")

  x_clean <- na.omit(x)
  if (length(x_clean) < 10) {
    warning("Sample size in x is small (n < 10). Interpret results with caution.")
  }

  normality_note <- NULL
  if (length(x_clean) >= 3 && length(x_clean) <= 5000) {
    sw_x <- shapiro.test(x_clean)
    if (sw_x$p.value < 0.05) {
      normality_note <- "WARNING: Shapiro-Wilk suggests x may not be normally distributed."
    }
  }

  if (!is.null(y)) {
    y_clean <- na.omit(y)
    if (length(y_clean) < 2) stop("y must have at least 2 non-missing values.")
    if (length(y_clean) < 10) {
      warning("Sample size in y is small (n < 10). Interpret results with caution.")
    }
    if (length(y_clean) >= 3 && length(y_clean) <= 5000) {
      sw_y <- shapiro.test(y_clean)
      if (sw_y$p.value < 0.05) {
        normality_note <- paste(normality_note,
                                "WARNING: Shapiro-Wilk suggests y may not be normally distributed.")
      }
    }
  }

  variance_note <- NULL
  if (!is.null(y) && !paired) {
    y_clean   <- na.omit(y)
    var_test  <- var.test(x_clean, y_clean)
    if (var_test$p.value < 0.05) {
      variance_note <- "WARNING: Variances appear unequal. Welch correction applied."
    }
  }

  if (is.null(y)) {
    test_type  <- "One-Sample T-Test"
    result     <- t.test(x, mu = mu, conf.level = conf.level)
    group_info <- sprintf("n = %d  |  Hypothesised mean (mu) = %.2f",
                          length(x_clean), mu)
  } else if (paired) {
    if (length(x_clean) != length(na.omit(y))) {
      stop("For a paired t-test, x and y must have the same number of observations.")
    }
    test_type  <- "Paired Samples T-Test"
    result     <- t.test(x, y, paired = TRUE, conf.level = conf.level)
    group_info <- sprintf("n (pairs) = %d", length(x_clean))
  } else {
    test_type  <- "Independent Samples T-Test"
    result     <- t.test(x, y, paired = FALSE, conf.level = conf.level)
    group_info <- sprintf("Group 1: n = %d  |  Group 2: n = %d",
                          length(x_clean), length(na.omit(y)))
  }

  t_val <- result$statistic
  df    <- result$parameter
  p_val <- result$p.value
  ci    <- result$conf.int
  alpha <- 1 - conf.level

  if (is.null(y)) {
    d <- (mean(x_clean) - mu) / sd(x_clean)
  } else if (paired) {
    diff <- na.omit(x - y)
    d    <- mean(diff) / sd(diff)
  } else {
    pooled_sd <- sqrt((sd(x_clean)^2 + sd(na.omit(y))^2) / 2)
    d         <- (mean(x_clean) - mean(na.omit(y))) / pooled_sd
  }

  d_abs        <- abs(d)
  effect_label <- if (d_abs < 0.2) "negligible" else if
  (d_abs < 0.5) "small" else if
  (d_abs < 0.8) "moderate" else "large"

  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.3f < alpha %.2f)", p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.3f > alpha %.2f)", p_val, alpha)
  }

  if (!is.null(y)) {
    direction <- if (mean(x_clean) > mean(na.omit(y))) {
      sprintf("Group 1 had a higher mean (%.2f vs %.2f).",
              mean(x_clean), mean(na.omit(y)))
    } else {
      sprintf("Group 2 had a higher mean (%.2f vs %.2f).",
              mean(na.omit(y)), mean(x_clean))
    }
  } else {
    direction <- sprintf("Sample mean was %.2f vs hypothesised %.2f.",
                         mean(x_clean), mu)
  }

  output <- list(
    test_type      = test_type,
    var_name       = var_name,
    group_info     = group_info,
    t_val          = t_val,
    df             = df,
    p_val          = p_val,
    ci             = ci,
    conf.level     = conf.level,
    cohens_d       = d,
    effect_label   = effect_label,
    sig_label      = sig_label,
    direction      = direction,
    normality_note = normality_note,
    variance_note  = variance_note
  )

  class(output) <- "statease_ttest"
  output
}

#' @export
print.statease_ttest <- function(x, ...) {
  cat("\n")
  cat("-- statease T-Test Report ----------------------------------------\n")
  cat(sprintf("  Test         : %s\n", x$test_type))
  cat(sprintf("  Variable     : %s\n", x$var_name))
  cat(sprintf("  Groups       : %s\n", x$group_info))
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  t-statistic  : %.3f\n", x$t_val))
  cat(sprintf("  df           : %.1f\n", x$df))
  cat(sprintf("  p-value      : %.4f\n", x$p_val))
  cat(sprintf("  %d%% CI      : [%.3f, %.3f]\n",
              as.integer(x$conf.level * 100), x$ci[1], x$ci[2]))
  cat(sprintf("  Cohen's d    : %.3f (%s effect)\n", x$cohens_d, x$effect_label))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The result is %s.\n", x$sig_label))
  cat(sprintf("  %s\n", x$direction))
  cat(sprintf("  Effect size is %s (d = %.3f).\n", x$effect_label, x$cohens_d))
  cat(sprintf("  %d%% CI: true difference lies between %.3f and %.3f.\n",
              as.integer(x$conf.level * 100), x$ci[1], x$ci[2]))
  if (!is.null(x$normality_note)) cat(sprintf("\n  %s\n", x$normality_note))
  if (!is.null(x$variance_note)) cat(sprintf("  %s\n", x$variance_note))
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

test_that("ttest_interpret returns correct class", {
  result <- ttest_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    c(2,3,4,5,6,7,8,9,10,11)
  )
  expect_s3_class(result, "statease_ttest")
})

test_that("ttest_interpret independent samples works", {
  result <- ttest_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    c(2,3,4,5,6,7,8,9,10,11)
  )
  expect_equal(result$test_type, "Independent Samples T-Test")
  expect_true(is.numeric(result$p_val))
  expect_true(result$p_val >= 0 && result$p_val <= 1)
})

test_that("ttest_interpret one sample works", {
  result <- ttest_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    mu = 3
  )
  expect_equal(result$test_type, "One-Sample T-Test")
})

test_that("ttest_interpret paired works", {
  result <- ttest_interpret(
    c(23,45,12,67,34,89,56,43,78,90),
    c(19,38,22,51,29,74,44,38,65,80),
    paired = TRUE
  )
  expect_equal(result$test_type, "Paired Samples T-Test")
})

test_that("ttest_interpret errors on non-numeric x", {
  expect_error(ttest_interpret("hello"))
})

test_that("ttest_interpret errors on invalid conf.level", {
  expect_error(ttest_interpret(
    c(1,2,3,4,5), conf.level = 1.5
  ))
})

test_that("ttest_interpret Cohen's d is numeric", {
  result <- ttest_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    c(2,3,4,5,6,7,8,9,10,11)
  )
  expect_true(is.numeric(result$cohens_d))
})

#' Standalone P-Value Interpreter
#'
#' @param p A numeric p-value between 0 and 1
#' @param alpha Significance level. Default 0.05
#' @param context Optional string describing the test context
#'
#' @return An object of class \code{statease_pvalue} containing the
#'   p-value interpretation. Use \code{print()} to display the report.
#' @export
#'
#' @examples
#' result <- interpret_p(0.03)
#' print(result)
#'
#' result2 <- interpret_p(0.12, alpha = 0.05, context = "treatment vs control")
#' print(result2)
interpret_p <- function(p, alpha = 0.05, context = NULL) {

  if (!is.numeric(p) || length(p) != 1) stop("p must be a single numeric value.")
  if (p < 0 || p > 1) stop("p-value must be between 0 and 1.")
  if (alpha <= 0 || alpha >= 1) stop("alpha must be between 0 and 1.")

  significant <- p < alpha

  evidence <- if (p < 0.001) {
    "very strong evidence against the null hypothesis"
  } else if (p < 0.01) {
    "strong evidence against the null hypothesis"
  } else if (p < 0.05) {
    "moderate evidence against the null hypothesis"
  } else if (p < 0.10) {
    "weak evidence against the null hypothesis (borderline)"
  } else {
    "little to no evidence against the null hypothesis"
  }

  decision <- if (significant) {
    sprintf("REJECT the null hypothesis at alpha = %.2f", alpha)
  } else {
    sprintf("FAIL TO REJECT the null hypothesis at alpha = %.2f", alpha)
  }

  verdict <- if (significant) {
    paste("The result is statistically significant. The observed data is",
          "unlikely to have occurred by chance if the null hypothesis were true.")
  } else {
    paste("The result is not statistically significant. The observed data",
          "does not provide sufficient evidence to reject the null hypothesis.")
  }

  reminder <- if (significant) {
    paste("Note: Statistical significance does not imply practical importance.",
          "Always consider effect size alongside the p-value.")
  } else {
    paste("Note: A non-significant result does not prove the null hypothesis.",
          "It may reflect insufficient power or a small sample size.")
  }

  output <- list(
    p           = p,
    alpha       = alpha,
    context     = context,
    significant = significant,
    evidence    = evidence,
    decision    = decision,
    verdict     = verdict,
    reminder    = reminder
  )

  class(output) <- "statease_pvalue"
  output
}

#' @export
print.statease_pvalue <- function(x, ...) {
  cat("\n")
  cat("-- statease P-Value Interpretation ------------------------------\n")
  if (!is.null(x$context)) {
    cat(sprintf("  Context      : %s\n", x$context))
  }
  cat(sprintf("  P-value      : %.4f\n", x$p))
  cat(sprintf("  Alpha        : %.2f\n", x$alpha))
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  Decision     : %s\n", x$decision))
  cat(sprintf("  Evidence     : There is %s.\n", x$evidence))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  %s\n", x$verdict))
  cat("\n")
  cat(sprintf("  %s\n", x$reminder))
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

test_that("interpret_p returns correct class", {
  result <- interpret_p(0.03)
  expect_s3_class(result, "statease_pvalue")
})

test_that("interpret_p significant result", {
  result <- interpret_p(0.03)
  expect_true(result$significant)
})

test_that("interpret_p non-significant result", {
  result <- interpret_p(0.07)
  expect_false(result$significant)
})

test_that("interpret_p very strong evidence", {
  result <- interpret_p(0.0001)
  expect_equal(result$evidence,
               "very strong evidence against the null hypothesis")
})

test_that("interpret_p errors on invalid p-value", {
  expect_error(interpret_p(1.5))
  expect_error(interpret_p(-0.1))
})

test_that("interpret_p errors on invalid alpha", {
  expect_error(interpret_p(0.03, alpha = 1.5))
})

test_that("interpret_p context is stored", {
  result <- interpret_p(0.03, context = "test context")
  expect_equal(result$context, "test context")
})

#' Descriptive Statistics with Interpretation
#'
#' @param x A numeric vector
#' @param var_name Optional name for the variable (used in the report)
#'
#' @return An object of class \code{statease_describe} containing
#'   descriptive statistics and interpretation. Use \code{print()} to
#'   display the formatted report.
#' @export
#'
#' @examples
#' result <- describe(c(23, 45, 12, 67, 34, 89, 56))
#' print(result)
describe <- function(x, var_name = "Variable") {

  if (!is.numeric(x)) stop("Input must be a numeric vector.")
  if (length(x) < 2) stop("At least 2 observations are required.")
  if (all(is.na(x))) stop("All values are missing. Please check your data.")

  x_clean <- na.omit(x)
  if (length(x_clean) < 2) stop("At least 2 non-missing observations are required.")
  if (length(x_clean) < 10) {
    warning("Sample size is small (n < 10). Interpret descriptive statistics with caution.")
  }

  n       <- length(x)
  missing <- sum(is.na(x))
  mn      <- mean(x_clean)
  med     <- median(x_clean)
  sd_val  <- sd(x_clean)
  min_val <- min(x_clean)
  max_val <- max(x_clean)
  q1      <- quantile(x_clean, 0.25)
  q3      <- quantile(x_clean, 0.75)
  iqr_val <- IQR(x_clean)
  skew    <- (3 * (mn - med)) / sd_val
  cv      <- (sd_val / mn) * 100

  skew_label <- if (abs(skew) < 0.5) {
    "approximately symmetric"
  } else if (skew > 0.5) {
    "positively skewed (tail to the right)"
  } else {
    "negatively skewed (tail to the left)"
  }

  spread_label <- if (cv < 15) {
    "low variability"
  } else if (cv < 35) {
    "moderate variability"
  } else {
    "high variability"
  }

  normality_note <- NULL
  if (length(x_clean) >= 3 && length(x_clean) <= 5000) {
    sw <- shapiro.test(x_clean)
    normality_note <- if (sw$p.value < 0.05) {
      sprintf("Shapiro-Wilk test suggests non-normality (W = %.3f, p = %.4f).",
              sw$statistic, sw$p.value)
    } else {
      sprintf("Shapiro-Wilk test suggests normality is reasonable (W = %.3f, p = %.4f).",
              sw$statistic, sw$p.value)
    }
  }

  result <- list(
    var_name       = var_name,
    n              = n,
    missing        = missing,
    mean           = mn,
    median         = med,
    sd             = sd_val,
    min            = min_val,
    max            = max_val,
    q1             = q1,
    q3             = q3,
    iqr            = iqr_val,
    skew           = skew,
    skew_label     = skew_label,
    cv             = cv,
    spread_label   = spread_label,
    normality_note = normality_note
  )

  class(result) <- "statease_describe"
  result
}

#' @export
print.statease_describe <- function(x, ...) {
  cat("\n")
  cat("-- statease Descriptive Report ----------------------------------\n")
  cat(sprintf("  Variable     : %s\n", x$var_name))
  cat(sprintf("  N            : %d  |  Missing: %d\n", x$n, x$missing))
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  Mean         : %.2f\n", x$mean))
  cat(sprintf("  Median       : %.2f\n", x$median))
  cat(sprintf("  Std Dev      : %.2f\n", x$sd))
  cat(sprintf("  Min          : %.2f  |  Max: %.2f\n", x$min, x$max))
  cat(sprintf("  Q1           : %.2f  |  Q3: %.2f\n", x$q1, x$q3))
  cat(sprintf("  IQR          : %.2f\n", x$iqr))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The distribution is %s.\n", x$skew_label))
  cat(sprintf("  Spread shows %s (CV = %.1f%%).\n", x$spread_label, x$cv))
  if (!is.null(x$normality_note)) {
    cat(sprintf("  %s\n", x$normality_note))
  }
  if (x$missing > 0) {
    cat(sprintf("  WARNING: %d missing value(s) were excluded.\n", x$missing))
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

test_that("describe returns correct class", {
  result <- describe(c(1, 2, 3, 4, 5))
  expect_s3_class(result, "statease_describe")
})

test_that("describe returns correct values", {
  result <- describe(c(1, 2, 3, 4, 5))
  expect_equal(result$mean, 3)
  expect_equal(result$n, 5)
  expect_equal(result$missing, 0)
  expect_equal(result$min, 1)
  expect_equal(result$max, 5)
})

test_that("describe handles missing values", {
  result <- describe(c(1, 2, NA, 4, 5))
  expect_equal(result$missing, 1)
  expect_equal(result$n, 5)
})

test_that("describe errors on non-numeric input", {
  expect_error(describe("hello"))
})

test_that("describe errors on single value", {
  expect_error(describe(1))
})

test_that("describe errors on all missing values", {
  expect_error(describe(c(NA, NA, NA)))
})

test_that("describe var_name is stored correctly", {
  result <- describe(c(1, 2, 3, 4, 5),
                     var_name = "Test Variable")
  expect_equal(result$var_name, "Test Variable")
})

#' Simple Linear Regression with Plain-English Interpretation
#'
#' @param formula A formula of the form outcome ~ predictor
#' @param data A data frame containing the variables
#' @param conf.level Confidence level. Default 0.95.
#'
#' @return An object of class \code{statease_reg} containing regression
#'   results and interpretation. Use \code{print()} to display the
#'   formatted report.
#' @export
#'
#' @examples
#' df <- data.frame(
#'   exam_score = c(23,45,12,67,34,89,56,43,78,90),
#'   study_hours = c(2,5,1,7,3,9,6,4,8,10)
#' )
#' result <- reg_interpret(exam_score ~ study_hours, data = df)
#' print(result)
reg_interpret <- function(formula, data, conf.level = 0.95) {

  # --- Guard clauses ---
  if (!inherits(formula, "formula")) {
    stop("Please provide a valid formula e.g. outcome ~ predictor")
  }
  if (!is.data.frame(data)) stop("data must be a data frame.")
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }

  alpha <- 1 - conf.level

  # --- Extract variable names ---
  vars      <- all.vars(formula)
  outcome   <- vars[1]
  predictor <- vars[2]

  # --- Check variables exist ---
  if (!outcome %in% names(data)) {
    stop(sprintf("Outcome variable '%s' not found in data.", outcome))
  }
  if (!predictor %in% names(data)) {
    stop(sprintf("Predictor variable '%s' not found in data.", predictor))
  }

  # --- Check variables are numeric ---
  if (!is.numeric(data[[outcome]])) {
    stop(sprintf("Outcome variable '%s' must be numeric.", outcome))
  }
  if (!is.numeric(data[[predictor]])) {
    stop(sprintf("Predictor variable '%s' must be numeric.", predictor))
  }

  # --- Sample size check ---
  n <- nrow(na.omit(data[, c(outcome, predictor)]))
  if (n < 3) stop("At least 3 complete observations are required.")
  if (n < 10) {
    warning("Sample size is small (n < 10). Interpret results with caution.")
  }

  # --- Run regression ---
  model     <- lm(formula, data = data)
  model_sum <- summary(model)
  coefs     <- coef(model_sum)
  ci        <- confint(model, level = conf.level)

  # --- Extract values ---
  intercept     <- coefs[1, 1]
  slope         <- coefs[2, 1]
  slope_se      <- coefs[2, 2]
  slope_t       <- coefs[2, 3]
  slope_p       <- coefs[2, 4]
  r_squared     <- model_sum$r.squared
  adj_r_squared <- model_sum$adj.r.squared
  f_val         <- model_sum$fstatistic[1]
  f_df1         <- model_sum$fstatistic[2]
  f_df2         <- model_sum$fstatistic[3]
  f_p           <- pf(f_val, f_df1, f_df2, lower.tail = FALSE)

  # --- R-squared interpretation ---
  r_sq_label <- if (r_squared < 0.01) {
    "negligible"
  } else if (r_squared < 0.09) {
    "small"
  } else if (r_squared < 0.25) {
    "moderate"
  } else {
    "large"
  }

  # --- Slope direction ---
  slope_direction <- if (slope > 0) {
    sprintf("positive - as %s increases by 1 unit, %s increases by %.3f units",
            predictor, outcome, slope)
  } else {
    sprintf("negative - as %s increases by 1 unit, %s decreases by %.3f units",
            predictor, outcome, abs(slope))
  }

  # --- Significance ---
  sig_label <- if (slope_p < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)", slope_p, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)", slope_p, alpha)
  }

  # --- Residual diagnostics ---
  residuals     <- residuals(model)
  fitted_values <- fitted(model)

  normality_note <- NULL
  if (length(residuals) >= 3 && length(residuals) <= 5000) {
    sw <- shapiro.test(residuals)
    if (sw$p.value < 0.05) {
      normality_note <- sprintf(
        "WARNING: Residuals may not be normally distributed (Shapiro-Wilk p = %.4f).",
        sw$p.value)
    }
  }

  output <- list(
    outcome        = outcome,
    predictor      = predictor,
    n              = n,
    intercept      = intercept,
    slope          = slope,
    slope_se       = slope_se,
    slope_t        = slope_t,
    slope_p        = slope_p,
    ci             = ci,
    r_squared      = r_squared,
    adj_r_squared  = adj_r_squared,
    r_sq_label     = r_sq_label,
    f_val          = f_val,
    f_df1          = f_df1,
    f_df2          = f_df2,
    f_p            = f_p,
    slope_direction = slope_direction,
    sig_label      = sig_label,
    normality_note = normality_note,
    conf.level     = conf.level,
    alpha          = alpha
  )

  class(output) <- "statease_reg"
  output
}

#' @export
print.statease_reg <- function(x, ...) {
  cat("\n")
  cat("-- statease Simple Linear Regression Report ---------------------\n")
  cat(sprintf("  Outcome      : %s\n", x$outcome))
  cat(sprintf("  Predictor    : %s\n", x$predictor))
  cat(sprintf("  N            : %d\n", x$n))
  cat("-----------------------------------------------------------------\n")
  cat("  Model Equation:\n")
  cat(sprintf("  %s = %.3f + %.3f * %s\n",
              x$outcome, x$intercept, x$slope, x$predictor))
  cat("-----------------------------------------------------------------\n")
  cat("  Coefficients:\n")
  cat(sprintf("  Intercept    : %.3f\n", x$intercept))
  cat(sprintf("  Slope        : %.3f  (SE = %.3f)\n", x$slope, x$slope_se))
  cat(sprintf("  t-statistic  : %.3f\n", x$slope_t))
  cat(sprintf("  p-value      : %.4f\n", x$slope_p))
  cat(sprintf("  %d%% CI      : [%.3f, %.3f]\n",
              as.integer(x$conf.level * 100),
              x$ci[2, 1], x$ci[2, 2]))
  cat("-----------------------------------------------------------------\n")
  cat("  Model Fit:\n")
  cat(sprintf("  R-squared    : %.4f\n", x$r_squared))
  cat(sprintf("  Adj R-squared: %.4f\n", x$adj_r_squared))
  cat(sprintf("  F-statistic  : %.3f (df = %.0f, %.0f)  p = %.4f\n",
              x$f_val, x$f_df1, x$f_df2, x$f_p))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The predictor %s is %s.\n", x$predictor, x$sig_label))
  cat(sprintf("  The slope is %s.\n", x$slope_direction))
  cat(sprintf("  R-squared = %.4f: %s explains %.1f%% of the\n",
              x$r_squared, x$predictor, x$r_squared * 100))
  cat(sprintf("  variance in %s (%s effect).\n", x$outcome, x$r_sq_label))
  if (!is.null(x$normality_note)) {
    cat(sprintf("\n  %s\n", x$normality_note))
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

test_that("reg_interpret returns correct class", {
  df <- data.frame(
    y = c(1,2,3,4,5,6,7,8,9,10),
    x = c(2,3,4,5,6,7,8,9,10,11)
  )
  result <- reg_interpret(y ~ x, data = df)
  expect_s3_class(result, "statease_reg")
})

test_that("reg_interpret returns correct values", {
  df <- data.frame(
    y = c(1,2,3,4,5,6,7,8,9,10),
    x = c(1,2,3,4,5,6,7,8,9,10)
  )
  result <- reg_interpret(y ~ x, data = df)
  expect_true(is.numeric(result$r_squared))
  expect_true(result$r_squared >= 0 && result$r_squared <= 1)
  expect_true(is.numeric(result$slope))
  expect_true(is.numeric(result$intercept))
})

test_that("reg_interpret perfect fit", {
  df <- data.frame(
    y = c(1,2,3,4,5,6,7,8,9,10),
    x = c(1,2,3,4,5,6,7,8,9,10)
  )
  result <- reg_interpret(y ~ x, data = df)
  expect_equal(round(result$r_squared, 4), 1)
})

test_that("reg_interpret errors on missing variable", {
  df <- data.frame(
    y = c(1,2,3,4,5),
    x = c(1,2,3,4,5)
  )
  expect_error(reg_interpret(y ~ z, data = df))
})

test_that("reg_interpret errors on non-numeric outcome", {
  df <- data.frame(
    y = c("a","b","c","d","e"),
    x = c(1,2,3,4,5)
  )
  expect_error(reg_interpret(y ~ x, data = df))
})

#' Chi-Square Test with Plain-English Interpretation
#'
#' @param x A factor or character vector (first categorical variable)
#' @param y A factor or character vector (second categorical variable)
#' @param correct Logical. Apply Yates continuity correction. Default TRUE.
#' @param conf.level Confidence level. Default 0.95.
#'
#' @return An object of class \code{statease_chisq} containing test
#'   results and interpretation. Use \code{print()} to display the
#'   formatted report.
#' @export
#'
#' @examples
#' x <- c("Yes","No","Yes","Yes","No","Yes","No","No","Yes","Yes")
#' y <- c("Male","Female","Male","Female","Male","Female","Male","Female","Male","Female")
#' result <- chisq_interpret(x, y)
#' print(result)
chisq_interpret <- function(x, y, correct = TRUE, conf.level = 0.95) {

  # --- Guard clauses ---
  if (!is.vector(x) && !is.factor(x)) stop("x must be a vector or factor.")
  if (!is.vector(y) && !is.factor(y)) stop("y must be a vector or factor.")
  if (length(x) != length(y)) stop("x and y must have the same length.")
  if (conf.level <= 0 || conf.level >= 1) stop("conf.level must be between 0 and 1.")

  alpha <- 1 - conf.level

  # --- Convert to factor ---
  x <- as.factor(x)
  y <- as.factor(y)

  # --- Contingency table ---
  cont_table <- table(x, y)

  # --- Check expected frequencies ---
  expected   <- chisq.test(cont_table, correct = correct)$expected
  low_exp    <- any(expected < 5)
  low_exp_note <- if (low_exp) {
    "WARNING: Some expected frequencies are less than 5. Interpret with caution."
  } else NULL

  # --- Run chi-square test ---
  result  <- chisq.test(cont_table, correct = correct)
  chi_val <- result$statistic
  df      <- result$parameter
  p_val   <- result$p.value

  # --- Cramers V (effect size) ---
  n         <- sum(cont_table)
  min_dim   <- min(nrow(cont_table), ncol(cont_table)) - 1
  cramers_v <- sqrt(chi_val / (n * min_dim))

  v_label <- if (cramers_v < 0.1) {
    "negligible"
  } else if (cramers_v < 0.3) {
    "small"
  } else if (cramers_v < 0.5) {
    "moderate"
  } else {
    "large"
  }

  # --- Significance ---
  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)", p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)", p_val, alpha)
  }

  # --- Association direction ---
  assoc_label <- if (p_val < alpha) {
    "There is a significant association between the two variables."
  } else {
    "There is no significant association between the two variables."
  }

  output <- list(
    cont_table   = cont_table,
    expected     = expected,
    chi_val      = chi_val,
    df           = df,
    p_val        = p_val,
    cramers_v    = cramers_v,
    v_label      = v_label,
    sig_label    = sig_label,
    assoc_label  = assoc_label,
    low_exp_note = low_exp_note,
    alpha        = alpha,
    conf.level   = conf.level,
    n            = n
  )

  class(output) <- "statease_chisq"
  output
}

#' @export
print.statease_chisq <- function(x, ...) {
  cat("\n")
  cat("-- statease Chi-Square Test Report ------------------------------\n")
  cat(sprintf("  N            : %d\n", x$n))
  cat("-----------------------------------------------------------------\n")
  cat("  Contingency Table (Observed):\n")
  print(x$cont_table)
  cat("\n")
  cat("  Expected Frequencies:\n")
  print(round(x$expected, 2))
  cat("\n")
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  Chi-square   : %.3f\n", x$chi_val))
  cat(sprintf("  df           : %d\n", x$df))
  cat(sprintf("  p-value      : %.4f\n", x$p_val))
  cat(sprintf("  Cramer's V   : %.3f (%s effect)\n", x$cramers_v, x$v_label))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The result is %s.\n", x$sig_label))
  cat(sprintf("  %s\n", x$assoc_label))
  cat(sprintf("  Effect size is %s (V = %.3f).\n", x$v_label, x$cramers_v))
  if (!is.null(x$low_exp_note)) {
    cat(sprintf("\n  %s\n", x$low_exp_note))
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

test_that("chisq_interpret returns correct class", {
  x <- c("Yes","No","Yes","Yes","No","Yes","No","No","Yes","Yes")
  y <- c("Male","Female","Male","Female","Male",
         "Female","Male","Female","Male","Female")
  result <- chisq_interpret(x, y)
  expect_s3_class(result, "statease_chisq")
})

test_that("chisq_interpret returns correct values", {
  x <- c("Yes","No","Yes","Yes","No","Yes","No","No","Yes","Yes")
  y <- c("Male","Female","Male","Female","Male",
         "Female","Male","Female","Male","Female")
  result <- chisq_interpret(x, y)
  expect_true(is.numeric(result$chi_val))
  expect_true(is.numeric(result$p_val))
  expect_true(result$p_val >= 0 && result$p_val <= 1)
  expect_true(is.numeric(result$cramers_v))
})

test_that("chisq_interpret errors on unequal lengths", {
  expect_error(chisq_interpret(
    c("Yes","No","Yes"),
    c("Male","Female")
  ))
})

test_that("chisq_interpret errors on invalid conf.level", {
  x <- c("Yes","No","Yes","Yes","No")
  y <- c("Male","Female","Male","Female","Male")
  expect_error(chisq_interpret(x, y, conf.level = 2))
})

#' One-Way ANOVA with Post-Hoc Tukey and Plain-English Interpretation
#'
#' @param formula A formula of the form outcome ~ group
#' @param data A data frame containing the variables
#' @param conf.level Confidence level. Default 0.95
#'
#' @return An object of class \code{statease_anova} containing ANOVA
#'   results, effect size, and post-hoc comparisons. Use \code{print()}
#'   to display the formatted report.
#' @export
#'
#' @examples
#' df <- data.frame(
#'   score = c(23,45,12,67,34,89,56,43,78,90,11,34),
#'   group = rep(c("A","B","C"), each = 4)
#' )
#' result <- anova_interpret(score ~ group, data = df)
#' print(result)
anova_interpret <- function(formula, data, conf.level = 0.95) {

  if (!inherits(formula, "formula")) {
    stop("Please provide a valid formula e.g. score ~ group")
  }
  if (!is.data.frame(data)) stop("data must be a data frame.")
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }

  alpha     <- 1 - conf.level
  vars      <- all.vars(formula)
  outcome   <- vars[1]
  group_var <- vars[2]

  if (!outcome %in% names(data)) {
    stop(sprintf("Outcome variable '%s' not found in data.", outcome))
  }
  if (!group_var %in% names(data)) {
    stop(sprintf("Group variable '%s' not found in data.", group_var))
  }
  if (!is.numeric(data[[outcome]])) {
    stop(sprintf("Outcome variable '%s' must be numeric.", outcome))
  }

  data[[group_var]] <- as.factor(data[[group_var]])
  groups            <- levels(data[[group_var]])
  n_groups          <- length(groups)

  if (n_groups < 2) stop("Group variable must have at least 2 levels.")
  if (n_groups < 3) {
    warning("Only 2 groups detected. Consider using ttest_interpret() instead.")
  }

  group_ns <- tapply(data[[outcome]], data[[group_var]],
                     function(x) sum(!is.na(x)))
  if (any(group_ns < 2)) {
    stop("Each group must have at least 2 non-missing observations.")
  }
  if (any(group_ns < 10)) {
    warning("One or more groups have small sample sizes (n < 10). Interpret with caution.")
  }

  normality_notes <- c()
  for (g in groups) {
    grp_data <- na.omit(data[[outcome]][data[[group_var]] == g])
    if (length(grp_data) >= 3 && length(grp_data) <= 5000) {
      sw <- shapiro.test(grp_data)
      if (sw$p.value < 0.05) {
        normality_notes <- c(normality_notes,
                             sprintf("WARNING: Group '%s' may not be normally distributed (p = %.4f).",
                                     g, sw$p.value))
      }
    }
  }

  variance_note <- NULL
  bart <- tryCatch(
    bartlett.test(formula, data = data),
    error = function(e) NULL
  )
  if (!is.null(bart) && bart$p.value < 0.05) {
    variance_note <- sprintf(
      "WARNING: Bartlett's test suggests unequal variances (p = %.4f).",
      bart$p.value)
  }

  aov_model   <- aov(formula, data = data)
  aov_sum     <- summary(aov_model)[[1]]
  f_val       <- aov_sum[["F value"]][1]
  p_val       <- aov_sum[["Pr(>F)"]][1]
  df1         <- aov_sum[["Df"]][1]
  df2         <- aov_sum[["Df"]][2]
  group_means <- tapply(data[[outcome]], data[[group_var]], mean, na.rm = TRUE)
  ss_between  <- aov_sum[["Sum Sq"]][1]
  ss_total    <- sum(aov_sum[["Sum Sq"]])
  eta_sq      <- ss_between / ss_total

  eta_label <- if (eta_sq < 0.01) "negligible" else if
  (eta_sq < 0.06) "small" else if
  (eta_sq < 0.14) "moderate" else "large"

  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)", p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)", p_val, alpha)
  }

  tukey_df <- NULL
  if (p_val < alpha) {
    tukey    <- TukeyHSD(aov_model, conf.level = conf.level)
    tukey_df <- as.data.frame(tukey[[group_var]])
    tukey_df$comparison <- rownames(tukey_df)
  }

  output <- list(
    outcome         = outcome,
    group_var       = group_var,
    n_groups        = n_groups,
    groups          = groups,
    group_means     = group_means,
    group_ns        = group_ns,
    f_val           = f_val,
    df1             = df1,
    df2             = df2,
    p_val           = p_val,
    eta_sq          = eta_sq,
    eta_label       = eta_label,
    sig_label       = sig_label,
    alpha           = alpha,
    conf.level      = conf.level,
    tukey_df        = tukey_df,
    normality_notes = normality_notes,
    variance_note   = variance_note
  )

  class(output) <- "statease_anova"
  output
}

#' @export
print.statease_anova <- function(x, ...) {
  cat("\n")
  cat("-- statease ANOVA Report -----------------------------------------\n")
  cat(sprintf("  Outcome      : %s\n", x$outcome))
  cat(sprintf("  Group        : %s  (%d levels)\n", x$group_var, x$n_groups))
  cat("-----------------------------------------------------------------\n")
  cat("  Group Means:\n")
  for (g in x$groups) {
    cat(sprintf("    %-12s : Mean = %.2f  (n = %d)\n",
                g, x$group_means[g], x$group_ns[g]))
  }
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  F-statistic  : %.3f\n", x$f_val))
  cat(sprintf("  df           : %d, %d\n", x$df1, x$df2))
  cat(sprintf("  p-value      : %.4f\n", x$p_val))
  cat(sprintf("  Eta squared  : %.4f (%s effect)\n", x$eta_sq, x$eta_label))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The overall ANOVA result is %s.\n", x$sig_label))
  cat(sprintf("  Group differences explain %.1f%% of variance\n", x$eta_sq * 100))
  cat(sprintf("  (eta^2 = %.4f, %s effect).\n", x$eta_sq, x$eta_label))

  if (length(x$normality_notes) > 0) {
    cat("\n")
    for (note in x$normality_notes) cat(sprintf("  %s\n", note))
  }
  if (!is.null(x$variance_note)) cat(sprintf("  %s\n", x$variance_note))

  if (!is.null(x$tukey_df)) {
    cat("\n")
    cat("-- Post-Hoc Tukey HSD --------------------------------------------\n")
    for (i in seq_len(nrow(x$tukey_df))) {
      comp    <- x$tukey_df$comparison[i]
      diff    <- x$tukey_df$diff[i]
      p_tukey <- x$tukey_df$`p adj`[i]
      sig     <- if (p_tukey < x$alpha) "[significant]" else "[not significant]"
      cat(sprintf("  %s\n", comp))
      cat(sprintf("    Mean diff = %.3f  |  p adj = %.4f  |  %s\n",
                  diff, p_tukey, sig))
    }
    cat("-----------------------------------------------------------------\n")
    cat("  Note: Tukey HSD controls for family-wise error rate.\n")
  } else {
    cat("\n  Post-hoc tests not run (overall result not significant).\n")
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

test_that("anova_interpret returns correct class", {
  df <- data.frame(
    score = c(23,45,12,67,34,89,56,43,78,90,11,34),
    group = rep(c("A","B","C"), each = 4)
  )
  result <- anova_interpret(score ~ group, data = df)
  expect_s3_class(result, "statease_anova")
})

test_that("anova_interpret returns correct values", {
  df <- data.frame(
    score = c(23,45,12,67,34,89,56,43,78,90,11,34),
    group = rep(c("A","B","C"), each = 4)
  )
  result <- anova_interpret(score ~ group, data = df)
  expect_true(is.numeric(result$f_val))
  expect_true(is.numeric(result$p_val))
  expect_true(result$p_val >= 0 && result$p_val <= 1)
  expect_true(is.numeric(result$eta_sq))
})

test_that("anova_interpret errors on missing variable", {
  df <- data.frame(
    score = c(23,45,12,67,34,89,56,43,78,90,11,34),
    group = rep(c("A","B","C"), each = 4)
  )
  expect_error(anova_interpret(marks ~ group, data = df))
})

test_that("anova_interpret errors on non-numeric outcome", {
  df <- data.frame(
    score = rep(c("a","b","c","d"), times = 3),
    group = rep(c("A","B","C"), each = 4)
  )
  expect_error(anova_interpret(score ~ group, data = df))
})

test_that("anova_interpret errors on single group", {
  df <- data.frame(
    score = c(23,45,12,67,34,89),
    group = rep("A", 6)
  )
  expect_error(anova_interpret(score ~ group, data = df))
})

#' McNemar's Test with Plain-English Interpretation
#'
#' @param x A factor or character vector (first measurement)
#' @param y A factor or character vector (second measurement)
#' @param conf.level Confidence level. Default 0.95.
#'
#' @return An object of class \code{statease_mcnemar} containing test
#'   results and interpretation. Use \code{print()} to display the
#'   formatted report.
#' @export
#'
#' @examples
#' x <- c("Yes","No","Yes","Yes","No","Yes","No","No","Yes","Yes")
#' y <- c("No","No","Yes","Yes","No","Yes","Yes","No","Yes","No")
#' result <- mcnemar_interpret(x, y)
#' print(result)
mcnemar_interpret <- function(x, y, conf.level = 0.95) {

  #Guard clauses
  if (!is.vector(x) && !is.factor(x)) {
    stop("x must be a vector or factor.")
  }
  if (!is.vector(y) && !is.factor(y)) {
    stop("y must be a vector or factor.")
  }
  if (length(x) != length(y)) {
    stop("x and y must have the same length.")
  }
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }

  alpha <- 1 - conf.level

  #Convert to factor with same levels
  all_levels <- union(levels(as.factor(x)), levels(as.factor(y)))
  x <- factor(x, levels = all_levels)
  y <- factor(y, levels = all_levels)

  #Contingency table
  cont_table <- table(x, y)
  n          <- sum(cont_table)
  n_rows     <- nrow(cont_table)
  n_cols     <- ncol(cont_table)

  #Check for 2x2 table
  if (n_rows != 2 || n_cols != 2) {
    warning(paste("McNemar's Test is designed for 2x2 tables.",
                  "For larger tables consider using the",
                  "Stuart-Maxwell test instead."))
  }

  #Discordant pairs
  if (n_rows == 2 && n_cols == 2) {
    b <- cont_table[1, 2]  # x=1, y=2
    c <- cont_table[2, 1]  # x=2, y=1
    discordant <- b + c
  } else {
    discordant <- NA
  }

  #Run McNemar's Test
  result <- mcnemar.test(cont_table)
  p_val  <- result$statistic
  p_val  <- result$p.value

  #Matched Odds Ratio
  or    <- if (n_rows == 2 && n_cols == 2 && c != 0) b / c else NA
  or_ci <- if (!is.na(or) && c != 0) {
    se_log_or <- sqrt(1/b + 1/c)
    z         <- qnorm(1 - alpha/2)
    c(exp(log(or) - z * se_log_or),
      exp(log(or) + z * se_log_or))
  } else {
    NULL
  }

  #  Significance
  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)",
            p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)",
            p_val, alpha)
  }

  # Result interpretation
  result_label <- if (p_val < alpha) {
    "There is evidence of a significant difference in paired proportions between the two measurements."
  } else {
    "There is insufficient evidence of a significant difference in paired proportions between the two measurements."
  }

  # OR interpretation
  or_label <- if (!is.na(or)) {
    if (or > 1) {
      sprintf(paste("Matched OR = %.3f: More subjects changed",
                    "from the first category to the second",
                    "category than vice versa."), or)
    } else if (or < 1) {
      sprintf(paste("Matched OR = %.3f: More subjects changed",
                    "from the second category to the first",
                    "category than vice versa."), or)
    } else {
      sprintf(paste("Matched OR = %.3f: No evidence of",
                    "asymmetry in the discordant pairs."), or)
    }
  } else {
    "Matched OR could not be computed."
  }

  # CI interpretation
  ci_label <- if (!is.null(or_ci)) {
    if (or_ci[1] > 1 || or_ci[2] < 1) {
      sprintf(paste("%.0f%% CI [%.3f, %.3f] excludes 1:",
                    "Evidence of a significant difference",
                    "in paired proportions between measurements."),
              conf.level * 100, or_ci[1], or_ci[2])
    } else {
      sprintf(paste("%.0f%% CI [%.3f, %.3f] includes 1:",
                    "No statistically significant evidence",
                    "of a difference in paired proportions."),
              conf.level * 100, or_ci[1], or_ci[2])
    }
  } else {
    NULL
  }

  # Warnings and Notes
  warnings_list <- c()
  notes_list    <- c()

  # Small discordant pairs
  if (!is.na(discordant) && discordant < 10) {
    warnings_list <- c(warnings_list,
                       paste("The number of discordant pairs is very small",
                             "(less than 10). Results may be unreliable.",
                             "Interpret with caution."))
  }

  # Zero cells
  if (any(cont_table == 0)) {
    warnings_list <- c(warnings_list,
                       paste("One or more cells contain zero counts.",
                             "Matched odds ratio may be unstable,",
                             "undefined, or infinite.",
                             "Interpret results with caution."))
  }

  # Independence warning
  warnings_list <- c(warnings_list,
                     paste("McNemar's Test assumes that observations",
                           "are paired and independent across pairs.",
                           "Violation of this assumption may affect",
                           "the validity of the results."))

  # Paired data note
  notes_list <- c(notes_list,
                  paste("NOTE: McNemar's Test requires paired or",
                        "matched data. Ensure that each row in your",
                        "data represents the same subject measured",
                        "twice or a matched pair."))

  # Large table note
  if (n_rows > 2 || n_cols > 2) {
    notes_list <- c(notes_list,
                    paste("NOTE: For tables larger than 2x2 consider",
                          "using the Stuart-Maxwell test instead,",
                          "which is a generalization of McNemar's",
                          "Test for larger tables."))
  }

  output <- list(
    cont_table    = cont_table,
    n             = n,
    n_rows        = n_rows,
    n_cols        = n_cols,
    discordant    = discordant,
    p_val         = p_val,
    or            = or,
    or_ci         = or_ci,
    sig_label     = sig_label,
    result_label  = result_label,
    or_label      = or_label,
    ci_label      = ci_label,
    warnings_list = warnings_list,
    notes_list    = notes_list,
    conf.level    = conf.level,
    alpha         = alpha
  )

  class(output) <- "statease_mcnemar"
  output
}

#' @export
print.statease_mcnemar <- function(x, ...) {
  cat("\n")
  cat("statease McNemar's Test Report --------------------------------\n")
  cat(sprintf("  N            : %d\n", x$n))
  cat(sprintf("  Table size   : %d x %d\n", x$n_rows, x$n_cols))
  if (!is.na(x$discordant)) {
    cat(sprintf("  Discordant   : %d pairs\n", x$discordant))
  }
  cat("-----------------------------------------------------------------\n")
  cat("  Contingency Table:\n")
  print(x$cont_table)
  cat("\n")
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  p-value      : %.4f\n", x$p_val))
  if (!is.na(x$or)) {
    cat(sprintf("  Matched OR   : %.3f\n", x$or))
  }
  if (!is.null(x$or_ci)) {
    cat(sprintf("  %d%% CI      : [%.3f, %.3f]\n",
                as.integer(x$conf.level * 100),
                x$or_ci[1], x$or_ci[2]))
  }
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The result is %s.\n", x$sig_label))
  cat(sprintf("  %s\n", x$result_label))
  if (!is.null(x$or_label)) {
    cat(sprintf("  %s\n", x$or_label))
  }
  if (!is.null(x$ci_label)) {
    cat(sprintf("  %s\n", x$ci_label))
  }
  if (length(x$warnings_list) > 0) {
    cat("\n")
    for (w in x$warnings_list) {
      cat(sprintf("  WARNING: %s\n", w))
    }
  }
  if (length(x$notes_list) > 0) {
    cat("\n")
    for (n in x$notes_list) {
      cat(sprintf("  %s\n", n))
    }
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

#' Fisher's Exact Test with Plain-English Interpretation
#'
#' @param x A factor or character vector (first categorical variable)
#' @param y A factor or character vector (second categorical variable)
#' @param conf.level Confidence level. Default 0.95.
#' @param simulate.p.value Logical. Whether to use simulation to
#'   compute p-values for larger tables. Default FALSE.
#'
#' @return An object of class \code{statease_fisher} containing test
#'   results and interpretation. Use \code{print()} to display the
#'   formatted report.
#' @export
#'
#' @examples
#' x <- c("Yes","No","Yes","Yes","No","Yes","No","No","Yes","Yes")
#' y <- c("Male","Female","Male","Female","Male",
#'        "Female","Male","Female","Male","Female")
#' result <- fisher_interpret(x, y)
#' print(result)
fisher_interpret <- function(x, y, conf.level = 0.95,
                             simulate.p.value = FALSE) {

  # Guard clauses
  if (!is.vector(x) && !is.factor(x)) {
    stop("x must be a vector or factor.")
  }
  if (!is.vector(y) && !is.factor(y)) {
    stop("y must be a vector or factor.")
  }
  if (length(x) != length(y)) {
    stop("x and y must have the same length.")
  }
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }

  alpha <- 1 - conf.level

  # Convert to factor
  x <- as.factor(x)
  y <- as.factor(y)

  # Contingency table
  cont_table <- table(x, y)
  n          <- sum(cont_table)
  n_rows     <- nrow(cont_table)
  n_cols     <- ncol(cont_table)

  # Expected frequencies
  expected <- suppressWarnings(chisq.test(cont_table)$expected)

  # Run Fisher's Exact Test
  result <- fisher.test(cont_table,
                        conf.level = conf.level,
                        simulate.p.value = simulate.p.value)

  p_val <- result$p.value
  or    <- result$estimate
  ci    <- result$conf.int

  # Significance
  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)",
            p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)",
            p_val, alpha)
  }

  # Association interpretation
  assoc_label <- if (p_val < alpha) {
    "There is evidence of an association between the two categorical variables."
  } else {
    "There is insufficient evidence of an association between the two variables."
  }

  # OR interpretation
  or_label <- if (!is.null(or)) {
    if (or > 1) {
      sprintf("OR = %.3f: The odds of the outcome are higher in the first group.", or)
    } else if (or < 1) {
      sprintf("OR = %.3f: The odds of the outcome are lower in the first group.", or)
    } else {
      sprintf("OR = %.3f: No association between exposure and outcome.", or)
    }
  } else {
    NULL
  }

  # CI interpretation
  ci_label <- if (!is.null(ci)) {
    if (ci[1] > 1 || ci[2] < 1) {
      sprintf("%.0f%% CI [%.3f, %.3f] excludes 1: Evidence of a significant association.",
              conf.level * 100, ci[1], ci[2])
    } else {
      sprintf("%.0f%% CI [%.3f, %.3f] includes 1: No statistically significant evidence of an association.",
              conf.level * 100, ci[1], ci[2])
    }
  } else {
    NULL
  }

  #Warnings and Notes
  warnings_list <- c()
  notes_list    <- c()

  # Large sample warning
  if (n > 200) {
    warnings_list <- c(warnings_list,
                       paste("Sample size is relatively large.",
                             "A Chi-square test would likely produce similar",
                             "results and may be more computationally efficient.",
                             "Consider using chisq_interpret()."))
  }

  # Table larger than 2x2
  if (n_rows > 2 || n_cols > 2) {
    warnings_list <- c(warnings_list,
                       paste("The contingency table is larger than 2x2.",
                             "Fisher's Exact Test may require simulation or",
                             "approximation methods, which can increase",
                             "computation time and reduce exactness.",
                             "Interpret results with caution.",
                             "If simulate.p.value = TRUE was used,",
                             "explicitly state this in your report."))
  }

  # Zero cells
  if (any(cont_table == 0)) {
    warnings_list <- c(warnings_list,
                       paste("One or more cells contain zero counts.",
                             "Odds ratios may be unstable, undefined,",
                             "or infinite. Interpret results with caution."))
  }

  # All expected frequencies > 5
  if (all(expected >= 5)) {
    notes_list <- c(notes_list,
                    paste("NOTE: All expected frequencies exceed 5.",
                          "A Chi-square test would also be appropriate",
                          "and may be preferred for larger samples.",
                          "Consider using chisq_interpret()."))
  }

  # Simulate p value note
  if (simulate.p.value) {
    notes_list <- c(notes_list,
                    paste("NOTE: P-value was computed using simulation",
                          "(simulate.p.value = TRUE).",
                          "Please state this explicitly in your report."))
  }

  output <- list(
    cont_table        = cont_table,
    expected          = expected,
    n                 = n,
    n_rows            = n_rows,
    n_cols            = n_cols,
    p_val             = p_val,
    or                = or,
    ci                = ci,
    sig_label         = sig_label,
    assoc_label       = assoc_label,
    or_label          = or_label,
    ci_label          = ci_label,
    warnings_list     = warnings_list,
    notes_list        = notes_list,
    simulate.p.value  = simulate.p.value,
    conf.level        = conf.level,
    alpha             = alpha
  )

  class(output) <- "statease_fisher"
  output
}

#' @export
print.statease_fisher <- function(x, ...) {
  cat("\n")
  cat("--- statease Fisher's Exact Test Report ---------------\n")
  cat(sprintf("  N            : %d\n", x$n))
  cat(sprintf("  Table size   : %d x %d\n", x$n_rows, x$n_cols))
  cat("\n")
  cat("  Contingency Table (Observed):\n")
  print(x$cont_table)
  cat("\n")
  cat("  Expected Frequencies:\n")
  print(round(x$expected, 2))
  cat("\n")
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  p-value      : %.4f\n", x$p_val))
  if (!is.null(x$or)) {
    cat(sprintf("  Odds Ratio   : %.3f\n", x$or))
  }
  if (!is.null(x$ci)) {
    cat(sprintf("  %d%% CI      : [%.3f, %.3f]\n",
                as.integer(x$conf.level * 100),
                x$ci[1], x$ci[2]))
  }
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The result is %s.\n", x$sig_label))
  cat(sprintf("  %s\n", x$assoc_label))
  if (!is.null(x$or_label)) {
    cat(sprintf("  %s\n", x$or_label))
  }
  if (!is.null(x$ci_label)) {
    cat(sprintf("  %s\n", x$ci_label))
  }
  if (length(x$warnings_list) > 0) {
    cat("\n")
    for (w in x$warnings_list) {
      cat(sprintf("  WARNING: %s\n", w))
    }
  }
  if (length(x$notes_list) > 0) {
    cat("\n")
    for (n in x$notes_list) {
      cat(sprintf("  %s\n", n))
    }
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

#' Logistic Regression with Plain-English Interpretation
#'
#' @param formula A formula of the form outcome ~ predictor1 + predictor2 + ...
#' @param data A data frame containing the variables
#' @param conf.level Confidence level. Default 0.95.
#'
#' @return An object of class \code{statease_logistic} containing logistic
#'   regression results and interpretation. Use \code{print()} to
#'   display the formatted report.
#' @export
#'
#' @examples
#' df <- data.frame(
#'   passed      = c(1,1,0,1,0,1,1,0,1,1,0,0,1,1,0),
#'   study_hours = c(9,8,3,7,2,9,8,3,7,6,2,1,8,7,3),
#'   attendance  = c(90,85,50,80,45,95,88,55,78,70,40,35,92,83,52)
#' )
#' result <- logistic_interpret(passed ~ study_hours + attendance, data = df)
#' print(result)
logistic_interpret <- function(formula, data, conf.level = 0.95) {

  # --- Guard clauses ---
  if (!inherits(formula, "formula")) {
    stop("Please provide a valid formula e.g. outcome ~ pred1 + pred2")
  }
  if (!is.data.frame(data)) stop("data must be a data frame.")
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }

  alpha <- 1 - conf.level
  vars  <- all.vars(formula)

  outcome    <- vars[1]
  predictors <- vars[-1]

  # --- Check variables exist ---
  for (v in vars) {
    if (!v %in% names(data)) {
      stop(sprintf("Variable '%s' not found in data.", v))
    }
  }

  # --- Check outcome is binary ---
  outcome_vals <- unique(na.omit(data[[outcome]]))
  if (length(outcome_vals) != 2) {
    stop(sprintf(
      "Outcome variable '%s' must be binary (e.g. 0/1 or Yes/No).",
      outcome))
  }

  # --- Sample size check ---
  n <- nrow(na.omit(data[, vars]))
  if (n < 20) {
    warning("Sample size is small (n < 20). Interpret results with caution.")
  }

  # --- Run logistic regression ---
  model     <- glm(formula, data = data, family = binomial())
  model_sum <- summary(model)
  coefs     <- coef(model_sum)
  ci <- tryCatch(
    confint(model, level = conf.level),
    error = function(e) confint.default(model, level = conf.level),
    warning = function(w) confint.default(model, level = conf.level)
  )

  # --- Odds ratios ---
  or     <- exp(coef(model))
  or_ci  <- exp(ci)

  # --- Nagelkerke R-squared ---
  null_dev  <- model$null.deviance
  res_dev   <- model$deviance
  n_obs     <- model$df.null + 1
  cox_snell <- 1 - exp((res_dev - null_dev) / n_obs)
  nagelkerke <- cox_snell / (1 - exp(-null_dev / n_obs))

  # --- R-squared label ---
  r_sq_label <- if (nagelkerke < 0.01) {
    "negligible"
  } else if (nagelkerke < 0.09) {
    "small"
  } else if (nagelkerke < 0.25) {
    "moderate"
  } else {
    "large"
  }

  # --- Overall model significance (likelihood ratio test) ---
  chi_model <- null_dev - res_dev
  df_model  <- model$df.null - model$df.residual
  p_model   <- pchisq(chi_model, df_model, lower.tail = FALSE)

  model_sig <- if (p_model < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)", p_model, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)", p_model, alpha)
  }

  # --- Individual predictors ---
  predictor_results <- list()
  for (i in seq_along(predictors)) {
    pred    <- predictors[i]
    row_idx <- i + 1
    b       <- coefs[row_idx, 1]
    se      <- coefs[row_idx, 2]
    z_val   <- coefs[row_idx, 3]
    p_val   <- coefs[row_idx, 4]
    odds    <- or[row_idx]
    ci_low  <- or_ci[row_idx, 1]
    ci_high <- or_ci[row_idx, 2]

    sig <- if (p_val < alpha) "significant" else "not significant"

    or_interpret <- if (odds > 1) {
      sprintf("each unit increase in %s increases the odds by %.1f%%",
              pred, (odds - 1) * 100)
    } else {
      sprintf("each unit increase in %s decreases the odds by %.1f%%",
              pred, (1 - odds) * 100)
    }

    predictor_results[[pred]] <- list(
      name         = pred,
      b            = b,
      se           = se,
      z_val        = z_val,
      p_val        = p_val,
      odds         = odds,
      ci_low       = ci_low,
      ci_high      = ci_high,
      sig          = sig,
      or_interpret = or_interpret
    )
  }

  output <- list(
    outcome           = outcome,
    predictors        = predictors,
    n                 = n,
    intercept         = coefs[1, 1],
    nagelkerke        = nagelkerke,
    r_sq_label        = r_sq_label,
    chi_model         = chi_model,
    df_model          = df_model,
    p_model           = p_model,
    model_sig         = model_sig,
    predictor_results = predictor_results,
    conf.level        = conf.level,
    alpha             = alpha
  )

  class(output) <- "statease_logistic"
  output
}

#' @export
print.statease_logistic <- function(x, ...) {
  cat("\n")
  cat("-- statease Logistic Regression Report --------------------------\n")
  cat(sprintf("  Outcome      : %s\n", x$outcome))
  cat(sprintf("  Predictors   : %s\n", paste(x$predictors, collapse = ", ")))
  cat(sprintf("  N            : %d\n", x$n))
  cat("-----------------------------------------------------------------\n")
  cat("  Overall Model Fit:\n")
  cat(sprintf("  Chi-square   : %.3f  (df = %d)  p = %.4f\n",
              x$chi_model, x$df_model, x$p_model))
  cat(sprintf("  Nagelkerke R2: %.4f (%s effect)\n",
              x$nagelkerke, x$r_sq_label))
  cat(sprintf("  The overall model is %s.\n", x$model_sig))
  cat("-----------------------------------------------------------------\n")
  cat("  Individual Predictors:\n")
  for (pred in x$predictors) {
    pr <- x$predictor_results[[pred]]
    cat(sprintf("\n  %s\n", pred))
    cat(sprintf("    Coefficient  : %.3f  (SE = %.3f)\n", pr$b, pr$se))
    cat(sprintf("    z-statistic  : %.3f\n", pr$z_val))
    cat(sprintf("    p-value      : %.4f  [%s]\n", pr$p_val, pr$sig))
    cat(sprintf("    Odds Ratio   : %.3f\n", pr$odds))
    cat(sprintf("    %d%% CI (OR) : [%.3f, %.3f]\n",
                as.integer(x$conf.level * 100), pr$ci_low, pr$ci_high))
    cat(sprintf("    Interpretation: %s.\n", pr$or_interpret))
  }
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The model is %s.\n", x$model_sig))
  cat(sprintf("  Nagelkerke R2 = %.4f suggests a %s amount of\n",
              x$nagelkerke, x$r_sq_label))
  cat(sprintf("  variance in %s is explained by the predictors.\n",
              x$outcome))

  sig_preds <- Filter(function(p) p$sig == "significant",
                      x$predictor_results)
  nonsig_preds <- Filter(function(p) p$sig == "not significant",
                         x$predictor_results)

  if (length(sig_preds) > 0) {
    cat(sprintf("\n  Significant predictors: %s\n",
                paste(names(sig_preds), collapse = ", ")))
  }
  if (length(nonsig_preds) > 0) {
    cat(sprintf("  Non-significant predictors: %s\n",
                paste(names(nonsig_preds), collapse = ", ")))
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

#' Mann-Whitney U Test with Plain-English Interpretation
#'
#' @param x A numeric vector (group 1)
#' @param y A numeric vector (group 2)
#' @param conf.level Confidence level. Default 0.95.
#' @param var_name Optional label for the report. Default "Variable"
#'
#' @return An object of class \code{statease_mannwhitney} containing
#'   test results and interpretation. Use \code{print()} to display
#'   the formatted report.
#' @export
#'
#' @examples
#' x <- c(23, 45, 12, 67, 34, 89, 56)
#' y <- c(19, 38, 22, 51, 29, 74, 44)
#' result <- mannwhitney_interpret(x, y)
#' print(result)
mannwhitney_interpret <- function(x, y, conf.level = 0.95,
                                  var_name = "Variable") {

  # --- Guard clauses ---
  if (!is.numeric(x)) stop("x must be a numeric vector.")
  if (!is.numeric(y)) stop("y must be a numeric vector.")
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }
  if (length(na.omit(x)) < 2) stop("x must have at least 2 non-missing values.")
  if (length(na.omit(y)) < 2) stop("y must have at least 2 non-missing values.")

  alpha   <- 1 - conf.level
  x_clean <- na.omit(x)
  y_clean <- na.omit(y)

  if (length(x_clean) < 10 || length(y_clean) < 10) {
    warning("Sample size is small (n < 10). Interpret results with caution.")
  }

  # --- Run test ---
  result <- wilcox.test(x, y, paired = FALSE,
                        conf.int = TRUE, conf.level = conf.level)
  w_val  <- result$statistic
  p_val  <- result$p.value
  ci     <- result$conf.int

  # --- Effect size r = Z / sqrt(N) ---
  n_total <- length(x_clean) + length(y_clean)
  z_val   <- qnorm(p_val / 2)
  r_effect <- abs(z_val) / sqrt(n_total)

  effect_label <- if (r_effect < 0.1) {
    "negligible"
  } else if (r_effect < 0.3) {
    "small"
  } else if (r_effect < 0.5) {
    "moderate"
  } else {
    "large"
  }

  # --- Medians ---
  med_x <- median(x_clean)
  med_y <- median(y_clean)

  direction <- if (med_x > med_y) {
    sprintf(paste("Values in Group 1 appear stochastically greater",
                  "than values in Group 2.",
                  "(Reported medians: Group 1 = %.2f, Group 2 = %.2f)"),
            med_x, med_y)
  } else {
    sprintf(paste("Values in Group 2 appear stochastically greater",
                  "than values in Group 1.",
                  "(Reported medians: Group 1 = %.2f, Group 2 = %.2f)"),
            med_x, med_y)
  }

  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)", p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)", p_val, alpha)
  }

  output <- list(
    var_name     = var_name,
    n_x          = length(x_clean),
    n_y          = length(y_clean),
    med_x        = med_x,
    med_y        = med_y,
    w_val        = w_val,
    p_val        = p_val,
    ci           = ci,
    r_effect     = r_effect,
    effect_label = effect_label,
    sig_label    = sig_label,
    direction    = direction,
    conf.level   = conf.level,
    alpha        = alpha
  )

  class(output) <- "statease_mannwhitney"
  output
}

#' @export
print.statease_mannwhitney <- function(x, ...) {
  cat("\n")
  cat("-- statease Mann-Whitney U Test Report --------------------------\n")
  cat(sprintf("  Variable     : %s\n", x$var_name))
  cat(sprintf("  Group 1      : n = %d  |  Median = %.2f\n", x$n_x, x$med_x))
  cat(sprintf("  Group 2      : n = %d  |  Median = %.2f\n", x$n_y, x$med_y))
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  W statistic  : %.3f\n", x$w_val))
  cat(sprintf("  p-value      : %.4f\n", x$p_val))
  cat(sprintf("  %d%% CI      : [%.3f, %.3f]\n",
              as.integer(x$conf.level * 100), x$ci[1], x$ci[2]))
  cat(sprintf("  Effect size  : %.3f (%s)\n", x$r_effect, x$effect_label))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The result is %s.\n", x$sig_label))
  cat(sprintf("  %s\n", x$direction))
  cat(sprintf("  Effect size is %s (r = %.3f).\n",
              x$effect_label, x$r_effect))
  cat("  Note: Mann-Whitney tests stochastic superiority,\n")
  cat("  not differences in medians.\n")
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}


#' Wilcoxon Signed Rank Test with Plain-English Interpretation
#'
#' @param x A numeric vector (first measurement)
#' @param y A numeric vector (second measurement)
#' @param conf.level Confidence level. Default 0.95.
#' @param var_name Optional label for the report. Default "Variable"
#'
#' @return An object of class \code{statease_wilcoxon} containing
#'   test results and interpretation. Use \code{print()} to display
#'   the formatted report.
#' @export
#'
#' @examples
#' x <- c(23, 45, 12, 67, 34, 89, 56)
#' y <- c(19, 38, 22, 51, 29, 74, 44)
#' result <- wilcoxon_interpret(x, y)
#' print(result)
wilcoxon_interpret <- function(x, y, conf.level = 0.95,
                               var_name = "Variable") {

  # --- Guard clauses ---
  if (!is.numeric(x)) stop("x must be a numeric vector.")
  if (!is.numeric(y)) stop("y must be a numeric vector.")
  if (length(x) != length(y)) {
    stop("x and y must have the same length for a paired test.")
  }
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }
  if (length(na.omit(x)) < 2) stop("x must have at least 2 non-missing values.")

  alpha   <- 1 - conf.level
  x_clean <- na.omit(x)
  y_clean <- na.omit(y)

  if (length(x_clean) < 10) {
    warning("Sample size is small (n < 10). Interpret results with caution.")
  }

  # --- Run test ---
  result <- wilcox.test(x, y, paired = TRUE,
                        conf.int = TRUE, conf.level = conf.level)
  v_val  <- result$statistic
  p_val  <- result$p.value
  ci     <- result$conf.int

  # --- Effect size ---
  n_total  <- length(x_clean)
  z_val    <- qnorm(p_val / 2)
  r_effect <- abs(z_val) / sqrt(n_total)

  effect_label <- if (r_effect < 0.1) {
    "negligible"
  } else if (r_effect < 0.3) {
    "small"
  } else if (r_effect < 0.5) {
    "moderate"
  } else {
    "large"
  }

  # --- Medians ---
  med_x <- median(x_clean)
  med_y <- median(y_clean)

  direction <- if (med_x > med_y) {
    sprintf(paste("Post-measurement values appear stochastically",
                  "greater than pre-measurement values.",
                  "(Reported medians: Post = %.2f, Pre = %.2f)"),
            med_x, med_y)
  } else {
    sprintf(paste("Pre-measurement values appear stochastically",
                  "greater than post-measurement values.",
                  "(Reported medians: Post = %.2f, Pre = %.2f)"),
            med_x, med_y)
  }

  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)", p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)", p_val, alpha)
  }

  output <- list(
    var_name     = var_name,
    n            = length(x_clean),
    med_x        = med_x,
    med_y        = med_y,
    v_val        = v_val,
    p_val        = p_val,
    ci           = ci,
    r_effect     = r_effect,
    effect_label = effect_label,
    sig_label    = sig_label,
    direction    = direction,
    conf.level   = conf.level,
    alpha        = alpha
  )

  class(output) <- "statease_wilcoxon"
  output
}

#' @export
print.statease_wilcoxon <- function(x, ...) {
  cat("\n")
  cat("-- statease Wilcoxon Signed Rank Test Report --------------------\n")
  cat(sprintf("  Variable     : %s\n", x$var_name))
  cat(sprintf("  N (pairs)    : %d\n", x$n))
  cat(sprintf("  Pre Median   : %.2f\n", x$med_y))
  cat(sprintf("  Post Median  : %.2f\n", x$med_x))
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  V statistic  : %.3f\n", x$v_val))
  cat(sprintf("  p-value      : %.4f\n", x$p_val))
  cat(sprintf("  %d%% CI      : [%.3f, %.3f]\n",
              as.integer(x$conf.level * 100), x$ci[1], x$ci[2]))
  cat(sprintf("  Effect size  : %.3f (%s)\n", x$r_effect, x$effect_label))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The result is %s.\n", x$sig_label))
  cat(sprintf("  %s\n", x$direction))
  cat(sprintf("  Effect size is %s (r = %.3f).\n",
              x$effect_label, x$r_effect))
  cat("  Note: Wilcoxon test compares groups using ranked values.\n")
  cat("  A significant result sugegsts one group tends to have larger or smaller observation than the other.\n")
  cat("  This can be interpreted as evidence of stochastic superiority, but only under typical distribution assumptions.")
  cat("  It does not specifically test differences in medians.\n")
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}


#' Kruskal-Wallis Test with Plain-English Interpretation
#'
#' @param formula A formula of the form outcome ~ group
#' @param data A data frame containing the variables
#' @param conf.level Confidence level. Default 0.95.
#'
#' @return An object of class \code{statease_kruskal} containing
#'   test results and interpretation. Use \code{print()} to display
#'   the formatted report.
#' @export
#'
#' @examples
#' df <- data.frame(
#'   score = c(23,45,12,67,34,89,56,43,78,90,11,34),
#'   group = rep(c("A","B","C"), each = 4)
#' )
#' result <- kruskal_interpret(score ~ group, data = df)
#' print(result)
kruskal_interpret <- function(formula, data, conf.level = 0.95) {

  # --- Guard clauses ---
  if (!inherits(formula, "formula")) {
    stop("Please provide a valid formula e.g. score ~ group")
  }
  if (!is.data.frame(data)) stop("data must be a data frame.")
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }

  alpha     <- 1 - conf.level
  vars      <- all.vars(formula)
  outcome   <- vars[1]
  group_var <- vars[2]

  # --- Check variables exist ---
  if (!outcome %in% names(data)) {
    stop(sprintf("Outcome variable '%s' not found in data.", outcome))
  }
  if (!group_var %in% names(data)) {
    stop(sprintf("Group variable '%s' not found in data.", group_var))
  }
  if (!is.numeric(data[[outcome]])) {
    stop(sprintf("Outcome variable '%s' must be numeric.", outcome))
  }

  # --- Convert group to factor ---
  data[[group_var]] <- as.factor(data[[group_var]])
  groups            <- levels(data[[group_var]])
  n_groups          <- length(groups)

  if (n_groups < 2) stop("Group variable must have at least 2 levels.")

  # --- Sample size check ---
  group_ns <- tapply(data[[outcome]], data[[group_var]],
                     function(x) sum(!is.na(x)))
  if (any(group_ns < 5)) {
    warning("One or more groups have very small sample sizes (n < 5).")
  }

  # --- Group medians ---
  group_medians <- tapply(data[[outcome]], data[[group_var]],
                          median, na.rm = TRUE)

  # --- Run Kruskal-Wallis ---
  result  <- kruskal.test(formula, data = data)
  h_val   <- result$statistic
  df      <- result$parameter
  p_val   <- result$p.value
  n_total <- sum(group_ns)

  # --- Effect size eta squared ---
  eta_sq <- (h_val - n_groups + 1) / (n_total - n_groups)
  eta_sq <- max(0, eta_sq)

  effect_label <- if (eta_sq < 0.01) {
    "negligible"
  } else if (eta_sq < 0.06) {
    "small"
  } else if (eta_sq < 0.14) {
    "moderate"
  } else {
    "large"
  }

  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)", p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)", p_val, alpha)
  }

  # --- Post-hoc Dunn test (manual) if significant ---
  dunn_results <- NULL
  if (p_val < alpha && n_groups > 2) {
    pairs     <- combn(groups, 2, simplify = FALSE)
    dunn_list <- list()
    for (pair in pairs) {
      g1   <- pair[1]
      g2   <- pair[2]
      x1   <- data[[outcome]][data[[group_var]] == g1]
      x2   <- data[[outcome]][data[[group_var]] == g2]
      wt   <- wilcox.test(x1, x2, exact = FALSE)
      comp <- paste(g1, "vs", g2)
      dunn_list[[comp]] <- list(
        comparison = comp,
        p_val      = wt$p.value,
        sig        = if (wt$p.value < alpha) "[significant]" else "[not significant]"
      )
    }
    dunn_results <- dunn_list
  }

  output <- list(
    outcome       = outcome,
    group_var     = group_var,
    groups        = groups,
    n_groups      = n_groups,
    n_total       = n_total,
    group_ns      = group_ns,
    group_medians = group_medians,
    h_val         = h_val,
    df            = df,
    p_val         = p_val,
    eta_sq        = eta_sq,
    effect_label  = effect_label,
    sig_label     = sig_label,
    dunn_results  = dunn_results,
    alpha         = alpha,
    conf.level    = conf.level
  )

  class(output) <- "statease_kruskal"
  output
}

#' @export
print.statease_kruskal <- function(x, ...) {
  cat("\n")
  cat("-- statease Kruskal-Wallis Test Report --------------------------\n")
  cat(sprintf("  Outcome      : %s\n", x$outcome))
  cat(sprintf("  Group        : %s  (%d levels)\n", x$group_var, x$n_groups))
  cat(sprintf("  N            : %d\n", x$n_total))
  cat("-----------------------------------------------------------------\n")
  cat("  Group Medians:\n")
  for (g in x$groups) {
    cat(sprintf("    %-12s : Median = %.2f  (n = %d)\n",
                g, x$group_medians[g], x$group_ns[g]))
  }
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  H statistic  : %.3f\n", x$h_val))
  cat(sprintf("  df           : %d\n", x$df))
  cat(sprintf("  p-value      : %.4f\n", x$p_val))
  cat(sprintf("  Eta squared  : %.4f (%s effect)\n",
              x$eta_sq, x$effect_label))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The result is %s.\n", x$sig_label))
  cat(sprintf("  The result is %s.\n", x$sig_label))
  cat(sprintf("  Effect size is %s (eta^2 = %.4f).\n",
              x$effect_label, x$eta_sq))
  cat("  Note: Kruskal-Wallis test compares multiple groups using ranked values\n")
  cat("  not differences in medians.\n")
  cat("  Medians are reported for descriptive purposes only.\n")
  if (!is.null(x$dunn_results)) {
    cat("\n")
    cat("-- Post-Hoc Pairwise Comparisons (Wilcoxon) ---------------------\n")
    for (comp in names(x$dunn_results)) {
      dr <- x$dunn_results[[comp]]
      cat(sprintf("  %s\n", dr$comparison))
      cat(sprintf("    p = %.4f  %s\n", dr$p_val, dr$sig))
    }
    cat("\n")
    cat("  Note: Pairwise Wilcoxon tests used for post-hoc comparisons.\n")
  } else if (x$p_val >= x$alpha) {
    cat("\n  Post-hoc tests not run (overall result not significant).\n")
  }

  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

test_that("mannwhitney_interpret returns correct class", {
  result <- mannwhitney_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    c(2,3,4,5,6,7,8,9,10,11)
  )
  expect_s3_class(result, "statease_mannwhitney")
})

test_that("mannwhitney_interpret returns correct values", {
  result <- mannwhitney_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    c(2,3,4,5,6,7,8,9,10,11)
  )
  expect_true(is.numeric(result$p_val))
  expect_true(result$p_val >= 0 && result$p_val <= 1)
  expect_true(is.numeric(result$r_effect))
})

test_that("mannwhitney_interpret errors on non-numeric", {
  expect_error(mannwhitney_interpret("hello", c(1,2,3)))
})

test_that("wilcoxon_interpret returns correct class", {
  result <- wilcoxon_interpret(
    c(1,2,3,4,5,6,7,8,9,10),
    c(2,3,4,5,6,7,8,9,10,11)
  )
  expect_s3_class(result, "statease_wilcoxon")
})

test_that("wilcoxon_interpret errors on unequal lengths", {
  expect_error(wilcoxon_interpret(
    c(1,2,3,4,5),
    c(1,2,3)
  ))
})

test_that("kruskal_interpret returns correct class", {
  df <- data.frame(
    score = c(23,45,12,67,34,89,56,43,78,90,11,34),
    group = rep(c("A","B","C"), each = 4)
  )
  result <- kruskal_interpret(score ~ group, data = df)
  expect_s3_class(result, "statease_kruskal")
})

test_that("kruskal_interpret returns correct values", {
  df <- data.frame(
    score = c(23,45,12,67,34,89,56,43,78,90,11,34),
    group = rep(c("A","B","C"), each = 4)
  )
  result <- kruskal_interpret(score ~ group, data = df)
  expect_true(is.numeric(result$h_val))
  expect_true(is.numeric(result$p_val))
  expect_true(result$p_val >= 0 && result$p_val <= 1)
})

#' Launch the statease Shiny App
#'
#' @description Launches an interactive Shiny application for
#'   running statistical analyses without writing any code.
#'
#' @param ... Additional arguments passed to shiny::runApp()
#'
#' @return Launches the Shiny app in your browser
#' @export
#'
#' @examples
#' if(interactive()){
#'   run_app()
#' }
run_app <- function(...) {
  app_dir <- system.file("shiny", package = "statease")
  if (app_dir == "") {
    stop("Shiny app not found. Try reinstalling statease.")
  }
  shiny::runApp(app_dir, ...)
}

#' Master Analysis Function - Auto-detects and runs the right test
#'
#' @param x A numeric vector (required always)
#' @param y A numeric vector, factor, or character group variable (optional)
#' @param data A data frame (required if using a formula)
#' @param formula A formula of the form outcome ~ predictor or
#'   outcome ~ group1 * group2 or cbind(y1, y2) ~ group (optional)
#' @param mu Hypothesised mean for one-sample t-test. Default 0.
#' @param paired Logical. TRUE for paired t-test. Default FALSE.
#' @param nonparam Logical. TRUE to use non-parametric tests. Default FALSE.
#' @param conf.level Confidence level. Default 0.95.
#' @param var_name Optional label for the report.
#' @param var1_name Optional name for first variable in correlation.
#' @param var2_name Optional name for second variable in correlation.
#' @param method Correlation method: "pearson", "spearman", or "kendall".
#'   Default "pearson".
#' @param test_type For power analysis: one of "ttest.one", "ttest.two",
#'   "ttest.paired", "anova", "correlation", "chisq", "regression".
#' @param effect_size For power analysis: the expected effect size.
#' @param power For power analysis: desired power level. Default 0.80.
#' @param n_groups For power analysis ANOVA: number of groups. Default 2.
#' @param n_predictors For power analysis regression: number of predictors.
#'   Default 1.
#' @param check Logical. TRUE to run assumption checks before analysis.
#'   Default FALSE.
#'
#' @return A printed analysis report from the appropriate test
#' @export
#'
#' @examples
#' # Descriptive only
#' analyze(x = c(23, 45, 12, 67, 34))
#'
#' # Auto t-test
#' analyze(x = c(23,45,12,67,34), y = c(19,38,22,51,29))
#'
#' # Auto ANOVA
#' df <- data.frame(
#'   score = c(23,45,12,67,34,89,56,43,78,90,11,34),
#'   group = rep(c("A","B","C"), each = 4)
#' )
#' analyze(formula = score ~ group, data = df)
#'
#' # Power analysis
#' analyze(test_type = "ttest.two", effect_size = 0.5)
#'
#' # Check assumptions
#' analyze(x = c(23,45,12,67,34), y = c(19,38,22,51,29),
#'         check = TRUE)
analyze <- function(x = NULL, y = NULL, data = NULL,
                    formula = NULL, mu = 0, paired = FALSE,
                    nonparam = FALSE, conf.level = 0.95,
                    var_name = "Variable",
                    var1_name = "Variable 1",
                    var2_name = "Variable 2",
                    method = "pearson",
                    test_type = NULL, effect_size = NULL,
                    power = 0.80, n_groups = 2,
                    n_predictors = 1, check = FALSE) {

  #ROUTE 0: Power Analysis
  if (!is.null(test_type) && !is.null(effect_size)) {
    message("[statease] Power analysis requested -> Running Power Analysis")
    result <- power_interpret(
      test        = test_type,
      effect_size = effect_size,
      n           = x,
      alpha       = 1 - conf.level,
      power       = power,
      n_groups    = n_groups,
      n_predictors = n_predictors
    )
    print(result)
    return(invisible(result))
  }

  #ROUTE 0b: Assumption checks
  if (check) {
    if (!is.null(formula) && !is.null(data)) {
      vars      <- all.vars(formula)
      group_var <- vars[2]
      test_name <- if (length(vars) == 3) "anova2" else {
        if (is.numeric(data[[group_var]])) "regression" else "anova"
      }
      message(sprintf("[statease] check = TRUE -> Checking assumptions for %s",
                      test_name))
      result <- check_assumptions(test_name,
                                  formula = formula,
                                  data    = data)
      print(result)
      return(invisible(result))
    } else if (!is.null(x) && !is.null(y) && is.numeric(y)) {
      message("[statease] check = TRUE -> Checking assumptions for ttest")
      result <- check_assumptions("ttest", x = x, y = y)
      print(result)
      return(invisible(result))
    } else if (!is.null(x) && !is.null(y) && is.numeric(x)) {
      message("[statease] check = TRUE -> Checking assumptions for correlation")
      result <- check_assumptions("correlation", x = x, y = y)
      print(result)
      return(invisible(result))
    }
  }

  #ROUTE 1: Formula provided
  if (!is.null(formula)) {
    if (is.null(data)) {
      stop("Please provide a data frame using the 'data' argument.")
    }

    formula_str <- deparse(formula)
    vars        <- all.vars(formula)

    # MANOVA — cbind in formula
    if (grepl("cbind", formula_str)) {
      message("[statease] Multiple outcomes detected -> Running MANOVA")
      result <- manova_interpret(formula, data = data,
                                 conf.level = conf.level)
      print(result)

      # Two-Way ANOVA — two grouping variables
    } else if (length(vars) == 3) {
      group1 <- vars[2]
      group2 <- vars[3]

      if (!is.numeric(data[[group1]]) && !is.numeric(data[[group2]])) {
        message("[statease] Two grouping variables detected -> Running Two-Way ANOVA")
        result <- anova2_interpret(formula, data = data,
                                   conf.level = conf.level)
        print(result)
      } else {
        message("[statease] Multiple numeric predictors -> Running Multiple Linear Regression")
        result <- mlr_interpret(formula, data = data,
                                conf.level = conf.level)
        print(result)
      }

      # One variable in formula
    } else if (length(vars) == 2) {
      group_var <- vars[2]

      # Regression — predictor is numeric
      if (is.numeric(data[[group_var]])) {
        message("[statease] Numeric predictor detected -> Running Simple Linear Regression")
        result <- reg_interpret(formula, data = data,
                                conf.level = conf.level)
        print(result)

        # Categorical predictor
      } else {
        n_groups_data <- length(unique(data[[group_var]]))

        if (n_groups_data == 2) {
          if (nonparam) {
            message("[statease] Two groups + nonparam = TRUE -> Running Mann-Whitney U Test")
            grp_levels <- unique(data[[group_var]])
            x_grp <- data[[vars[1]]][data[[group_var]] == grp_levels[1]]
            y_grp <- data[[vars[1]]][data[[group_var]] == grp_levels[2]]
            result <- mannwhitney_interpret(x_grp, y_grp,
                                            conf.level = conf.level,
                                            var_name   = vars[1])
            print(result)
          } else {
            message("[statease] Two groups detected -> Running Independent T-Test")
            grp_levels <- unique(data[[group_var]])
            x_grp <- data[[vars[1]]][data[[group_var]] == grp_levels[1]]
            y_grp <- data[[vars[1]]][data[[group_var]] == grp_levels[2]]
            result <- ttest_interpret(x_grp, y_grp,
                                      conf.level = conf.level,
                                      var_name   = vars[1])
            print(result)
          }
        } else {
          if (nonparam) {
            message("[statease] 3+ groups + nonparam = TRUE -> Running Kruskal-Wallis Test")
            result <- kruskal_interpret(formula, data = data,
                                        conf.level = conf.level)
            print(result)
          } else {
            message("[statease] 3+ groups detected -> Running One-Way ANOVA")
            result <- anova_interpret(formula, data = data,
                                      conf.level = conf.level)
            print(result)
          }
        }
      }
    } else {
      stop("Could not determine the right analysis. Check your formula.")
    }

    # ── ROUTE 2: Two categorical vectors → Chi-square ──────────
  } else if (!is.null(x) && !is.null(y) &&
             (is.character(x) || is.factor(x)) &&
             (is.character(y) || is.factor(y))) {
    message("[statease] Two categorical vectors detected -> Running Chi-Square Test")
    result <- chisq_interpret(x, y, conf.level = conf.level)
    print(result)

    #ROUTE 3: Two numeric vectors
  } else if (!is.null(x) && !is.null(y) &&
             is.numeric(x) && is.numeric(y)) {

    if (var1_name != "Variable 1" || var2_name != "Variable 2") {
      message("[statease] Two numeric vectors with variable names -> Running Correlation")
      result <- cor_interpret(x, y, method = method,
                              conf.level = conf.level,
                              var1_name  = var1_name,
                              var2_name  = var2_name)
      print(result)

    } else if (nonparam && paired) {
      message("[statease] Paired + nonparam = TRUE -> Running Wilcoxon Signed Rank Test")
      result <- wilcoxon_interpret(x, y, conf.level = conf.level,
                                   var_name = var_name)
      print(result)

    } else if (nonparam) {
      message("[statease] nonparam = TRUE -> Running Mann-Whitney U Test")
      result <- mannwhitney_interpret(x, y, conf.level = conf.level,
                                      var_name = var_name)
      print(result)

    } else {
      message("[statease] Two numeric vectors detected -> Running T-Test")
      result <- ttest_interpret(x, y, mu = mu, paired = paired,
                                conf.level = conf.level,
                                var_name   = var_name)
      print(result)
    }

    # ROUTE 4: x numeric + y categorical
  } else if (!is.null(x) && !is.null(y) &&
             is.numeric(x) &&
             (is.factor(y) || is.character(y))) {
    n_groups_data <- length(unique(y))

    if (n_groups_data == 2) {
      if (nonparam) {
        message("[statease] Numeric + 2 groups + nonparam = TRUE -> Running Mann-Whitney U")
        grp_levels <- unique(y)
        x1 <- x[y == grp_levels[1]]
        x2 <- x[y == grp_levels[2]]
        result <- mannwhitney_interpret(x1, x2,
                                        conf.level = conf.level,
                                        var_name   = var_name)
        print(result)
      } else {
        message("[statease] Numeric + 2-level group detected -> Running T-Test")
        grp_levels <- unique(y)
        x1 <- x[y == grp_levels[1]]
        x2 <- x[y == grp_levels[2]]
        result <- ttest_interpret(x1, x2,
                                  conf.level = conf.level,
                                  var_name   = var_name)
        print(result)
      }

    } else if (n_groups_data > 2) {
      if (nonparam) {
        message("[statease] Numeric + 3+ groups + nonparam = TRUE -> Running Kruskal-Wallis")
        temp_df <- data.frame(outcome = x, group = as.factor(y))
        result  <- kruskal_interpret(outcome ~ group,
                                     data       = temp_df,
                                     conf.level = conf.level)
        print(result)
      } else {
        message("[statease] Numeric + 3+ level group detected -> Running One-Way ANOVA")
        temp_df <- data.frame(outcome = x, group = as.factor(y))
        result  <- anova_interpret(outcome ~ group,
                                   data       = temp_df,
                                   conf.level = conf.level)
        print(result)
      }
    } else {
      stop("Group variable must have at least 2 levels.")
    }

    # ROUTE 5: x only → Descriptive or One-Sample T-Test
  } else if (!is.null(x) && is.numeric(x)) {
    if (mu != 0) {
      message("[statease] Single vector + mu detected -> Running One-Sample T-Test")
      result <- ttest_interpret(x, mu = mu,
                                conf.level = conf.level,
                                var_name   = var_name)
      print(result)
    } else {
      message("[statease] Single numeric vector -> Running Descriptive Statistics")
      result <- describe(x, var_name = var_name)
      print(result)
    }

  } else {
    stop("Could not determine the right analysis. Check your inputs.")
  }

  invisible(result)
}

#' Check Statistical Assumptions Before Running a Test
#'
#' @param test The test you plan to run. One of "ttest", "anova",
#'   "anova2", "correlation", "regression".
#' @param x A numeric vector (required for most tests)
#' @param y A numeric vector, factor, or character group variable
#'   (optional depending on test)
#' @param data A data frame (required for anova, anova2, regression)
#' @param formula A formula (required for anova, anova2, regression)
#'
#' @return An object of class \code{statease_assumptions} containing
#'   assumption check results. Use \code{print()} to display the
#'   formatted report.
#' @export
#'
#' @examples
#' x <- c(23, 45, 12, 67, 34, 89, 56, 43, 78, 90)
#' y <- c(19, 38, 22, 51, 29, 74, 44, 38, 65, 80)
#' result <- check_assumptions("ttest", x = x, y = y)
#' print(result)
check_assumptions <- function(test, x = NULL, y = NULL,
                              data = NULL, formula = NULL) {

  valid_tests <- c("ttest", "anova", "anova2",
                   "correlation", "regression")
  if (!test %in% valid_tests) {
    stop(sprintf("test must be one of: %s",
                 paste(valid_tests, collapse = ", ")))
  }

  results <- list()

  # --- Helper: normality test selector ---
  check_normality <- function(values, label) {
    values <- na.omit(values)
    n      <- length(values)

    if (n < 3) {
      return(list(
        assumption = sprintf("Normality (%s)", label),
        status     = "WARNING",
        detail     = "Sample size too small to test normality (n < 3)."
      ))
    }

    if (n <= 5000) {
      test_result <- shapiro.test(values)
      test_name   <- "Shapiro-Wilk"
      stat        <- test_result$statistic
      p           <- test_result$p.value
    } else {
      test_result <- ks.test(values, "pnorm",
                             mean(values), sd(values))
      test_name   <- "Kolmogorov-Smirnov"
      stat        <- test_result$statistic
      p           <- test_result$p.value
    }

    status <- if (p >= 0.05) "PASSED" else "WARNING"
    detail <- sprintf(
      "%s test: statistic = %.3f, p = %.4f. %s",
      test_name, stat, p,
      if (status == "PASSED") {
        "Normality assumption appears satisfied."
      } else {
        "Evidence suggests that the normality assumption may be violated."
      }
    )

    list(
      assumption = sprintf("Normality (%s)", label),
      status     = status,
      detail     = detail
    )
  }

  # --- Helper: sample size guidance ---
  sample_size_note <- function(n, label = "") {
    list(
      assumption = sprintf("Sample size guidance%s",
                           if (nchar(label) > 0) {
                             paste0(" (", label, ")")
                           } else ""),
      status     = if (n < 10) "WARNING" else "PASSED",
      detail     = sprintf(
        "n = %d. %s", n,
        if (n < 10) {
          "Small sample size. There is no formal assumption of sample size adequacy, but results should be interpreted with caution."
        } else {
          "Sample size appears reasonable."
        }
      )
    )
  }

  # T-TEST
  if (test == "ttest") {
    if (is.null(x)) stop("x is required for ttest assumption checks.")

    results[[length(results) + 1]] <- check_normality(x, "x")
    results[[length(results) + 1]] <- sample_size_note(length(na.omit(x)), "x")

    if (!is.null(y) && is.numeric(y)) {
      results[[length(results) + 1]] <- check_normality(y, "y")
      results[[length(results) + 1]] <- sample_size_note(length(na.omit(y)), "y")

      lev <- tryCatch({
        car::leveneTest(c(x, y) ~ as.factor(c(rep("x", length(x)),
                                              rep("y", length(y)))))
      }, error = function(e) NULL)

      if (!is.null(lev)) {
        p <- lev[1, "Pr(>F)"]
        status <- if (p >= 0.05) "PASSED" else "WARNING"
        results[[length(results) + 1]] <- list(
          assumption = "Homogeneity of variance",
          status     = status,
          detail     = sprintf(
            "Levene's Test: p = %.4f. %s", p,
            if (status == "PASSED") {
              "Variances appear approximately equal."
            } else {
              "Evidence suggests unequal variances. Consider Welch correction (used automatically in ttest_interpret())."
            }
          )
        )
      }
    }
  }

  # ONE-WAY ANOVA
  if (test == "anova") {
    if (is.null(formula) || is.null(data)) {
      stop("formula and data are required for anova assumption checks.")
    }

    vars      <- all.vars(formula)
    outcome   <- vars[1]
    group_var <- vars[2]
    data[[group_var]] <- as.factor(data[[group_var]])
    groups    <- levels(data[[group_var]])

    for (g in groups) {
      vals <- data[[outcome]][data[[group_var]] == g]
      results[[length(results) + 1]] <- check_normality(vals, paste("group:", g))
      results[[length(results) + 1]] <- sample_size_note(length(na.omit(vals)), g)
    }

    bart <- tryCatch(
      bartlett.test(formula, data = data),
      error = function(e) NULL
    )
    if (!is.null(bart)) {
      status <- if (bart$p.value >= 0.05) "PASSED" else "WARNING"
      results[[length(results) + 1]] <- list(
        assumption = "Homogeneity of variance",
        status     = status,
        detail     = sprintf(
          "Bartlett's Test: p = %.4f. %s", bart$p.value,
          if (status == "PASSED") {
            "Variances appear approximately equal across groups."
          } else {
            "Evidence suggests unequal variances across groups. Consider kruskal_interpret() as a non-parametric alternative."
          }
        )
      )
    }
  }

  # TWO-WAY ANOVA
  if (test == "anova2") {
    if (is.null(formula) || is.null(data)) {
      stop("formula and data are required for anova2 assumption checks.")
    }

    vars    <- all.vars(formula)
    outcome <- vars[1]
    group1  <- vars[2]
    group2  <- vars[3]

    data[[group1]] <- as.factor(data[[group1]])
    data[[group2]] <- as.factor(data[[group2]])

    model <- lm(formula, data = data)
    res   <- residuals(model)

    results[[length(results) + 1]] <- check_normality(res, "residuals")
    results[[length(results) + 1]] <- sample_size_note(
      nrow(na.omit(data[, vars])), "overall"
    )

    bart <- tryCatch(
      bartlett.test(data[[outcome]] ~
                      interaction(data[[group1]], data[[group2]])),
      error = function(e) NULL
    )
    if (!is.null(bart)) {
      status <- if (bart$p.value >= 0.05) "PASSED" else "WARNING"
      results[[length(results) + 1]] <- list(
        assumption = "Homogeneity of variance",
        status     = status,
        detail     = sprintf(
          "Bartlett's Test: p = %.4f. %s", bart$p.value,
          if (status == "PASSED") {
            "Variances appear approximately equal across cells."
          } else {
            "Evidence suggests unequal variances across cells."
          }
        )
      )
    }
  }

  # CORRELATION
  if (test == "correlation") {
    if (is.null(x) || is.null(y)) {
      stop("x and y are required for correlation assumption checks.")
    }

    results[[length(results) + 1]] <- check_normality(x, "x (for Pearson only)")
    results[[length(results) + 1]] <- check_normality(y, "y (for Pearson only)")
    results[[length(results) + 1]] <- sample_size_note(length(na.omit(x)))

    results[[length(results) + 1]] <- list(
      assumption = "Linearity",
      status     = "INFO",
      detail     = paste("Linearity assessment (recommended visual",
                         "inspection). Create a scatterplot of x",
                         "against y to visually assess linearity",
                         "before interpreting Pearson correlation.")
    )
  }

  # REGRESSION
  if (test == "regression") {
    if (is.null(formula) || is.null(data)) {
      stop("formula and data are required for regression assumption checks.")
    }

    model <- lm(formula, data = data)
    res   <- residuals(model)

    results[[length(results) + 1]] <- check_normality(res, "residuals")
    results[[length(results) + 1]] <- sample_size_note(nrow(model$model))

    # Homoscedasticity
    bp <- tryCatch(
      car::ncvTest(model),
      error = function(e) NULL
    )
    if (!is.null(bp)) {
      status <- if (bp$p >= 0.05) "PASSED" else "WARNING"
      results[[length(results) + 1]] <- list(
        assumption = "Homoscedasticity",
        status     = status,
        detail     = sprintf(
          "Non-constant variance test: p = %.4f. %s", bp$p,
          if (status == "PASSED") {
            "Homoscedasticity assumption appears satisfied."
          } else {
            "Evidence suggests heteroscedasticity (non-constant variance)."
          }
        )
      )
    }

    # Independence of residuals
    dw <- tryCatch(
      car::durbinWatsonTest(model),
      error = function(e) NULL
    )
    if (!is.null(dw)) {
      status <- if (dw$p >= 0.05) "PASSED" else "WARNING"
      results[[length(results) + 1]] <- list(
        assumption = "Independence of residuals",
        status     = status,
        detail     = sprintf(
          "Durbin-Watson test: DW = %.3f, p = %.4f. %s",
          dw$dw, dw$p,
          if (status == "PASSED") {
            "No strong evidence of autocorrelation in residuals."
          } else {
            "Evidence suggests autocorrelation in residuals."
          }
        )
      )
    }

    # Multicollinearity (VIF) for multiple regression
    n_predictors <- length(all.vars(formula)) - 1
    if (n_predictors > 1) {
      vif_vals <- tryCatch(car::vif(model), error = function(e) NULL)
      if (!is.null(vif_vals)) {
        max_vif <- max(vif_vals)
        status  <- if (max_vif < 5) "PASSED" else "WARNING"
        results[[length(results) + 1]] <- list(
          assumption = "Multicollinearity (VIF)",
          status     = status,
          detail     = sprintf(
            "Maximum VIF = %.2f. %s", max_vif,
            if (status == "PASSED") {
              "No strong evidence of multicollinearity."
            } else {
              "Evidence of multicollinearity (VIF >= 5). Consider removing or combining correlated predictors."
            }
          )
        )
      }
    }
  }

  output <- list(
    test    = test,
    results = results
  )

  class(output) <- "statease_assumptions"
  output
}

#' @export
print.statease_assumptions <- function(x, ...) {
  cat("\n")
  cat("-- statease Assumption Check Report -------------------------------\n")
  cat(sprintf("  Test         : %s\n", x$test))
  cat("---------------------------------------------------------------------\n")

  for (r in x$results) {
    status_label <- switch(r$status,
                           "PASSED"  = "[PASSED]",
                           "WARNING" = "[WARNING]",
                           "FAILED"  = "[FAILED]",
                           "INFO"    = "[INFO]"
    )
    cat(sprintf("\n  %s %s\n", status_label, r$assumption))
    cat(sprintf("    %s\n", r$detail))
  }

  cat("\n---------------------------------------------------------------------\n")
  cat("  NOTE: Assumption checks are based on statistical tests and\n")
  cat("  heuristics. They provide guidance but should not be\n")
  cat("  interpreted as definitive proof that assumptions are met\n")
  cat("  or violated.\n\n")
  cat("  NOTE: Failure to reject an assumption test does not prove\n")
  cat("  that the assumption has been satisfied.\n\n")
  cat("  NOTE: Visual inspection of residual plots is always\n")
  cat("  recommended alongside formal assumption tests.\n")
  cat("---------------------------------------------------------------------\n\n")
  invisible(x)
}

#' statease: Simplified Statistical Analysis with Plain-English Interpretation
#'
#' @description
#' statease provides a suite of functions for performing common statistical
#' analyses and automatically interpreting the results in plain English.
#' It is designed for students, researchers, and educators who want fast,
#' readable statistical output without sacrificing rigour.
#'
#' @section Main Functions:
#' \describe{
#'   \item{\code{\link{analyze}}}{Master function — auto-detects and runs the right test}
#'   \item{\code{\link{describe}}}{Descriptive statistics with interpretation}
#'   \item{\code{\link{ttest_interpret}}}{T-tests (one-sample, independent, paired) with Cohen's d}
#'   \item{\code{\link{anova_interpret}}}{One-way ANOVA with Tukey post-hoc and eta squared}
#'   \item{\code{\link{interpret_p}}}{Standalone p-value interpreter}
#' }
#'
#' @section Typical Workflow:
#' The simplest way to use statease is through the master \code{analyze()}
#' function, which automatically detects what test to run based on your input:
#'
#' \preformatted{
#' # Descriptive statistics
#' analyze(x = my_vector, var_name = "My Variable")
#'
#' # Independent samples t-test
#' analyze(x = group1, y = group2, var_name = "Scores")
#'
#' # One-way ANOVA
#' analyze(formula = score ~ group, data = my_df)
#'
#' # Interpret a p-value
#' interpret_p(0.03, context = "treatment vs control")
#' }
#'
#' @author Uwakmfon Usen Paul
#'
#' @importFrom stats IQR TukeyHSD aov bartlett.test median na.omit quantile sd shapiro.test t.test var.test chisq.test cor.test lm confint confint.default residuals fitted pf coef glm binomial pchisq manova wilcox.test kruskal.test qnorm summary.aov contr.sum fisher.test mcnemar.test friedman.test p.adjust as.formula ks.test
#' @importFrom utils combn
#' @docType package
#' @name statease
"_PACKAGE"

#' MANOVA with Plain-English Interpretation
#'
#' @param formula A formula of the form cbind(outcome1, outcome2, ...) ~ group
#' @param data A data frame containing the variables
#' @param conf.level Confidence level. Default 0.95.
#'
#' @return An object of class \code{statease_manova} containing MANOVA
#'   results and interpretation. Use \code{print()} to display the
#'   formatted report.
#' @export
#'
#' @examples
#' df <- data.frame(
#'   math    = c(23,45,12,67,34,89,56,43,78,90,11,34),
#'   english = c(34,56,23,78,45,90,67,54,89,95,22,45),
#'   group   = rep(c("A","B","C"), each = 4)
#' )
#' result <- manova_interpret(cbind(math, english) ~ group, data = df)
#' print(result)
manova_interpret <- function(formula, data, conf.level = 0.95) {

  # --- Guard clauses ---
  if (!inherits(formula, "formula")) {
    stop("Please provide a valid formula e.g. cbind(y1, y2) ~ group")
  }
  if (!is.data.frame(data)) stop("data must be a data frame.")
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }

  alpha <- 1 - conf.level

  # --- Extract variable names ---
  vars      <- all.vars(formula)
  group_var <- vars[length(vars)]
  outcomes  <- vars[-length(vars)]

  # --- Check variables exist ---
  for (v in vars) {
    if (!v %in% names(data)) {
      stop(sprintf("Variable '%s' not found in data.", v))
    }
  }

  # --- Check outcomes are numeric ---
  for (o in outcomes) {
    if (!is.numeric(data[[o]])) {
      stop(sprintf("Outcome variable '%s' must be numeric.", o))
    }
  }

  # --- Check at least two outcomes ---
  if (length(outcomes) < 2) {
    stop("MANOVA requires at least two outcome variables e.g. cbind(y1, y2) ~ group")
  }

  # --- Convert group to factor ---
  data[[group_var]] <- as.factor(data[[group_var]])
  groups            <- levels(data[[group_var]])
  n_groups          <- length(groups)

  if (n_groups < 2) stop("Group variable must have at least 2 levels.")

  # --- Sample size check ---
  n <- nrow(na.omit(data[, vars]))
  if (n < 20) {
    warning("Sample size is small (n < 20). Interpret results with caution.")
  }

  # --- Group means for each outcome ---
  group_means <- list()
  for (o in outcomes) {
    group_means[[o]] <- tapply(data[[o]], data[[group_var]],
                               mean, na.rm = TRUE)
  }

  # --- Run MANOVA ---
  model     <- manova(formula, data = data)
  model_sum <- summary(model, test = "Pillai")
  model_sum_wilks <- summary(model, test = "Wilks")

  # --- Extract Pillai's trace ---
  pillai    <- model_sum$stats[1, 2]
  f_val     <- model_sum$stats[1, 3]
  df1       <- model_sum$stats[1, 4]
  df2       <- model_sum$stats[1, 5]
  p_val     <- model_sum$stats[1, 6]

  # --- Extract Wilks lambda ---
  wilks     <- model_sum_wilks$stats[1, 2]

  # --- Effect size (Pillai's trace is itself an effect size) ---
  effect_label <- if (pillai < 0.1) {
    "negligible"
  } else if (pillai < 0.3) {
    "small"
  } else if (pillai < 0.5) {
    "moderate"
  } else {
    "large"
  }

  # --- Significance ---
  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)", p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)", p_val, alpha)
  }

  # --- Follow-up univariate ANOVAs ---
  univariate  <- summary.aov(model)
  uni_results <- list()
  for (i in seq_along(outcomes)) {
    o       <- outcomes[i]
    uni_sum <- tryCatch({
      as.data.frame(univariate[[i]])
    }, error = function(e) NULL)

    if (!is.null(uni_sum) && nrow(uni_sum) >= 2) {
      f_uni   <- uni_sum[1, "F value"]
      p_uni   <- uni_sum[1, "Pr(>F)"]
      df1_uni <- uni_sum[1, "Df"]
      df2_uni <- uni_sum[2, "Df"]
      sig_uni <- if (!is.na(p_uni) && p_uni < alpha) {
        "significant"
      } else {
        "not significant"
      }
    } else {
      f_uni   <- NA
      p_uni   <- NA
      df1_uni <- NA
      df2_uni <- NA
      sig_uni <- "could not be computed"
    }

    uni_results[[o]] <- list(
      outcome = o,
      f_val   = f_uni,
      df1     = df1_uni,
      df2     = df2_uni,
      p_val   = p_uni,
      sig     = sig_uni
    )
  }

  # --- Normality check ---
  normality_notes <- c()
  for (o in outcomes) {
    vals <- na.omit(data[[o]])
    if (length(vals) >= 3 && length(vals) <= 5000) {
      sw <- shapiro.test(vals)
      if (sw$p.value < 0.05) {
        normality_notes <- c(normality_notes,
                             sprintf("WARNING: '%s' may not be normally distributed (Shapiro-Wilk p = %.4f).",
                                     o, sw$p.value))
      }
    }
  }

  output <- list(
    outcomes        = outcomes,
    group_var       = group_var,
    groups          = groups,
    n_groups        = n_groups,
    n               = n,
    group_means     = group_means,
    pillai          = pillai,
    wilks           = wilks,
    f_val           = f_val,
    df1             = df1,
    df2             = df2,
    p_val           = p_val,
    effect_label    = effect_label,
    sig_label       = sig_label,
    uni_results     = uni_results,
    normality_notes = normality_notes,
    alpha           = alpha,
    conf.level      = conf.level
  )

  class(output) <- "statease_manova"
  output
}

#' @export
print.statease_manova <- function(x, ...) {
  cat("\n")
  cat("-- statease MANOVA Report ----------------------------------------\n")
  cat(sprintf("  Outcomes     : %s\n", paste(x$outcomes, collapse = ", ")))
  cat(sprintf("  Group        : %s  (%d levels)\n", x$group_var, x$n_groups))
  cat(sprintf("  N            : %d\n", x$n))
  cat("-----------------------------------------------------------------\n")
  cat("  Group Means:\n")
  for (o in x$outcomes) {
    cat(sprintf("\n  %s:\n", o))
    for (g in x$groups) {
      cat(sprintf("    %-12s : %.2f\n", g, x$group_means[[o]][g]))
    }
  }
  cat("-----------------------------------------------------------------\n")
  cat("  Multivariate Test Results:\n")
  cat(sprintf("  Pillai's Trace : %.4f\n", x$pillai))
  cat(sprintf("  Wilks' Lambda  : %.4f\n", x$wilks))
  cat(sprintf("  F-statistic    : %.3f  (df = %.0f, %.0f)\n",
              x$f_val, x$df1, x$df2))
  cat(sprintf("  p-value        : %.4f\n", x$p_val))
  cat(sprintf("  Effect size    : %s (Pillai = %.4f)\n",
              x$effect_label, x$pillai))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The overall MANOVA result is %s.\n", x$sig_label))
  cat(sprintf("  Pillai's Trace = %.4f indicates a %s effect.\n",
              x$pillai, x$effect_label))
  cat("-----------------------------------------------------------------\n")
  cat("  Follow-Up Univariate ANOVAs:\n")
  for (o in x$outcomes) {
    ur <- x$uni_results[[o]]
    cat(sprintf("\n  %s\n", o))
    cat(sprintf("    F = %.3f  (df = %d, %d)  p = %.4f  [%s]\n",
                ur$f_val, ur$df1, ur$df2, ur$p_val, ur$sig))
  }
  cat("\n")
  cat("  Note: Follow-up ANOVAs identify which outcomes\n")
  cat("  differ significantly across groups.\n")
  if (length(x$normality_notes) > 0) {
    cat("\n")
    for (note in x$normality_notes) cat(sprintf("  %s\n", note))
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

#' Power Analysis with Plain English Interpretation
#'
#' @param test The statistical test. One of "ttest.one",
#'   "ttest.two", "ttest.paired", "anova", "correlation",
#'   "chisq", "regression".
#' @param effect_size The expected effect size. Use Cohen's
#'   conventions: small = 0.2, medium = 0.5, large = 0.8
#'   for t-tests; small = 0.10, medium = 0.25, large = 0.40
#'   for ANOVA; small = 0.10, medium = 0.30, large = 0.50
#'   for correlation.
#' @param n Sample size per group. If provided, calculates
#'   achieved power. If NULL, calculates required sample size.
#' @param alpha Significance level. Default 0.05.
#' @param power Desired power level. Default 0.80.
#' @param n_groups Number of groups (for ANOVA only). Default 2.
#' @param n_predictors Number of predictors (for regression only).
#'   Default 1.
#'
#' @return An object of class \code{statease_power} containing
#'   power analysis results and interpretation. Use \code{print()}
#'   to display the formatted report.
#' @export
#'
#' @examples
#' # Calculate required sample size for independent t-test
#' result <- power_interpret("ttest.two", effect_size = 0.5)
#' print(result)
#'
#' # Calculate achieved power for given sample size
#' result2 <- power_interpret("ttest.two", effect_size = 0.5, n = 30)
#' print(result2)
power_interpret <- function(test, effect_size, n = NULL,
                            alpha = 0.05, power = 0.80,
                            n_groups = 2, n_predictors = 1) {

  #Guard clauses
  valid_tests <- c("ttest.one", "ttest.two", "ttest.paired",
                   "anova", "correlation", "chisq", "regression")
  if (!test %in% valid_tests) {
    stop(sprintf("test must be one of: %s",
                 paste(valid_tests, collapse = ", ")))
  }
  if (!is.numeric(effect_size) || effect_size <= 0) {
    stop("effect_size must be a positive numeric value.")
  }
  if (alpha <= 0 || alpha >= 1) {
    stop("alpha must be between 0 and 1.")
  }
  if (power <= 0 || power >= 1) {
    stop("power must be between 0 and 1.")
  }

  # -Mode
  mode <- if (is.null(n)) "sample_size" else "power"

  # Effect size label
  es_label <- function(es, type = "d") {
    thresholds <- switch(type,
                         "d" = c(0.2, 0.5, 0.8),
                         "f" = c(0.10, 0.25, 0.40),
                         "r" = c(0.10, 0.30, 0.50),
                         "w" = c(0.10, 0.30, 0.50),
                         "f2" = c(0.02, 0.15, 0.35),
                         c(0.2, 0.5, 0.8)
    )
    if (es < thresholds[1]) "small" else if
    (es < thresholds[2]) "medium" else "large"
  }

  # Run power analysis
  result_val  <- NULL
  test_label  <- NULL
  es_type     <- "d"

  if (test == "ttest.one") {
    test_label <- "One-Sample T-Test"
    es_type    <- "d"
    if (mode == "sample_size") {
      pw         <- pwr::pwr.t.test(d = effect_size,
                                    sig.level = alpha,
                                    power = power,
                                    type = "one.sample")
      result_val <- ceiling(pw$n)
    } else {
      pw         <- pwr::pwr.t.test(d = effect_size,
                                    n = n,
                                    sig.level = alpha,
                                    type = "one.sample")
      result_val <- pw$power
    }

  } else if (test == "ttest.two") {
    test_label <- "Independent Samples T-Test"
    es_type    <- "d"
    if (mode == "sample_size") {
      pw         <- pwr::pwr.t.test(d = effect_size,
                                    sig.level = alpha,
                                    power = power,
                                    type = "two.sample")
      result_val <- ceiling(pw$n)
    } else {
      pw         <- pwr::pwr.t.test(d = effect_size,
                                    n = n,
                                    sig.level = alpha,
                                    type = "two.sample")
      result_val <- pw$power
    }

  } else if (test == "ttest.paired") {
    test_label <- "Paired Samples T-Test"
    es_type    <- "d"
    if (mode == "sample_size") {
      pw         <- pwr::pwr.t.test(d = effect_size,
                                    sig.level = alpha,
                                    power = power,
                                    type = "paired")
      result_val <- ceiling(pw$n)
    } else {
      pw         <- pwr::pwr.t.test(d = effect_size,
                                    n = n,
                                    sig.level = alpha,
                                    type = "paired")
      result_val <- pw$power
    }

  } else if (test == "anova") {
    test_label <- "One-Way ANOVA"
    es_type    <- "f"
    if (mode == "sample_size") {
      pw         <- pwr::pwr.anova.test(k = n_groups,
                                        f = effect_size,
                                        sig.level = alpha,
                                        power = power)
      result_val <- ceiling(pw$n)
    } else {
      pw         <- pwr::pwr.anova.test(k = n_groups,
                                        n = n,
                                        f = effect_size,
                                        sig.level = alpha)
      result_val <- pw$power
    }

  } else if (test == "correlation") {
    test_label <- "Correlation"
    es_type    <- "r"
    if (mode == "sample_size") {
      pw         <- pwr::pwr.r.test(r = effect_size,
                                    sig.level = alpha,
                                    power = power)
      result_val <- ceiling(pw$n)
    } else {
      pw         <- pwr::pwr.r.test(r = effect_size,
                                    n = n,
                                    sig.level = alpha)
      result_val <- pw$power
    }

  } else if (test == "chisq") {
    test_label <- "Chi-Square Test"
    es_type    <- "w"
    if (mode == "sample_size") {
      pw         <- pwr::pwr.chisq.test(w = effect_size,
                                        sig.level = alpha,
                                        power = power)
      result_val <- ceiling(pw$N)
    } else {
      pw         <- pwr::pwr.chisq.test(w = effect_size,
                                        N = n,
                                        sig.level = alpha)
      result_val <- pw$power
    }

  } else if (test == "regression") {
    test_label <- sprintf("Multiple Regression (fixed model, %d predictors)",
                          n_predictors)
    es_type    <- "f2"
    if (mode == "sample_size") {
      pw         <- pwr::pwr.f2.test(u = n_predictors,
                                     f2 = effect_size,
                                     sig.level = alpha,
                                     power = power)
      result_val <- ceiling(pw$v + n_predictors + 1)
    } else {
      pw         <- pwr::pwr.f2.test(u = n_predictors,
                                     v = n - n_predictors - 1,
                                     f2 = effect_size,
                                     sig.level = alpha)
      result_val <- pw$power
    }
  }

  # Interpretation
  effect_label <- es_label(effect_size, es_type)

  if (mode == "sample_size") {
    result_interpretation <- sprintf(
      paste("To detect a %s effect (effect size = %.2f) with",
            "%.0f%% power at alpha = %.2f, you need at least",
            "%d participants%s."),
      effect_label, effect_size, power * 100, alpha,
      result_val,
      if (test == "ttest.two" || test == "anova") {
        sprintf(" per group (%d total for %d groups)",
                result_val * n_groups, n_groups)
      } else ""
    )
  } else {
    result_interpretation <- sprintf(
      paste("With n = %d and a %s effect size (%.2f),",
            "the achieved power is %.1f%%."),
      n, effect_label, effect_size, result_val * 100
    )
  }

  # Warnings and Notes
  warnings_list <- c()
  notes_list    <- c()

  if (mode == "power" && result_val < 0.80) {
    warnings_list <- c(warnings_list,
                       paste("Power is less than 0.80. The study may be",
                             "underpowered, there is a meaningful risk of",
                             "failing to detect a true effect (Type II error).",
                             "Consider increasing the sample size."))
  }

  if (effect_size < 0.10) {
    warnings_list <- c(warnings_list,
                       paste("The effect size provided is very small.",
                             "A very large sample size will be required",
                             "to detect this effect reliably. Ensure the",
                             "effect size is theoretically and practically",
                             "meaningful before proceeding."))
  }

  if (mode == "power") {
    warnings_list <- c(warnings_list,
                       paste("Post-hoc (observed) power calculations should",
                             "be interpreted cautiously, as they are largely",
                             "determined by the observed p-value and effect size."))
  }

  notes_list <- c(notes_list,
                  paste("Power analysis results are estimates based on",
                        "assumptions about effect size, alpha, and power.",
                        "Actual results may differ depending on the true",
                        "effect size in the population."))

  notes_list <- c(notes_list,
                  paste("Effect sizes should ideally be based on previous",
                        "research, pilot studies, or theoretically justified",
                        "values, not chosen arbitrarily to reduce required",
                        "sample size."))

  notes_list <- c(notes_list,
                  paste("A power of 0.80 is a conventional minimum.",
                        "In high stakes research such as clinical trials,",
                        "a higher power of 0.90 or 0.95 is often recommended."))

  notes_list <- c(notes_list,
                  paste("Power analysis assumes that the chosen statistical",
                        "test and its assumptions are appropriate for the data."))

  output <- list(
    test                     = test,
    test_label               = test_label,
    mode                     = mode,
    effect_size              = effect_size,
    effect_label             = effect_label,
    es_type                  = es_type,
    n                        = n,
    alpha                    = alpha,
    power                    = power,
    n_groups                 = n_groups,
    n_predictors             = n_predictors,
    result_val               = result_val,
    result_interpretation    = result_interpretation,
    warnings_list            = warnings_list,
    notes_list               = notes_list
  )

  class(output) <- "statease_power"
  output
}

#' @export
print.statease_power <- function(x, ...) {
  cat("\n")
  cat("-- statease Power Analysis Report  \n")
  cat(sprintf("  Test         : %s\n", x$test_label))
  cat(sprintf("  Mode         : %s\n",
              if (x$mode == "sample_size") {
                "Calculate required sample size"
              } else {
                "Calculate achieved power"
              }))
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  Effect size  : %.3f (%s)\n",
              x$effect_size, x$effect_label))
  cat(sprintf("  Alpha        : %.2f\n", x$alpha))
  if (x$mode == "sample_size") {
    cat(sprintf("  Desired power: %.2f (%.0f%%)\n",
                x$power, x$power * 100))
    cat(sprintf("  Required n   : %d\n", x$result_val))
    if (x$test %in% c("ttest.two", "anova")) {
      cat(sprintf("  Total N      : %d (%d groups x %d)\n",
                  x$result_val * x$n_groups,
                  x$n_groups, x$result_val))
    }
  } else {
    cat(sprintf("  Sample size  : %d\n", x$n))
    cat(sprintf("  Achieved power: %.4f (%.1f%%)\n",
                x$result_val, x$result_val * 100))
  }
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  %s\n", x$result_interpretation))

  if (length(x$warnings_list) > 0) {
    cat("\n")
    for (w in x$warnings_list) {
      cat(sprintf("  WARNING: %s\n", w))
    }
  }

  if (length(x$notes_list) > 0) {
    cat("\n")
    for (n in x$notes_list) {
      cat(sprintf("  NOTE: %s\n", n))
    }
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

#' Friedman Test with Plain-English Interpretation
#'
#' @param formula A formula of the form outcome ~ time | subject
#' @param data A data frame containing the variables
#' @param conf.level Confidence level. Default 0.95.
#'
#' @return An object of class \code{statease_friedman} containing test
#'   results and interpretation. Use \code{print()} to display the
#'   formatted report.
#' @export
#'
#' @examples
#' df <- data.frame(
#'   score   = c(23,45,12,67,34,89,56,43,78,90,11,34),
#'   time    = rep(c("T1","T2","T3"), each = 4),
#'   subject = rep(1:4, times = 3)
#' )
#' result <- friedman_interpret(score ~ time | subject, data = df)
#' print(result)
friedman_interpret <- function(formula, data, conf.level = 0.95) {

  #Guard clauses
  if (!inherits(formula, "formula")) {
    stop("Please provide a valid formula e.g. score ~ time | subject")
  }
  if (!is.data.frame(data)) stop("data must be a data frame.")
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }

  alpha <- 1 - conf.level

  #Extract variables from formula
  formula_str <- deparse(formula)
  if (!grepl("\\|", formula_str)) {
    stop("Formula must include subject variable e.g. score ~ time | subject")
  }

  parts     <- strsplit(formula_str, "\\|")[[1]]
  left_part <- trimws(parts[1])
  subject   <- trimws(parts[2])
  left_vars <- all.vars(as.formula(left_part))
  outcome   <- left_vars[1]
  time_var  <- left_vars[2]

  #Check variables exist
  for (v in c(outcome, time_var, subject)) {
    if (!v %in% names(data)) {
      stop(sprintf("Variable '%s' not found in data.", v))
    }
  }

  #Check outcome is numeric
  if (!is.numeric(data[[outcome]])) {
    stop(sprintf("Outcome variable '%s' must be numeric.", outcome))
  }

  #Convert time and subject to factor
  data[[time_var]] <- as.factor(data[[time_var]])
  data[[subject]]  <- as.factor(data[[subject]])

  groups   <- levels(data[[time_var]])
  n_groups <- length(groups)
  n_subj   <- length(levels(data[[subject]]))

  if (n_groups < 3) {
    stop("Friedman Test requires at least 3 time points or conditions.")
  }

  # Sample size check
  if (n_subj < 10) {
    warning(paste("The Friedman Test may have low statistical power",
                  "with very small sample sizes.",
                  "Interpret non-significant results with caution."))
  }

  # Group medians
  group_medians <- tapply(data[[outcome]],
                          data[[time_var]],
                          median, na.rm = TRUE)

  # Run Friedman Test
  result  <- friedman.test(formula, data = data)
  chi_val <- result$statistic
  df      <- result$parameter
  p_val   <- result$p.value

  # Kendall's W (effect size)
  kendall_w <- chi_val / (n_subj * (n_groups - 1))

  w_label <- if (kendall_w < 0.1) {
    "negligible"
  } else if (kendall_w < 0.3) {
    "weak"
  } else if (kendall_w < 0.5) {
    "moderate"
  } else {
    "strong"
  }

  # Significance
  sig_label <- if (p_val < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)",
            p_val, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)",
            p_val, alpha)
  }

  # Result interpretation
  result_label <- if (p_val < alpha) {
    "There is evidence of a significant difference in ranks across the related groups or repeated measurements."
  } else {
    "There is insufficient evidence of a significant difference in ranks across the related groups or repeated measurements."
  }

  # Post-hoc pairwise Wilcoxon
  posthoc <- NULL
  if (p_val < alpha) {
    pairs     <- combn(groups, 2, simplify = FALSE)
    posthoc   <- list()
    p_vals_ph <- c()

    for (pair in pairs) {
      g1   <- pair[1]
      g2   <- pair[2]
      x1   <- data[[outcome]][data[[time_var]] == g1]
      x2   <- data[[outcome]][data[[time_var]] == g2]
      wt   <- suppressWarnings(
        wilcox.test(x1, x2, paired = TRUE, exact = FALSE)
      )
      comp           <- paste(g1, "vs", g2)
      p_vals_ph[comp] <- wt$p.value
    }

    # Bonferroni correction
    p_adj <- p.adjust(p_vals_ph, method = "bonferroni")

    for (comp in names(p_adj)) {
      posthoc[[comp]] <- list(
        comparison = comp,
        p_val      = p_vals_ph[comp],
        p_adj      = p_adj[comp],
        sig        = if (p_adj[comp] < alpha) {
          "[significant]"
        } else {
          "[not significant]"
        }
      )
    }
  }

  #Normality check
  normality_note <- NULL
  vals <- na.omit(data[[outcome]])
  if (length(vals) >= 3 && length(vals) <= 5000) {
    sw <- shapiro.test(vals)
    if (sw$p.value >= 0.05) {
      normality_note <- paste(
        "NOTE: Normality assumption appears reasonable.",
        "If the assumptions of repeated measures ANOVA",
        "are met, consider using repeated measures ANOVA",
        "for greater statistical power.")
    }
  }

  # Independence warning
  independence_warning <- paste(
    "The Friedman Test assumes that the blocks",
    "(subjects) are independent of each other.",
    "Violation of this assumption may affect",
    "the validity of the results.")

  output <- list(
    outcome              = outcome,
    time_var             = time_var,
    subject              = subject,
    n_groups             = n_groups,
    n_subj               = n_subj,
    groups               = groups,
    group_medians        = group_medians,
    chi_val              = chi_val,
    df                   = df,
    p_val                = p_val,
    kendall_w            = kendall_w,
    w_label              = w_label,
    sig_label            = sig_label,
    result_label         = result_label,
    posthoc              = posthoc,
    normality_note       = normality_note,
    independence_warning = independence_warning,
    conf.level           = conf.level,
    alpha                = alpha
  )

  class(output) <- "statease_friedman"
  output
}

#' @export
print.statease_friedman <- function(x, ...) {
  cat("\n")
  cat("-- statease Friedman Test Report \n")
  cat(sprintf("  Outcome      : %s\n", x$outcome))
  cat(sprintf("  Time/Group   : %s (%d levels)\n",
              x$time_var, x$n_groups))
  cat(sprintf("  Subjects     : %s (n = %d)\n",
              x$subject, x$n_subj))
  cat("-----------------------------------------------------------------\n")
  cat("  Group Medians (descriptive only):\n")
  for (g in x$groups) {
    cat(sprintf("    %-12s : %.2f\n", g, x$group_medians[g]))
  }
  cat("-----------------------------------------------------------------\n")
  cat(sprintf("  Chi-square   : %.3f\n", x$chi_val))
  cat(sprintf("  df           : %d\n", x$df))
  cat(sprintf("  p-value      : %.4f\n", x$p_val))
  cat(sprintf("  Kendall's W  : %.4f (%s effect)\n",
              x$kendall_w, x$w_label))
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The result is %s.\n", x$sig_label))
  cat(sprintf("  %s\n", x$result_label))
  cat("\n")
  cat("  NOTE: Medians are reported for descriptive purposes only.\n")
  cat("  The Friedman Test assesses whether rank distributions\n")
  cat("  differ across groups and does not directly test for\n")
  cat("  differences in medians.\n")

  if (!is.null(x$posthoc)) {
    cat("\n")
    cat("-- Post-Hoc Pairwise Wilcoxon Signed-Rank Tests -----------------\n")
    cat("  (Bonferroni correction applied)\n\n")
    for (comp in names(x$posthoc)) {
      ph <- x$posthoc[[comp]]
      cat(sprintf("  %s\n", ph$comparison))
      cat(sprintf("    p = %.4f  |  p adj = %.4f  |  %s\n",
                  ph$p_val, ph$p_adj, ph$sig))
    }
  } else {
    cat("\n  Post-hoc tests not run (overall result not significant).\n")
  }

  cat("\n")
  cat(sprintf("  WARNING: %s\n", x$independence_warning))

  if (!is.null(x$normality_note)) {
    cat(sprintf("\n  %s\n", x$normality_note))
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

#' Multiple Linear Regression with Plain-English Interpretation
#'
#' @param formula A formula of the form outcome ~ predictor1 + predictor2 + ...
#' @param data A data frame containing the variables
#' @param conf.level Confidence level. Default 0.95.
#'
#' @return An object of class \code{statease_mlr} containing multiple
#'   regression results and interpretation. Use \code{print()} to
#'   display the formatted report.
#' @export
#'
#' @examples
#' df <- data.frame(
#'   exam_score  = c(23,45,12,67,34,89,56,43,78,90),
#'   study_hours = c(2,5,1,7,3,9,6,4,8,10),
#'   attendance  = c(60,80,50,90,70,95,85,75,88,92)
#' )
#' result <- mlr_interpret(exam_score ~ study_hours + attendance, data = df)
#' print(result)
mlr_interpret <- function(formula, data, conf.level = 0.95) {

  # --- Guard clauses ---
  if (!inherits(formula, "formula")) {
    stop("Please provide a valid formula e.g. outcome ~ pred1 + pred2")
  }
  if (!is.data.frame(data)) stop("data must be a data frame.")
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }

  alpha <- 1 - conf.level
  vars  <- all.vars(formula)

  if (length(vars) < 3) {
    stop("Please provide at least two predictors e.g. outcome ~ pred1 + pred2")
  }

  outcome    <- vars[1]
  predictors <- vars[-1]

  # --- Check variables exist ---
  for (v in vars) {
    if (!v %in% names(data)) {
      stop(sprintf("Variable '%s' not found in data.", v))
    }
  }

  # --- Check outcome is numeric ---
  if (!is.numeric(data[[outcome]])) {
    stop(sprintf("Outcome variable '%s' must be numeric.", outcome))
  }

  # --- Sample size check ---
  n <- nrow(na.omit(data[, vars]))
  if (n < length(vars) + 1) {
    stop("Not enough observations for the number of predictors.")
  }
  if (n < 20) {
    warning("Sample size is small (n < 20). Interpret results with caution.")
  }

  # --- Run regression ---
  model     <- lm(formula, data = data)
  model_sum <- summary(model)
  coefs     <- coef(model_sum)
  ci        <- confint(model, level = conf.level)

  # --- Extract overall model fit ---
  r_squared     <- model_sum$r.squared
  adj_r_squared <- model_sum$adj.r.squared
  f_val         <- model_sum$fstatistic[1]
  f_df1         <- model_sum$fstatistic[2]
  f_df2         <- model_sum$fstatistic[3]
  f_p           <- pf(f_val, f_df1, f_df2, lower.tail = FALSE)

  # --- R-squared interpretation ---
  r_sq_label <- if (r_squared < 0.01) {
    "negligible"
  } else if (r_squared < 0.09) {
    "small"
  } else if (r_squared < 0.25) {
    "moderate"
  } else {
    "large"
  }

  # --- Overall model significance ---
  model_sig <- if (f_p < alpha) {
    sprintf("statistically significant (p = %.4f < alpha %.2f)", f_p, alpha)
  } else {
    sprintf("not statistically significant (p = %.4f > alpha %.2f)", f_p, alpha)
  }

  # --- Individual predictors ---
  predictor_results <- list()
  for (i in seq_along(predictors)) {
    pred     <- predictors[i]
    row_idx  <- i + 1
    b        <- coefs[row_idx, 1]
    se       <- coefs[row_idx, 2]
    t_val    <- coefs[row_idx, 3]
    p_val    <- coefs[row_idx, 4]
    ci_low   <- ci[row_idx, 1]
    ci_high  <- ci[row_idx, 2]

    sig <- if (p_val < alpha) "significant" else "not significant"

    direction <- if (b > 0) {
      sprintf("positive (b = %.3f)", b)
    } else {
      sprintf("negative (b = %.3f)", b)
    }

    predictor_results[[pred]] <- list(
      name      = pred,
      b         = b,
      se        = se,
      t_val     = t_val,
      p_val     = p_val,
      ci_low    = ci_low,
      ci_high   = ci_high,
      sig       = sig,
      direction = direction
    )
  }

  # --- Residual diagnostics ---
  res            <- residuals(model)
  normality_note <- NULL
  if (length(res) >= 3 && length(res) <= 5000) {
    sw <- shapiro.test(res)
    if (sw$p.value < 0.05) {
      normality_note <- sprintf(
        "WARNING: Residuals may not be normally distributed (Shapiro-Wilk p = %.4f).",
        sw$p.value)
    }
  }

  output <- list(
    outcome           = outcome,
    predictors        = predictors,
    n                 = n,
    intercept         = coefs[1, 1],
    r_squared         = r_squared,
    adj_r_squared     = adj_r_squared,
    r_sq_label        = r_sq_label,
    f_val             = f_val,
    f_df1             = f_df1,
    f_df2             = f_df2,
    f_p               = f_p,
    model_sig         = model_sig,
    predictor_results = predictor_results,
    conf.level        = conf.level,
    alpha             = alpha,
    normality_note    = normality_note
  )

  class(output) <- "statease_mlr"
  output
}

#' @export
print.statease_mlr <- function(x, ...) {
  cat("\n")
  cat("-- statease Multiple Linear Regression Report -------------------\n")
  cat(sprintf("  Outcome      : %s\n", x$outcome))
  cat(sprintf("  Predictors   : %s\n", paste(x$predictors, collapse = ", ")))
  cat(sprintf("  N            : %d\n", x$n))
  cat("-----------------------------------------------------------------\n")
  cat("  Model Equation:\n")
  cat(sprintf("  %s = %.3f", x$outcome, x$intercept))
  for (pred in x$predictors) {
    b <- x$predictor_results[[pred]]$b
    if (b >= 0) {
      cat(sprintf(" + %.3f*%s", b, pred))
    } else {
      cat(sprintf(" - %.3f*%s", abs(b), pred))
    }
  }
  cat("\n")
  cat("-----------------------------------------------------------------\n")
  cat("  Overall Model Fit:\n")
  cat(sprintf("  R-squared    : %.4f (%s effect)\n",
              x$r_squared, x$r_sq_label))
  cat(sprintf("  Adj R-squared: %.4f\n", x$adj_r_squared))
  cat(sprintf("  F-statistic  : %.3f (df = %.0f, %.0f)  p = %.4f\n",
              x$f_val, x$f_df1, x$f_df2, x$f_p))
  cat(sprintf("  The overall model is %s.\n", x$model_sig))
  cat("-----------------------------------------------------------------\n")
  cat("  Individual Predictors:\n")
  for (pred in x$predictors) {
    pr <- x$predictor_results[[pred]]
    cat(sprintf("\n  %s\n", pred))
    cat(sprintf("    Coefficient  : %.3f  (SE = %.3f)\n", pr$b, pr$se))
    cat(sprintf("    t-statistic  : %.3f\n", pr$t_val))
    cat(sprintf("    p-value      : %.4f  [%s]\n", pr$p_val, pr$sig))
    cat(sprintf("    %d%% CI      : [%.3f, %.3f]\n",
                as.integer(x$conf.level * 100), pr$ci_low, pr$ci_high))
    cat(sprintf("    Direction    : %s\n", pr$direction))
  }
  cat("-----------------------------------------------------------------\n")
  cat("  Interpretation:\n")
  cat(sprintf("  The model explains %.1f%% of the variance in %s\n",
              x$r_squared * 100, x$outcome))
  cat(sprintf("  (R-squared = %.4f, %s effect).\n",
              x$r_squared, x$r_sq_label))
  cat(sprintf("  Adjusted R-squared = %.4f accounting for\n",
              x$adj_r_squared))
  cat(sprintf("  the number of predictors in the model.\n"))

  sig_preds <- Filter(function(p) p$sig == "significant",
                      x$predictor_results)
  nonsig_preds <- Filter(function(p) p$sig == "not significant",
                         x$predictor_results)

  if (length(sig_preds) > 0) {
    cat(sprintf("\n  Significant predictors: %s\n",
                paste(names(sig_preds), collapse = ", ")))
  }
  if (length(nonsig_preds) > 0) {
    cat(sprintf("  Non-significant predictors: %s\n",
                paste(names(nonsig_preds), collapse = ", ")))
  }
  if (!is.null(x$normality_note)) {
    cat(sprintf("\n  %s\n", x$normality_note))
  }
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

#' Two-Way ANOVA with Plain-English Interpretation
#'
#' Uses Type-2 SS by default (safe for unbalanced designs). Automatically
#' switches to Type-3 SS when an interaction term is detected and sets
#' the correct contrasts. Users are warned when interpreting main effects
#' in the presence of a significant interaction.
#'
#' @param formula A formula of the form outcome ~ group1 * group2
#' @param data A data frame containing the variables
#' @param type ANOVA type: 2 or 3. Default is 2. Type 3 is automatically
#'   used when an interaction term is detected in the formula.
#' @param conf.level Confidence level. Default 0.95.
#'
#' @return An object of class \code{statease_anova2} containing two-way
#'   ANOVA results and interpretation. Use \code{print()} to display
#'   the formatted report.
#' @export
#'
#' @examples
#' df <- data.frame(
#'   score  = c(23,45,12,67,34,89,56,43,78,90,11,34),
#'   method = rep(c("Online","Traditional"), each = 6),
#'   gender = rep(c("Male","Female"), times = 6)
#' )
#' result <- anova2_interpret(score ~ method * gender, data = df)
#' print(result)
anova2_interpret <- function(formula, data, type = 2, conf.level = 0.95) {

  # --- Guard clauses ---
  if (!inherits(formula, "formula")) {
    stop("Please provide a valid formula e.g. outcome ~ group1 * group2")
  }
  if (!is.data.frame(data)) stop("data must be a data frame.")
  # Standardize type
  type <- as.character(type)
  type <- toupper(type)
  type <- if (type %in% c("II", "2")) "II" else if
  (type %in% c("III", "3")) "III" else
    stop("type must be 'II' or 'III' (or numeric 2 or 3).")
  if (conf.level <= 0 || conf.level >= 1) {
    stop("conf.level must be between 0 and 1.")
  }

  alpha        <- 1 - conf.level
  formula_str  <- deparse(formula)
  vars         <- all.vars(formula)
  has_interaction <- grepl("\\*", formula_str)

  outcome   <- vars[1]
  group1    <- vars[2]
  group2    <- vars[3]

  # --- Auto switch to Type-3 if interaction detected ---
  if (has_interaction && type == 2) {
    type <- 3
    message("[statease] Interaction term detected -> Automatically using Type-3 SS.")
  }

  # --- Check variables exist ---
  if (!outcome %in% names(data)) {
    stop(sprintf("Outcome variable '%s' not found in data.", outcome))
  }
  if (!group1 %in% names(data)) {
    stop(sprintf("Group variable '%s' not found in data.", group1))
  }
  if (!group2 %in% names(data)) {
    stop(sprintf("Group variable '%s' not found in data.", group2))
  }

  # --- Check outcome is numeric ---
  if (!is.numeric(data[[outcome]])) {
    stop(sprintf("Outcome variable '%s' must be numeric.", outcome))
  }

  # --- Convert groups to factors ---
  data[[group1]] <- as.factor(data[[group1]])
  data[[group2]] <- as.factor(data[[group2]])

  # --- Sample size check ---
  n <- nrow(na.omit(data[, c(outcome, group1, group2)]))
  if (n < 4) stop("At least 4 complete observations are required.")
  if (n < 20) {
    warning("Sample size is small (n < 20). Interpret results with caution.")
  }

  # --- Group means ---
  means_g1 <- tapply(data[[outcome]], data[[group1]], mean, na.rm = TRUE)
  means_g2 <- tapply(data[[outcome]], data[[group2]], mean, na.rm = TRUE)
  means_interaction <- tapply(
    data[[outcome]],
    list(data[[group1]], data[[group2]]),
    mean, na.rm = TRUE
  )

  # --- Run linear model ---
  # For Type III, set contrasts to contr.sum for proper interpretation
  if (type == "III") {
    contrast_list <- list(
      contr.sum,
      contr.sum
    )
    names(contrast_list) <- c(group1, group2)
    model <- lm(formula, data = data, contrasts = contrast_list)
  } else {
    model <- lm(formula, data = data)
  }

  # --- Run car::Anova ---
  aov_result <- car::Anova(model, type = type)
  aov_df     <- as.data.frame(aov_result)

  # --- Extract main effects and interaction ---
  f_g1   <- aov_df[group1, "F value"]
  f_g2   <- aov_df[group2, "F value"]
  p_g1   <- aov_df[group1, "Pr(>F)"]
  p_g2   <- aov_df[group2, "Pr(>F)"]
  df_g1  <- aov_df[group1, "Df"]
  df_g2  <- aov_df[group2, "Df"]
  df_res <- aov_df["Residuals", "Df"]

  # --- Interaction (if present) ---
  int_label <- paste0(group1, ":", group2)
  has_int_row <- int_label %in% rownames(aov_df)

  f_int  <- if (has_int_row) aov_df[int_label, "F value"] else NA
  p_int  <- if (has_int_row) aov_df[int_label, "Pr(>F)"] else NA
  df_int <- if (has_int_row) aov_df[int_label, "Df"] else NA

  # --- Eta squared ---
  ss_g1  <- aov_df[group1, "Sum Sq"]
  ss_g2  <- aov_df[group2, "Sum Sq"]
  ss_int <- if (has_int_row) aov_df[int_label, "Sum Sq"] else 0
  ss_res <- aov_df["Residuals", "Sum Sq"]
  ss_tot <- ss_g1 + ss_g2 + ss_int + ss_res

  eta_g1  <- ss_g1 / ss_tot
  eta_g2  <- ss_g2 / ss_tot
  eta_int <- if (has_int_row) ss_int / ss_tot else NA

  # --- Effect size labels ---
  eta_label <- function(e) {
    if (is.na(e)) return("NA")
    if (e < 0.01) "negligible" else if
    (e < 0.06) "small" else if
    (e < 0.14) "moderate" else "large"
  }

  # --- Significance labels ---
  sig <- function(p) {
    if (is.na(p)) return("NA")
    if (p < alpha) {
      sprintf("significant (p = %.4f)", p)
    } else {
      sprintf("not significant (p = %.4f)", p)
    }
  }

  # --- Interaction warning ---
  interaction_warning <- NULL
  if (has_int_row && !is.na(p_int) && p_int < alpha) {
    interaction_warning <- paste(
      "WARNING: A significant interaction was detected.",
      "Interpret main effects with caution - the effect of",
      group1, "depends on the level of", group2,
      "(and vice versa). Consider examining interaction plots",
      "before drawing conclusions about main effects."
    )
  }

  # --- Normality check ---
  normality_note <- NULL
  res <- residuals(model)
  if (length(res) >= 3 && length(res) <= 5000) {
    sw <- shapiro.test(res)
    if (sw$p.value < 0.05) {
      normality_note <- sprintf(
        "WARNING: Residuals may not be normally distributed (Shapiro-Wilk p = %.4f).",
        sw$p.value)
    }
  }

  # --- Homogeneity of variance ---
  variance_note <- NULL
  bart <- tryCatch(
    bartlett.test(data[[outcome]] ~
                    interaction(data[[group1]], data[[group2]])),
    error = function(e) NULL
  )
  if (!is.null(bart) && bart$p.value < 0.05) {
    variance_note <- sprintf(
      "WARNING: Bartlett's test suggests unequal variances (p = %.4f).",
      bart$p.value)
  }

  # --- Post-hoc Tukey ---
  aov_model <- aov(formula, data = data)
  tukey_g1  <- NULL
  tukey_g2  <- NULL

  if (!is.na(p_g1) && p_g1 < alpha &&
      length(levels(data[[group1]])) > 2) {
    tukey    <- TukeyHSD(aov_model, conf.level = conf.level)
    tukey_g1 <- as.data.frame(tukey[[group1]])
    tukey_g1$comparison <- rownames(tukey_g1)
  }
  if (!is.na(p_g2) && p_g2 < alpha &&
      length(levels(data[[group2]])) > 2) {
    tukey    <- TukeyHSD(aov_model, conf.level = conf.level)
    tukey_g2 <- as.data.frame(tukey[[group2]])
    tukey_g2$comparison <- rownames(tukey_g2)
  }

  output <- list(
    outcome              = outcome,
    group1               = group1,
    group2               = group2,
    n                    = n,
    type                 = type,
    has_interaction      = has_interaction,
    means_g1             = means_g1,
    means_g2             = means_g2,
    means_interaction    = means_interaction,
    f_g1                 = f_g1,
    f_g2                 = f_g2,
    f_int                = f_int,
    p_g1                 = p_g1,
    p_g2                 = p_g2,
    p_int                = p_int,
    df_g1                = df_g1,
    df_g2                = df_g2,
    df_int               = df_int,
    df_res               = df_res,
    eta_g1               = eta_g1,
    eta_g2               = eta_g2,
    eta_int              = eta_int,
    eta_label            = eta_label,
    sig                  = sig,
    tukey_g1             = tukey_g1,
    tukey_g2             = tukey_g2,
    interaction_warning  = interaction_warning,
    normality_note       = normality_note,
    variance_note        = variance_note,
    alpha                = alpha,
    conf.level           = conf.level
  )

  class(output) <- "statease_anova2"
  output
}

#' @export
print.statease_anova2 <- function(x, ...) {
  cat("\n")
  cat(" statease Two-Way ANOVA Report \n")
  cat(sprintf("  Outcome      : %s\n", x$outcome))
  cat(sprintf("  Factor 1     : %s\n", x$group1))
  cat(sprintf("  Factor 2     : %s\n", x$group2))
  cat(sprintf("  N            : %d\n", x$n))
  cat(sprintf("  SS Type      : Type-%s\n", x$ss_type))
  cat("\n")
  cat(sprintf("  Means by %s:\n", x$group1))
  for (g in names(x$means_g1)) {
    cat(sprintf("    %-15s : %.2f\n", g, x$means_g1[g]))
  }
  cat(sprintf("\n  Means by %s:\n", x$group2))
  for (g in names(x$means_g2)) {
    cat(sprintf("    %-15s : %.2f\n", g, x$means_g2[g]))
  }
  cat("\n  Interaction Means:\n")
  print(round(x$means_interaction, 2))
  cat("\n")
  cat("  ANOVA Results:\n")
  cat(sprintf("  %-20s : F = %.3f  df = %.0f,%.0f  %s  eta^2 = %.4f (%s)\n",
              x$group1, x$f_g1, x$df_g1, x$df_res,
              x$sig(x$p_g1), x$eta_g1, x$eta_label(x$eta_g1)))
  cat(sprintf("  %-20s : F = %.3f  df = %.0f,%.0f  %s  eta^2 = %.4f (%s)\n",
              x$group2, x$f_g2, x$df_g2, x$df_res,
              x$sig(x$p_g2), x$eta_g2, x$eta_label(x$eta_g2)))
  if (x$has_interaction && !is.na(x$f_int)) {
    cat(sprintf("  %-20s : F = %.3f  df = %.0f,%.0f  %s  eta^2 = %.4f (%s)\n",
                "Interaction", x$f_int, x$df_int, x$df_res,
                x$sig(x$p_int), x$eta_int, x$eta_label(x$eta_int)))
  }
  cat("\n")
  cat("  Interpretation:\n")
  cat(sprintf("  Main effect of %s is %s.\n", x$group1, x$sig(x$p_g1)))
  cat(sprintf("  Main effect of %s is %s.\n", x$group2, x$sig(x$p_g2)))
  if (x$has_interaction && !is.na(x$p_int)) {
    cat(sprintf("  Interaction (%s x %s) is %s.\n",
                x$group1, x$group2, x$sig(x$p_int)))
  }

  # --- Interaction warning ---
  if (!is.null(x$interaction_warning)) {
    cat("\n")
    cat(sprintf("  %s\n", x$interaction_warning))
  }

  # --- Post-hoc ---
  if (!is.null(x$tukey_g1)) {
    cat("\n")
    cat(sprintf("-- Post-Hoc Tukey HSD (%s) ------------------------------\n",
                x$group1))
    for (i in seq_len(nrow(x$tukey_g1))) {
      sig <- if (x$tukey_g1$`p adj`[i] < x$alpha) {
        "[significant]"
      } else {
        "[not significant]"
      }
      cat(sprintf("  %s : diff = %.3f  p adj = %.4f  %s\n",
                  x$tukey_g1$comparison[i],
                  x$tukey_g1$diff[i],
                  x$tukey_g1$`p adj`[i], sig))
    }
  }
  if (!is.null(x$tukey_g2)) {
    cat("\n")
    cat(sprintf("-- Post-Hoc Tukey HSD (%s) ------------------------------\n",
                x$group2))
    for (i in seq_len(nrow(x$tukey_g2))) {
      sig <- if (x$tukey_g2$`p adj`[i] < x$alpha) {
        "[significant]"
      } else {
        "[not significant]"
      }
      cat(sprintf("  %s : diff = %.3f  p adj = %.4f  %s\n",
                  x$tukey_g2$comparison[i],
                  x$tukey_g2$diff[i],
                  x$tukey_g2$`p adj`[i], sig))
    }
  }

  if (!is.null(x$normality_note)) cat(sprintf("\n  %s\n", x$normality_note))
  if (!is.null(x$variance_note)) cat(sprintf("  %s\n", x$variance_note))
  cat("-----------------------------------------------------------------\n\n")
  invisible(x)
}

---
title: "Introduction to statease"
author: "Uwakmfon Paul"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Introduction to statease}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
library(statease)
```

## Overview

**statease** is an R package designed to simplify statistical analysis
by combining a wide range of tests with automatic plain-English
interpretation of results. Whether you are a student, researcher, or
educator, statease gives you numbers and meaning in one command.

---

## Installation

```{r eval=FALSE}
# Install from CRAN
install.packages("statease")

# Load the package
library(statease)
```

---

## Dataset

Throughout this vignette we use a simulated dataset of 90 students
examining the effect of teaching methods on exam performance.

```{r}
set.seed(42)

tutorial_data <- data.frame(
  student_id = 1:90,
  method     = rep(c("Traditional", "Online", "Hybrid"), each = 30),
  gender     = rep(c("Male", "Female"), times = 45),
  exam_score = c(
    round(rnorm(30, mean = 65, sd = 10)),
    round(rnorm(30, mean = 72, sd = 10)),
    round(rnorm(30, mean = 78, sd = 10))
  ),
  pre_test = c(
    round(rnorm(30, mean = 55, sd = 10)),
    round(rnorm(30, mean = 58, sd = 10)),
    round(rnorm(30, mean = 57, sd = 10))
  ),
  age        = round(rnorm(90, mean = 22, sd = 3)),
  passed     = rbinom(90, 1, prob = 0.7)
)

head(tutorial_data)
```

---

## 1. Descriptive Statistics

The `describe()` function provides a full summary of a numeric variable
including measures of central tendency, spread, and a normality check.

```{r}
result <- describe(tutorial_data$exam_score,
                   var_name = "Exam Score")
print(result)
```

You can also extract individual values:

```{r}
result$mean
result$sd
result$skew_label
```

---

## 2. T-Tests

### Independent Samples T-Test

Compare exam scores between male and female students:

```{r}
males   <- tutorial_data$exam_score[tutorial_data$gender == "Male"]
females <- tutorial_data$exam_score[tutorial_data$gender == "Female"]

result <- ttest_interpret(
  males, females,
  var_name = "Exam Score by Gender"
)
print(result)
```

### One-Sample T-Test

Test whether the average exam score is significantly different from 70:

```{r}
result <- ttest_interpret(
  tutorial_data$exam_score,
  mu = 70,
  var_name = "Exam Score"
)
print(result)
```

### Paired T-Test

Test whether students improved from pre-test to final exam:

```{r}
result <- ttest_interpret(
  tutorial_data$exam_score,
  tutorial_data$pre_test,
  paired   = TRUE,
  var_name = "Score Improvement"
)
print(result)
```

---

## 3. One-Way ANOVA

Test whether teaching method affects exam scores:

```{r}
result <- anova_interpret(
  exam_score ~ method,
  data = tutorial_data
)
print(result)
```

---

## 4. Two-Way ANOVA

Test the effect of both teaching method and gender on exam scores:

```{r}
result <- anova2_interpret(
  exam_score ~ method * gender,
  data = tutorial_data
)
print(result)
```

---

## 5. MANOVA

Test the combined effect of teaching method on both exam score
and pre-test score simultaneously:

```{r}
result <- manova_interpret(
  cbind(exam_score, pre_test) ~ method,
  data = tutorial_data
)
print(result)
```

---

## 6. Chi-Square Test

Test whether there is an association between teaching method
and pass/fail outcome:

```{r}
tutorial_data$passed_label <- ifelse(tutorial_data$passed == 1,
                                      "Pass", "Fail")

result <- chisq_interpret(
  tutorial_data$method,
  tutorial_data$passed_label
)
print(result)
```

---

## 7. Correlation Analysis

Test the relationship between pre-test scores and exam scores:

```{r}
result <- cor_interpret(
  tutorial_data$pre_test,
  tutorial_data$exam_score,
  var1_name = "Pre-Test Score",
  var2_name = "Exam Score"
)
print(result)
```

### Spearman Correlation

```{r}
result <- cor_interpret(
  tutorial_data$pre_test,
  tutorial_data$exam_score,
  method    = "spearman",
  var1_name = "Pre-Test Score",
  var2_name = "Exam Score"
)
print(result)
```

---

## 8. Simple Linear Regression

Predict exam score from pre-test score:

```{r}
result <- reg_interpret(
  exam_score ~ pre_test,
  data = tutorial_data
)
print(result)
```

---

## 9. Multiple Linear Regression

Predict exam score from both pre-test score and age:

```{r}
result <- mlr_interpret(
  exam_score ~ pre_test + age,
  data = tutorial_data
)
print(result)
```

---

## 10. Logistic Regression

Predict pass/fail outcome from pre-test score and age:

```{r}
result <- logistic_interpret(
  passed ~ pre_test + age,
  data = tutorial_data
)
print(result)
```

---

## 11. Non-Parametric Tests

### Mann-Whitney U Test

Non-parametric alternative to the independent samples t-test:

```{r}
result <- mannwhitney_interpret(
  males, females,
  var_name = "Exam Score by Gender"
)
print(result)
```

### Wilcoxon Signed Rank Test

Non-parametric alternative to the paired t-test:

```{r}
result <- wilcoxon_interpret(
  tutorial_data$exam_score,
  tutorial_data$pre_test,
  var_name = "Score Improvement"
)
print(result)
```

### Kruskal-Wallis Test

Non-parametric alternative to one-way ANOVA:

```{r}
result <- kruskal_interpret(
  exam_score ~ method,
  data = tutorial_data
)
print(result)
```

---

## 12. P-Value Interpretation

Interpret any p-value in plain English:

```{r}
result <- interpret_p(
  0.03,
  context = "teaching method effect on exam scores"
)
print(result)
```

---

## 13. The Master Function

The `analyze()` function automatically detects the right test
based on your input — no need to remember which function to use!

```{r}
# Descriptive statistics
analyze(x = tutorial_data$exam_score, var_name = "Exam Score")
```

```{r}
# Auto t-test
analyze(
  x        = males,
  y        = females,
  var_name = "Exam Score by Gender"
)
```

```{r}
# Auto ANOVA
analyze(formula = exam_score ~ method, data = tutorial_data)
```

```{r}
# Auto non-parametric
analyze(
  formula  = exam_score ~ method,
  data     = tutorial_data,
  nonparam = TRUE
)
```

```{r}
# Auto regression
analyze(formula = exam_score ~ pre_test, data = tutorial_data)
```

```{r}
# Auto MANOVA
analyze(
  formula = cbind(exam_score, pre_test) ~ method,
  data    = tutorial_data
)
```

---

## Summary

| Test | Function | analyze() support |
|---|---|---|
| Descriptive stats | `describe()` | ✔ |
| Independent t-test | `ttest_interpret()` | ✔ |
| One-sample t-test | `ttest_interpret()` | ✔ |
| Paired t-test | `ttest_interpret()` | ✔ |
| One-way ANOVA | `anova_interpret()` | ✔ |
| Two-way ANOVA | `anova2_interpret()` | ✔ |
| MANOVA | `manova_interpret()` | ✔ |
| Chi-square | `chisq_interpret()` | ✔ |
| Correlation | `cor_interpret()` | ✔ |
| Simple regression | `reg_interpret()` | ✔ |
| Multiple regression | `mlr_interpret()` | ✔ |
| Logistic regression | `logistic_interpret()` | ✔ |
| Mann-Whitney U | `mannwhitney_interpret()` | ✔ |
| Wilcoxon Signed Rank | `wilcoxon_interpret()` | ✔ |
| Kruskal-Wallis | `kruskal_interpret()` | ✔ |
| P-value interpretation | `interpret_p()` | - |

---
title: "Introduction to statease"
author: "Uwakmfon Paul"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Introduction to statease}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
library(statease)
```

## Overview

**statease** is an R package designed to simplify statistical analysis
by combining a wide range of tests with automatic plain-English
interpretation of results. Whether you are a student, researcher, or
educator, statease gives you numbers and meaning in one command.

---

## Installation

```{r eval=FALSE}
# Install from CRAN
install.packages("statease")

# Load the package
library(statease)
```

---

## Dataset

Throughout this vignette we use a simulated dataset of 90 students
examining the effect of teaching methods on exam performance.

```{r}
set.seed(42)

tutorial_data <- data.frame(
  student_id = 1:90,
  method     = rep(c("Traditional", "Online", "Hybrid"), each = 30),
  gender     = rep(c("Male", "Female"), times = 45),
  exam_score = c(
    round(rnorm(30, mean = 65, sd = 10)),
    round(rnorm(30, mean = 72, sd = 10)),
    round(rnorm(30, mean = 78, sd = 10))
  ),
  pre_test = c(
    round(rnorm(30, mean = 55, sd = 10)),
    round(rnorm(30, mean = 58, sd = 10)),
    round(rnorm(30, mean = 57, sd = 10))
  ),
  age        = round(rnorm(90, mean = 22, sd = 3)),
  passed     = rbinom(90, 1, prob = 0.7)
)

head(tutorial_data)
```

---

## 1. Descriptive Statistics

The `describe()` function provides a full summary of a numeric variable
including measures of central tendency, spread, and a normality check.

```{r}
result <- describe(tutorial_data$exam_score,
                   var_name = "Exam Score")
print(result)
```

You can also extract individual values:

```{r}
result$mean
result$sd
result$skew_label
```

---

## 2. T-Tests

### Independent Samples T-Test

Compare exam scores between male and female students:

```{r}
males   <- tutorial_data$exam_score[tutorial_data$gender == "Male"]
females <- tutorial_data$exam_score[tutorial_data$gender == "Female"]

result <- ttest_interpret(
  males, females,
  var_name = "Exam Score by Gender"
)
print(result)
```

### One-Sample T-Test

Test whether the average exam score is significantly different from 70:

```{r}
result <- ttest_interpret(
  tutorial_data$exam_score,
  mu = 70,
  var_name = "Exam Score"
)
print(result)
```

### Paired T-Test

Test whether students improved from pre-test to final exam:

```{r}
result <- ttest_interpret(
  tutorial_data$exam_score,
  tutorial_data$pre_test,
  paired   = TRUE,
  var_name = "Score Improvement"
)
print(result)
```

---

## 3. One-Way ANOVA

Test whether teaching method affects exam scores:

```{r}
result <- anova_interpret(
  exam_score ~ method,
  data = tutorial_data
)
print(result)
```

---

## 4. Two-Way ANOVA

Test the effect of both teaching method and gender on exam scores:

```{r}
result <- anova2_interpret(
  exam_score ~ method * gender,
  data = tutorial_data
)
print(result)
```

---

## 5. MANOVA

Test the combined effect of teaching method on both exam score
and pre-test score simultaneously:

```{r}
result <- manova_interpret(
  cbind(exam_score, pre_test) ~ method,
  data = tutorial_data
)
print(result)
```

---

## 6. Chi-Square Test

Test whether there is an association between teaching method
and pass/fail outcome:

```{r}
tutorial_data$passed_label <- ifelse(tutorial_data$passed == 1,
                                      "Pass", "Fail")

result <- chisq_interpret(
  tutorial_data$method,
  tutorial_data$passed_label
)
print(result)
```

---

## 7. Correlation Analysis

Test the relationship between pre-test scores and exam scores:

```{r}
result <- cor_interpret(
  tutorial_data$pre_test,
  tutorial_data$exam_score,
  var1_name = "Pre-Test Score",
  var2_name = "Exam Score"
)
print(result)
```

### Spearman Correlation

```{r}
result <- cor_interpret(
  tutorial_data$pre_test,
  tutorial_data$exam_score,
  method    = "spearman",
  var1_name = "Pre-Test Score",
  var2_name = "Exam Score"
)
print(result)
```

---

## 8. Simple Linear Regression

Predict exam score from pre-test score:

```{r}
result <- reg_interpret(
  exam_score ~ pre_test,
  data = tutorial_data
)
print(result)
```

---

## 9. Multiple Linear Regression

Predict exam score from both pre-test score and age:

```{r}
result <- mlr_interpret(
  exam_score ~ pre_test + age,
  data = tutorial_data
)
print(result)
```

---

## 10. Logistic Regression

Predict pass/fail outcome from pre-test score and age:

```{r}
result <- logistic_interpret(
  passed ~ pre_test + age,
  data = tutorial_data
)
print(result)
```

---

## 11. Non-Parametric Tests

### Mann-Whitney U Test

Non-parametric alternative to the independent samples t-test:

```{r}
result <- mannwhitney_interpret(
  males, females,
  var_name = "Exam Score by Gender"
)
print(result)
```

### Wilcoxon Signed Rank Test

Non-parametric alternative to the paired t-test:

```{r}
result <- wilcoxon_interpret(
  tutorial_data$exam_score,
  tutorial_data$pre_test,
  var_name = "Score Improvement"
)
print(result)
```

### Kruskal-Wallis Test

Non-parametric alternative to one-way ANOVA:

```{r}
result <- kruskal_interpret(
  exam_score ~ method,
  data = tutorial_data
)
print(result)
```

---

## 12. P-Value Interpretation

Interpret any p-value in plain English:

```{r}
result <- interpret_p(
  0.03,
  context = "teaching method effect on exam scores"
)
print(result)
```

---

## 13. The Master Function

The `analyze()` function automatically detects the right test
based on your input — no need to remember which function to use!

```{r}
# Descriptive statistics
analyze(x = tutorial_data$exam_score, var_name = "Exam Score")
```

```{r}
# Auto t-test
analyze(
  x        = males,
  y        = females,
  var_name = "Exam Score by Gender"
)
```

```{r}
# Auto ANOVA
analyze(formula = exam_score ~ method, data = tutorial_data)
```

```{r}
# Auto non-parametric
analyze(
  formula  = exam_score ~ method,
  data     = tutorial_data,
  nonparam = TRUE
)
```

```{r}
# Auto regression
analyze(formula = exam_score ~ pre_test, data = tutorial_data)
```

```{r}
# Auto MANOVA
analyze(
  formula = cbind(exam_score, pre_test) ~ method,
  data    = tutorial_data
)
```

---

## 14. Fisher's Exact Test

Test the association between two categorical variables 
when sample sizes are small:

```{r}
result <- fisher_interpret(
  tutorial_data$method,
  tutorial_data$passed_label
)
print(result)
```

## 15. McNemar's Test

Test whether there is a significant difference in paired 
proportions between two related measurements:

```{r}
pre_pass  <- sample(c("Yes","No"), 90, replace = TRUE, 
                    prob = c(0.4, 0.6))
post_pass <- sample(c("Yes","No"), 90, replace = TRUE, 
                    prob = c(0.7, 0.3))

result <- mcnemar_interpret(pre_pass, post_pass)
print(result)
```

## 16. Friedman Test

Non-parametric alternative to repeated measures ANOVA:

```{r}
friedman_data <- data.frame(
  score   = c(23,45,12,67,34,89,56,43,78,90,11,34),
  time    = rep(c("T1","T2","T3"), each = 4),
  subject = rep(1:4, times = 3)
)

result <- friedman_interpret(score ~ time | subject, 
                             data = friedman_data)
print(result)
```

## 17. Checking Assumptions

Before running a test, check its assumptions automatically:

```{r}
result <- check_assumptions(
  "ttest",
  x = males,
  y = females
)
print(result)
```

## 18. Power Analysis

Determine the sample size needed to detect an effect:

```{r}
result <- power_interpret(
  "ttest.two",
  effect_size = 0.5
)
print(result)
```

## 19. The Shiny App

For users who prefer a point-and-click interface, statease 
includes a built-in Shiny app:

```{r eval=FALSE}
statease::run_app()
```

This launches an interactive web application where you can 
upload your data, select variables, and run any statease 
function without writing code.

## Summary

| Test | Function | analyze() support |
|---|---|---|
| Descriptive stats | `describe()` | ✔ |
| Independent t-test | `ttest_interpret()` | ✔ |
| One-sample t-test | `ttest_interpret()` | ✔ |
| Paired t-test | `ttest_interpret()` | ✔ |
| One-way ANOVA | `anova_interpret()` | ✔ |
| Two-way ANOVA | `anova2_interpret()` | ✔ |
| MANOVA | `manova_interpret()` | ✔ |
| Chi-square | `chisq_interpret()` | ✔ |
| Correlation | `cor_interpret()` | ✔ |
| Simple regression | `reg_interpret()` | ✔ |
| Multiple regression | `mlr_interpret()` | ✔ |
| Logistic regression | `logistic_interpret()` | ✔ |
| Mann-Whitney U | `mannwhitney_interpret()` | ✔ |
| Wilcoxon Signed Rank | `wilcoxon_interpret()` | ✔ |
| Kruskal-Wallis | `kruskal_interpret()` | ✔ |
| Fisher's Exact | `fisher_interpret()` | ✔ |
| McNemar's Test | `mcnemar_interpret()` | ✔ |
| Friedman Test | `friedman_interpret()` | ✔ |
| Check Assumptions | `check_assumptions()` | ✔ |
| Power Analysis | `power_interpret()` | ✔ |
| P-value interpretation | `interpret_p()` | - |

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/statease-package.R
\docType{package}
\name{statease}
\alias{statease-package}
\alias{statease}
\title{statease: Simplified Statistical Analysis with Plain-English Interpretation}
\description{
statease provides a suite of functions for performing common statistical
analyses and automatically interpreting the results in plain English.
It is designed for students, researchers, and educators who want fast,
readable statistical output without sacrificing rigour.
}
\section{Main Functions}{

\describe{
\item{\code{\link{analyze}}}{Master function — auto-detects and runs the right test}
\item{\code{\link{describe}}}{Descriptive statistics with interpretation}
\item{\code{\link{ttest_interpret}}}{T-tests (one-sample, independent, paired) with Cohen's d}
\item{\code{\link{anova_interpret}}}{One-way ANOVA with Tukey post-hoc and eta squared}
\item{\code{\link{interpret_p}}}{Standalone p-value interpreter}
}
}

\section{Typical Workflow}{

The simplest way to use statease is through the master \code{analyze()}
function, which automatically detects what test to run based on your input:

\preformatted{
# Descriptive statistics
analyze(x = my_vector, var_name = "My Variable")

# Independent samples t-test
analyze(x = group1, y = group2, var_name = "Scores")

# One-way ANOVA
analyze(formula = score ~ group, data = my_df)

# Interpret a p-value
interpret_p(0.03, context = "treatment vs control")
}
}

\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/DevWebWacky/statease}
  \item Report bugs at \url{https://github.com/DevWebWacky/statease/issues}
}

}
\author{
Uwakmfon Usen Paul
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/anova2_interpret.R
\name{anova2_interpret}
\alias{anova2_interpret}
\title{Two-Way ANOVA with Plain-English Interpretation}
\usage{
anova2_interpret(formula, data, type = 2, conf.level = 0.95)
}
\arguments{
\item{formula}{A formula of the form outcome ~ group1 * group2}

\item{data}{A data frame containing the variables}

\item{type}{ANOVA type: 2 or 3. Default is 2. Type 3 is automatically
used when an interaction term is detected in the formula.}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_anova2} containing two-way
ANOVA results and interpretation. Use \code{print()} to display
the formatted report.
}
\description{
Uses Type-2 SS by default (safe for unbalanced designs). Automatically
switches to Type-3 SS when an interaction term is detected and sets
the correct contrasts. Users are warned when interpreting main effects
in the presence of a significant interaction.
}
\examples{
df <- data.frame(
  score  = c(23,45,12,67,34,89,56,43,78,90,11,34),
  method = rep(c("Online","Traditional"), each = 6),
  gender = rep(c("Male","Female"), times = 6)
)
result <- anova2_interpret(score ~ method * gender, data = df)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/anova_interpret.R
\name{anova_interpret}
\alias{anova_interpret}
\title{One-Way ANOVA with Post-Hoc Tukey and Plain-English Interpretation}
\usage{
anova_interpret(formula, data, conf.level = 0.95)
}
\arguments{
\item{formula}{A formula of the form outcome ~ group}

\item{data}{A data frame containing the variables}

\item{conf.level}{Confidence level. Default 0.95}
}
\value{
An object of class \code{statease_anova} containing ANOVA
results, effect size, and post-hoc comparisons. Use \code{print()}
to display the formatted report.
}
\description{
One-Way ANOVA with Post-Hoc Tukey and Plain-English Interpretation
}
\examples{
df <- data.frame(
  score = c(23,45,12,67,34,89,56,43,78,90,11,34),
  group = rep(c("A","B","C"), each = 4)
)
result <- anova_interpret(score ~ group, data = df)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chisq_interpret.R
\name{chisq_interpret}
\alias{chisq_interpret}
\title{Chi-Square Test with Plain-English Interpretation}
\usage{
chisq_interpret(x, y, correct = TRUE, conf.level = 0.95)
}
\arguments{
\item{x}{A factor or character vector (first categorical variable)}

\item{y}{A factor or character vector (second categorical variable)}

\item{correct}{Logical. Apply Yates continuity correction. Default TRUE.}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_chisq} containing test
results and interpretation. Use \code{print()} to display the
formatted report.
}
\description{
Chi-Square Test with Plain-English Interpretation
}
\examples{
x <- c("Yes","No","Yes","Yes","No","Yes","No","No","Yes","Yes")
y <- c("Male","Female","Male","Female","Male","Female","Male","Female","Male","Female")
result <- chisq_interpret(x, y)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cor_interpret.R
\name{cor_interpret}
\alias{cor_interpret}
\title{Correlation Analysis with Plain-English Interpretation}
\usage{
cor_interpret(
  x,
  y,
  method = "pearson",
  conf.level = 0.95,
  var1_name = "Variable 1",
  var2_name = "Variable 2"
)
}
\arguments{
\item{x}{A numeric vector}

\item{y}{A numeric vector}

\item{method}{Correlation method: "pearson", "spearman", or "kendall".
Default "pearson".}

\item{conf.level}{Confidence level. Default 0.95.}

\item{var1_name}{Optional name for first variable. Default "Variable 1"}

\item{var2_name}{Optional name for second variable. Default "Variable 2"}
}
\value{
An object of class \code{statease_cor} containing correlation
results and interpretation. Use \code{print()} to display the
formatted report.
}
\description{
Correlation Analysis with Plain-English Interpretation
}
\examples{
x <- c(23, 45, 12, 67, 34, 89, 56, 43, 78, 90)
y <- c(19, 42, 15, 70, 30, 85, 52, 48, 80, 88)
result <- cor_interpret(x, y)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nonparam_interpret.R
\name{kruskal_interpret}
\alias{kruskal_interpret}
\title{Kruskal-Wallis Test with Plain-English Interpretation}
\usage{
kruskal_interpret(formula, data, conf.level = 0.95)
}
\arguments{
\item{formula}{A formula of the form outcome ~ group}

\item{data}{A data frame containing the variables}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_kruskal} containing
test results and interpretation. Use \code{print()} to display
the formatted report.
}
\description{
Kruskal-Wallis Test with Plain-English Interpretation
}
\examples{
df <- data.frame(
  score = c(23,45,12,67,34,89,56,43,78,90,11,34),
  group = rep(c("A","B","C"), each = 4)
)
result <- kruskal_interpret(score ~ group, data = df)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reg_interpret.R
\name{reg_interpret}
\alias{reg_interpret}
\title{Simple Linear Regression with Plain-English Interpretation}
\usage{
reg_interpret(formula, data, conf.level = 0.95)
}
\arguments{
\item{formula}{A formula of the form outcome ~ predictor}

\item{data}{A data frame containing the variables}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_reg} containing regression
results and interpretation. Use \code{print()} to display the
formatted report.
}
\description{
Simple Linear Regression with Plain-English Interpretation
}
\examples{
df <- data.frame(
  exam_score = c(23,45,12,67,34,89,56,43,78,90),
  study_hours = c(2,5,1,7,3,9,6,4,8,10)
)
result <- reg_interpret(exam_score ~ study_hours, data = df)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcnemar_interpret.R
\name{mcnemar_interpret}
\alias{mcnemar_interpret}
\title{McNemar's Test with Plain-English Interpretation}
\usage{
mcnemar_interpret(x, y, conf.level = 0.95)
}
\arguments{
\item{x}{A factor or character vector (first measurement)}

\item{y}{A factor or character vector (second measurement)}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_mcnemar} containing test
results and interpretation. Use \code{print()} to display the
formatted report.
}
\description{
McNemar's Test with Plain-English Interpretation
}
\examples{
x <- c("Yes","No","Yes","Yes","No","Yes","No","No","Yes","Yes")
y <- c("No","No","Yes","Yes","No","Yes","Yes","No","Yes","No")
result <- mcnemar_interpret(x, y)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/describe.R
\name{describe}
\alias{describe}
\title{Descriptive Statistics with Interpretation}
\usage{
describe(x, var_name = "Variable")
}
\arguments{
\item{x}{A numeric vector}

\item{var_name}{Optional name for the variable (used in the report)}
}
\value{
An object of class \code{statease_describe} containing
descriptive statistics and interpretation. Use \code{print()} to
display the formatted report.
}
\description{
Descriptive Statistics with Interpretation
}
\examples{
result <- describe(c(23, 45, 12, 67, 34, 89, 56))
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_assumptions.R
\name{check_assumptions}
\alias{check_assumptions}
\title{Check Statistical Assumptions Before Running a Test}
\usage{
check_assumptions(test, x = NULL, y = NULL, data = NULL, formula = NULL)
}
\arguments{
\item{test}{The test you plan to run. One of "ttest", "anova",
"anova2", "correlation", "regression".}

\item{x}{A numeric vector (required for most tests)}

\item{y}{A numeric vector, factor, or character group variable
(optional depending on test)}

\item{data}{A data frame (required for anova, anova2, regression)}

\item{formula}{A formula (required for anova, anova2, regression)}
}
\value{
An object of class \code{statease_assumptions} containing
assumption check results. Use \code{print()} to display the
formatted report.
}
\description{
Check Statistical Assumptions Before Running a Test
}
\examples{
x <- c(23, 45, 12, 67, 34, 89, 56, 43, 78, 90)
y <- c(19, 38, 22, 51, 29, 74, 44, 38, 65, 80)
result <- check_assumptions("ttest", x = x, y = y)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nonparam_interpret.R
\name{mannwhitney_interpret}
\alias{mannwhitney_interpret}
\title{Mann-Whitney U Test with Plain-English Interpretation}
\usage{
mannwhitney_interpret(x, y, conf.level = 0.95, var_name = "Variable")
}
\arguments{
\item{x}{A numeric vector (group 1)}

\item{y}{A numeric vector (group 2)}

\item{conf.level}{Confidence level. Default 0.95.}

\item{var_name}{Optional label for the report. Default "Variable"}
}
\value{
An object of class \code{statease_mannwhitney} containing
test results and interpretation. Use \code{print()} to display
the formatted report.
}
\description{
Mann-Whitney U Test with Plain-English Interpretation
}
\examples{
x <- c(23, 45, 12, 67, 34, 89, 56)
y <- c(19, 38, 22, 51, 29, 74, 44)
result <- mannwhitney_interpret(x, y)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/interpret_p.R
\name{interpret_p}
\alias{interpret_p}
\title{Standalone P-Value Interpreter}
\usage{
interpret_p(p, alpha = 0.05, context = NULL)
}
\arguments{
\item{p}{A numeric p-value between 0 and 1}

\item{alpha}{Significance level. Default 0.05}

\item{context}{Optional string describing the test context}
}
\value{
An object of class \code{statease_pvalue} containing the
p-value interpretation. Use \code{print()} to display the report.
}
\description{
Standalone P-Value Interpreter
}
\examples{
result <- interpret_p(0.03)
print(result)

result2 <- interpret_p(0.12, alpha = 0.05, context = "treatment vs control")
print(result2)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ttest_interpret.R
\name{ttest_interpret}
\alias{ttest_interpret}
\title{T-Test with Plain-English Interpretation}
\usage{
ttest_interpret(
  x,
  y = NULL,
  mu = 0,
  paired = FALSE,
  conf.level = 0.95,
  var_name = "Variable"
)
}
\arguments{
\item{x}{A numeric vector (group 1, or the only group for one-sample)}

\item{y}{A numeric vector (group 2, for independent samples). Default NULL.}

\item{mu}{Hypothesised mean for one-sample t-test. Default 0.}

\item{paired}{Logical. TRUE for paired t-test. Default FALSE.}

\item{conf.level}{Confidence level. Default 0.95.}

\item{var_name}{Optional label for the report. Default "Variable"}
}
\value{
An object of class \code{statease_ttest} containing test
results and interpretation. Use \code{print()} to display the
formatted report.
}
\description{
T-Test with Plain-English Interpretation
}
\examples{
result <- ttest_interpret(c(23,45,12,67,34), c(19,38,22,51,29))
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nonparam_interpret.R
\name{wilcoxon_interpret}
\alias{wilcoxon_interpret}
\title{Wilcoxon Signed Rank Test with Plain-English Interpretation}
\usage{
wilcoxon_interpret(x, y, conf.level = 0.95, var_name = "Variable")
}
\arguments{
\item{x}{A numeric vector (first measurement)}

\item{y}{A numeric vector (second measurement)}

\item{conf.level}{Confidence level. Default 0.95.}

\item{var_name}{Optional label for the report. Default "Variable"}
}
\value{
An object of class \code{statease_wilcoxon} containing
test results and interpretation. Use \code{print()} to display
the formatted report.
}
\description{
Wilcoxon Signed Rank Test with Plain-English Interpretation
}
\examples{
x <- c(23, 45, 12, 67, 34, 89, 56)
y <- c(19, 38, 22, 51, 29, 74, 44)
result <- wilcoxon_interpret(x, y)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/manova_interpret.R
\name{manova_interpret}
\alias{manova_interpret}
\title{MANOVA with Plain-English Interpretation}
\usage{
manova_interpret(formula, data, conf.level = 0.95)
}
\arguments{
\item{formula}{A formula of the form cbind(outcome1, outcome2, ...) ~ group}

\item{data}{A data frame containing the variables}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_manova} containing MANOVA
results and interpretation. Use \code{print()} to display the
formatted report.
}
\description{
MANOVA with Plain-English Interpretation
}
\examples{
df <- data.frame(
  math    = c(23,45,12,67,34,89,56,43,78,90,11,34),
  english = c(34,56,23,78,45,90,67,54,89,95,22,45),
  group   = rep(c("A","B","C"), each = 4)
)
result <- manova_interpret(cbind(math, english) ~ group, data = df)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_app.R
\name{run_app}
\alias{run_app}
\title{Launch the statease Shiny App}
\usage{
run_app(...)
}
\arguments{
\item{...}{Additional arguments passed to shiny::runApp()}
}
\value{
Launches the Shiny app in your browser
}
\description{
Launches an interactive Shiny application for
running statistical analyses without writing any code.
}
\examples{
if(interactive()){
  run_app()
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/power_interpret.R
\name{power_interpret}
\alias{power_interpret}
\title{Power Analysis with Plain English Interpretation}
\usage{
power_interpret(
  test,
  effect_size,
  n = NULL,
  alpha = 0.05,
  power = 0.8,
  n_groups = 2,
  n_predictors = 1
)
}
\arguments{
\item{test}{The statistical test. One of "ttest.one",
"ttest.two", "ttest.paired", "anova", "correlation",
"chisq", "regression".}

\item{effect_size}{The expected effect size. Use Cohen's
conventions: small = 0.2, medium = 0.5, large = 0.8
for t-tests; small = 0.10, medium = 0.25, large = 0.40
for ANOVA; small = 0.10, medium = 0.30, large = 0.50
for correlation.}

\item{n}{Sample size per group. If provided, calculates
achieved power. If NULL, calculates required sample size.}

\item{alpha}{Significance level. Default 0.05.}

\item{power}{Desired power level. Default 0.80.}

\item{n_groups}{Number of groups (for ANOVA only). Default 2.}

\item{n_predictors}{Number of predictors (for regression only).
Default 1.}
}
\value{
An object of class \code{statease_power} containing
power analysis results and interpretation. Use \code{print()}
to display the formatted report.
}
\description{
Power Analysis with Plain English Interpretation
}
\examples{
# Calculate required sample size for independent t-test
result <- power_interpret("ttest.two", effect_size = 0.5)
print(result)

# Calculate achieved power for given sample size
result2 <- power_interpret("ttest.two", effect_size = 0.5, n = 30)
print(result2)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analyze.R
\name{analyze}
\alias{analyze}
\title{Master Analysis Function - Auto-detects and runs the right test}
\usage{
analyze(
  x = NULL,
  y = NULL,
  data = NULL,
  formula = NULL,
  mu = 0,
  paired = FALSE,
  nonparam = FALSE,
  conf.level = 0.95,
  var_name = "Variable",
  var1_name = "Variable 1",
  var2_name = "Variable 2",
  method = "pearson",
  test_type = NULL,
  effect_size = NULL,
  power = 0.8,
  n_groups = 2,
  n_predictors = 1,
  check = FALSE
)
}
\arguments{
\item{x}{A numeric vector (required always)}

\item{y}{A numeric vector, factor, or character group variable (optional)}

\item{data}{A data frame (required if using a formula)}

\item{formula}{A formula of the form outcome ~ predictor or
outcome ~ group1 * group2 or cbind(y1, y2) ~ group (optional)}

\item{mu}{Hypothesised mean for one-sample t-test. Default 0.}

\item{paired}{Logical. TRUE for paired t-test. Default FALSE.}

\item{nonparam}{Logical. TRUE to use non-parametric tests. Default FALSE.}

\item{conf.level}{Confidence level. Default 0.95.}

\item{var_name}{Optional label for the report.}

\item{var1_name}{Optional name for first variable in correlation.}

\item{var2_name}{Optional name for second variable in correlation.}

\item{method}{Correlation method: "pearson", "spearman", or "kendall".
Default "pearson".}

\item{test_type}{For power analysis: one of "ttest.one", "ttest.two",
"ttest.paired", "anova", "correlation", "chisq", "regression".}

\item{effect_size}{For power analysis: the expected effect size.}

\item{power}{For power analysis: desired power level. Default 0.80.}

\item{n_groups}{For power analysis ANOVA: number of groups. Default 2.}

\item{n_predictors}{For power analysis regression: number of predictors.
Default 1.}

\item{check}{Logical. TRUE to run assumption checks before analysis.
Default FALSE.}
}
\value{
A printed analysis report from the appropriate test
}
\description{
Master Analysis Function - Auto-detects and runs the right test
}
\examples{
# Descriptive only
analyze(x = c(23, 45, 12, 67, 34))

# Auto t-test
analyze(x = c(23,45,12,67,34), y = c(19,38,22,51,29))

# Auto ANOVA
df <- data.frame(
  score = c(23,45,12,67,34,89,56,43,78,90,11,34),
  group = rep(c("A","B","C"), each = 4)
)
analyze(formula = score ~ group, data = df)

# Power analysis
analyze(test_type = "ttest.two", effect_size = 0.5)

# Check assumptions
analyze(x = c(23,45,12,67,34), y = c(19,38,22,51,29),
        check = TRUE)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/logistic_interpret.R
\name{logistic_interpret}
\alias{logistic_interpret}
\title{Logistic Regression with Plain-English Interpretation}
\usage{
logistic_interpret(formula, data, conf.level = 0.95)
}
\arguments{
\item{formula}{A formula of the form outcome ~ predictor1 + predictor2 + ...}

\item{data}{A data frame containing the variables}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_logistic} containing logistic
regression results and interpretation. Use \code{print()} to
display the formatted report.
}
\description{
Logistic Regression with Plain-English Interpretation
}
\examples{
df <- data.frame(
  passed      = c(1,1,0,1,0,1,1,0,1,1,0,0,1,1,0),
  study_hours = c(9,8,3,7,2,9,8,3,7,6,2,1,8,7,3),
  attendance  = c(90,85,50,80,45,95,88,55,78,70,40,35,92,83,52)
)
result <- logistic_interpret(passed ~ study_hours + attendance, data = df)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fisher_interpret.R
\name{fisher_interpret}
\alias{fisher_interpret}
\title{Fisher's Exact Test with Plain-English Interpretation}
\usage{
fisher_interpret(x, y, conf.level = 0.95, simulate.p.value = FALSE)
}
\arguments{
\item{x}{A factor or character vector (first categorical variable)}

\item{y}{A factor or character vector (second categorical variable)}

\item{conf.level}{Confidence level. Default 0.95.}

\item{simulate.p.value}{Logical. Whether to use simulation to
compute p-values for larger tables. Default FALSE.}
}
\value{
An object of class \code{statease_fisher} containing test
results and interpretation. Use \code{print()} to display the
formatted report.
}
\description{
Fisher's Exact Test with Plain-English Interpretation
}
\examples{
x <- c("Yes","No","Yes","Yes","No","Yes","No","No","Yes","Yes")
y <- c("Male","Female","Male","Female","Male",
       "Female","Male","Female","Male","Female")
result <- fisher_interpret(x, y)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/friedman_interpret.R
\name{friedman_interpret}
\alias{friedman_interpret}
\title{Friedman Test with Plain-English Interpretation}
\usage{
friedman_interpret(formula, data, conf.level = 0.95)
}
\arguments{
\item{formula}{A formula of the form outcome ~ time | subject}

\item{data}{A data frame containing the variables}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_friedman} containing test
results and interpretation. Use \code{print()} to display the
formatted report.
}
\description{
Friedman Test with Plain-English Interpretation
}
\examples{
df <- data.frame(
  score   = c(23,45,12,67,34,89,56,43,78,90,11,34),
  time    = rep(c("T1","T2","T3"), each = 4),
  subject = rep(1:4, times = 3)
)
result <- friedman_interpret(score ~ time | subject, data = df)
print(result)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlr_interpret.R
\name{mlr_interpret}
\alias{mlr_interpret}
\title{Multiple Linear Regression with Plain-English Interpretation}
\usage{
mlr_interpret(formula, data, conf.level = 0.95)
}
\arguments{
\item{formula}{A formula of the form outcome ~ predictor1 + predictor2 + ...}

\item{data}{A data frame containing the variables}

\item{conf.level}{Confidence level. Default 0.95.}
}
\value{
An object of class \code{statease_mlr} containing multiple
regression results and interpretation. Use \code{print()} to
display the formatted report.
}
\description{
Multiple Linear Regression with Plain-English Interpretation
}
\examples{
df <- data.frame(
  exam_score  = c(23,45,12,67,34,89,56,43,78,90),
  study_hours = c(2,5,1,7,3,9,6,4,8,10),
  attendance  = c(60,80,50,90,70,95,85,75,88,92)
)
result <- mlr_interpret(exam_score ~ study_hours + attendance, data = df)
print(result)
}
